<?php
session_start();
include('../config.php');

// Check if user is an admin
if ($_SESSION['role'] !== 'admin') {
    header("Location: ../index.php");
    exit();
}

// Handle coupon creation
if (isset($_POST['create_coupon'])) {
    $code = $_POST['code'];
    $discount = $_POST['discount'];
    $one_time_use = isset($_POST['one_time_use']) ? 1 : 0;

    $stmt = $pdo->prepare("INSERT INTO coupons (code, discount, one_time_use) VALUES (?, ?, ?)");
    $stmt->execute([$code, $discount, $one_time_use]);

    $success_message = "Coupon created successfully.";
}
?>
<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Add Coupon</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
            background-color: #f0f2f5;
        }
        .container {
            max-width: 600px;
            margin-top: 50px;
        }
        .form-container {
            background-color: #fff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        .form-container h2 {
            margin-bottom: 20px;
            font-weight: 700;
        }
    </style>
</head>
<body>
    <nav>
        <?php include 'nav2.php'; ?>
    </nav>
    <div class="container">
        <div class="form-container">
            <h2>Add Coupon</h2>
            <?php if (isset($success_message)): ?>
                <p class="alert alert-success"><?php echo htmlspecialchars($success_message, ENT_QUOTES, 'UTF-8'); ?></p>
            <?php endif; ?>
            <form method="POST">
                <div class="form-group">
                    <label for="code">Coupon Code</label>
                    <input type="text" class="form-control" name="code" required>
                </div>
                <div class="form-group">
                    <label for="discount">Discount (%)</label>
                    <input type="number" class="form-control" name="discount" required>
                </div>
                <div class="form-group">
                    <label for="one_time_use">One Time Use</label>
                    <input type="checkbox" name="one_time_use">
                </div>
                <button type="submit" name="create_coupon" class="btn btn-primary">Create Coupon</button>
            </form>
        </div>
    </div>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>
</body>
</html>
