<?php
session_start();
include('../config.php');
include('includes/auth.php');

// Fetch all servers
function getAllServers($pdo) {
    $query = "SELECT * FROM servers";
    $stmt = $pdo->prepare($query);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

$servers = getAllServers($pdo);

?>
<!DOCTYPE html>
<html>
<head>
    <title>Add Hosting Plan</title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .form-control.unlimited {
            color: green;
            font-weight: bold;
        }
    </style>
</head>
<body>
    <nav>
        <?php include 'nav2.php'; ?>
    </nav>
    <div class="container mt-4">
        <div class="page-header">
            <h2>Add Hosting Plan</h2>
        </div>
        <form action="create_hosting_plan.php" method="post">
            <div class="form-group">
                <label for="server_id">Select Server</label>
                <select id="server_id" name="server_id" class="form-control" required>
                    <option value="">Select Server</option>
                    <?php foreach ($servers as $server): ?>
                        <option value="<?php echo htmlspecialchars($server['id'], ENT_QUOTES, 'UTF-8'); ?>">
                            <?php echo htmlspecialchars($server['name'], ENT_QUOTES, 'UTF-8'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>

            <div class="form-group">
                <label for="name">Plan Name</label>
                <input type="text" id="name" name="name" class="form-control" required>
            </div>

            <div class="form-group">
                <label for="disk">Disk Quota</label>
                <div class="input-group">
                    <input type="text" id="disk" name="disk" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('disk')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="bandwidth">Bandwidth</label>
                <div class="input-group">
                    <input type="text" id="bandwidth" name="bandwidth" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('bandwidth')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="maxaddondomains">Max Addon Domains</label>
                <div class="input-group">
                    <input type="text" id="maxaddondomains" name="maxaddondomains" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxaddondomains')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="maxftp">Max FTP Accounts</label>
                <div class="input-group">
                    <input type="text" id="maxftp" name="maxftp" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxftp')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="maxsql">Max SQL Databases</label>
                <div class="input-group">
                    <input type="text" id="maxsql" name="maxsql" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxsql')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="maxemail">Max Email Accounts</label>
                <div class="input-group">
                    <input type="text" id="maxemail" name="maxemail" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxemail')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="maxsubdomain">Max Subdomains</label>
                <div class="input-group">
                    <input type="text" id="maxsubdomain" name="maxsubdomain" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxsubdomain')">Unlimited</button>
                    </div>
                </div>
            </div>

            <div class="form-group">
                <label for="maxparked">Max Parked Domains</label>
                <div class="input-group">
                    <input type="text" id="maxparked" name="maxparked" class="form-control" value="unlimited">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxparked')">Unlimited</button>
                    </div>
                </div>
            </div>


            <button type="submit" class="btn btn-primary">Add Plan</button>
        </form>
    </div>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>

    <script>
        function setUnlimited(fieldId) {
            var field = document.getElementById(fieldId);
            field.value = 'unlimited';
            field.classList.add('unlimited');
        }
    </script>
</body>
</html>
