<?php
session_start();
include('../config.php');
include('includes/auth.php');

// Fetch categories for dropdown
$query = "SELECT * FROM categories";
$stmt = $pdo->prepare($query);
$stmt->execute();
$categories = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch servers for dropdown
$serverQuery = "SELECT * FROM servers";
$serverStmt = $pdo->prepare($serverQuery);
$serverStmt->execute();
$servers = $serverStmt->fetchAll(PDO::FETCH_ASSOC);

// Function to make API requests
function makeWhmApiRequest($url, $whmUsername, $whmApiToken) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
        "Authorization: whm $whmUsername:$whmApiToken"
    ));
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        return array('error' => curl_error($ch));
    }
    curl_close($ch);
    return json_decode($response, true);
}

// Process form submission
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = $_POST['name'];
    $description = $_POST['description'];
    $price_monthly = $_POST['price_monthly'];
    $price_yearly = $_POST['price_yearly'];
    $internal_name = $_POST['internal_name'];
    $product_type = $_POST['product_type'];
    $category_id = $_POST['category'];
    $server_id = $_POST['server_id'];
    $visibility = $_POST['visibility'];
    $status = $_POST['status'];

    // Insert the new product into the database
    $stmt = $pdo->prepare("
        INSERT INTO products (name, description, price_monthly, price_yearly, internal_name, product_type, category_id, server_id, visibility, status, created_at)
        VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, NOW())
    ");
    $stmt->execute([$name, $description, $price_monthly, $price_yearly, $internal_name, $product_type, $category_id, $server_id, $visibility, $status]);

    header('Location: manage_products.php');
    exit();
}
?>
<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إضافة منتج</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .form-group {
            margin-bottom: 15px;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <h2>إضافة منتج</h2>
        <form method="POST">
            <div class="form-group">
                <label for="name">الاسم</label>
                <input type="text" name="name" id="name" class="form-control" required>
            </div>
            <div class="form-group">
                <label for="description">الوصف</label>
                <textarea name="description" id="description" class="form-control" required></textarea>
            </div>
            <div class="form-group" id="price-group">
                <label for="price_monthly">السعر الشهري</label>
                <input type="number" name="price_monthly" id="price_monthly" class="form-control">
                <label for="price_yearly">السعر السنوي</label>
                <input type="number" name="price_yearly" id="price_yearly" class="form-control">
            </div>
            <div class="form-group">
                <label for="server_id">الخادم</label>
                <select name="server_id" id="server_id" class="form-control" required>
                    <option value="">-- اختر خادم --</option>
                    <?php foreach ($servers as $server): ?>
                        <option value="<?php echo htmlspecialchars($server['id'], ENT_QUOTES, 'UTF-8'); ?>">
                            <?php echo htmlspecialchars($server['name'], ENT_QUOTES, 'UTF-8'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-group">
                <label for="category">الفئة</label>
                <select name="category" id="category" class="form-control" required>
                    <option value="">-- اختر فئة --</option>
                    <?php foreach ($categories as $cat): ?>
                        <option value="<?php echo htmlspecialchars($cat['id'], ENT_QUOTES, 'UTF-8'); ?>">
                            <?php echo htmlspecialchars($cat['name'], ENT_QUOTES, 'UTF-8'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-group">
                <label for="product_type">نوع المنتج</label>
                <select name="product_type" id="product_type" class="form-control" required>
                    <option value="hosting">استضافة</option>
                    <option value="domain">نطاق</option>
                    <option value="ssl">SSL</option>
                </select>
            </div>
            <div class="form-group" id="internal-name-group">
                <label for="internal_name">الاسم الداخلي</label>
                <input type="text" name="internal_name" id="internal_name" class="form-control">
            </div>
            <div class="form-group" id="hosting-plan-group" style="display: none;">
                <label for="internal_name">اختر خطة الاستضافة</label>
                <select name="internal_name" id="hosting_plan" class="form-control">
                    <option value="">-- اختر خطة --</option>
                </select>
            </div>
            <div class="form-group">
                <label for="visibility">الظهور</label>
                <select name="visibility" id="visibility" class="form-control" required>
                    <option value="1">ظاهر</option>
                    <option value="0">مخفي</option>
                </select>
            </div>
            <div class="form-group">
                <label for="status">الحالة</label>
                <select name="status" id="status" class="form-control" required>
                    <option value="1">نشط</option>
                    <option value="0">غير نشط</option>
                </select>
            </div>
            <button type="submit" class="btn btn-primary">إضافة المنتج</button>
        </form>
    </div>
    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
<script>
    $(document).ready(function() {
        $('#product_type').on('change', function() {
            const productType = $(this).val();
            
            if (productType === 'domain') {
                $('#price-group').hide();
                $('#hosting-plan-group').hide();
                $('#internal-name-group').show();
            } else if (productType === 'hosting') {
                $('#price-group').show();
                $('#hosting-plan-group').show();
                $('#internal-name-group').hide();
            } else {
                $('#price-group').show();
                $('#hosting-plan-group').hide();
                $('#internal-name-group').show();
            }
        }).trigger('change'); // Trigger change to set initial state
        
        $('#server_id').on('change', function() {
            const serverId = $(this).val();
            if (serverId) {
                $.ajax({
                    url: 'fetch_server_plans.php', // This is the PHP file we created earlier
                    type: 'GET',
                    data: { server_id: serverId },
                    success: function(response) {
                        $('#hosting_plan').html(response);
                    },
                    error: function() {
                        $('#hosting_plan').html('<option value="">حدث خطأ في جلب الخطط</option>');
                    }
                });
            } else {
                $('#hosting_plan').html('<option value="">-- اختر خطة --</option>');
            }
        });
    });
</script>

</body>
</html>
