<?php
// Include necessary files and start session
include('../config.php');
include('includes/auth.php');
session_start();

// Redirect if not admin
if ($_SESSION['role'] !== 'admin') {
    header('Location: ../client/dashboard.php');
    exit();
}

// Handle add user
if (isset($_POST['add_user'])) {
    $username = $_POST['username'];
    $email = $_POST['email'];
    $password = password_hash($_POST['password'], PASSWORD_BCRYPT);
    $role = $_POST['role'];
    $balance = $_POST['balance'];
    $country = $_POST['country'];
    $gender = $_POST['gender'];
    $phone = $_POST['phone'];
    $first_name = $_POST['first_name'];
    $last_name = $_POST['last_name'];
    $company_name = $_POST['company_name']; // Assuming company_name is entered directly
    $verification_token = bin2hex(random_bytes(50)); // Generate a verification token

    // Insert user into users table
    $stmt = $pdo->prepare("INSERT INTO users (username, email, password, country, gender, phone, first_name, last_name, verification_token, role, balance, company_name) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
    $stmt->execute([$username, $email, $password, $country, $gender, $phone, $first_name, $last_name, $verification_token, $role, $balance, $company_name]);

    // Update or insert company in companies table
    $stmt = $pdo->prepare("SELECT id FROM companies WHERE name = ?");
    $stmt->execute([$company_name]);
    $company = $stmt->fetch();

    if ($company) {
        // Update existing company
        $stmt = $pdo->prepare("UPDATE companies SET name = ? WHERE id = ?");
        $stmt->execute([$company_name, $company['id']]);
    } else {
        // Insert new company
        $stmt = $pdo->prepare("INSERT INTO companies (name) VALUES (?)");
        $stmt->execute([$company_name]);
        $companyId = $pdo->lastInsertId();

        // Update user's company_id
        $stmt = $pdo->prepare("UPDATE users SET company_id = ? WHERE email = ?");
        $stmt->execute([$companyId, $email]);
    }

    header('Location: manage_users.php');
    exit();
}
?>

<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إضافة مستخدم جديد</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .form-container {
            margin-top: 20px;
            padding: 20px;
            border-radius: 8px;
        }
        .form-header {
            margin-bottom: 20px;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <div class="form-container">
            <div class="form-header text-center">
                <h2>إضافة مستخدم جديد</h2>
            </div>
            <form method="POST">
                <div class="form-group">
                    <label for="username">اسم المستخدم</label>
                    <input type="text" class="form-control" id="username" name="username" required>
                </div>
                <div class="form-group">
                    <label for="email">البريد الإلكتروني</label>
                    <input type="email" class="form-control" id="email" name="email" required>
                </div>
                <div class="form-group">
                    <label for="password">كلمة المرور</label>
                    <input type="password" class="form-control" id="password" name="password" required>
                </div>
                 <div class="form-group">
                    <label for="country">الدولة</label>
                    <select class="form-control" name="country" id="country" required>
                        <option value="">اختر دولتك</option>
                    </select>
                </div>
                <div class="form-group">
                    <label for="gender">الجنس</label>
                    <select class="form-control" id="gender" name="gender" required>
                        <option value="male">ذكر</option>
                        <option value="female">أنثى</option>
                        <option value="other">آخر</option>
                    </select>
                </div>
                <div class="form-group">
                    <label for="phone">رقم الهاتف</label>
                    <input type="text" class="form-control" id="phone" name="phone" required>
                </div>
                <div class="form-group">
                    <label for="first_name">الاسم الأول</label>
                    <input type="text" class="form-control" id="first_name" name="first_name" required>
                </div>
                <div class="form-group">
                    <label for="last_name">الاسم الأخير</label>
                    <input type="text" class="form-control" id="last_name" name="last_name" required>
                </div>
                <div class="form-group">
                    <label for="role">الدور</label>
                    <select class="form-control" id="role" name="role" required>
                        <option value="client">عميل</option>
                        <option value="admin">مسؤول</option>
                        <option value="employee">موظف</option>
                    </select>
                </div>
                <div class="form-group">
                    <label for="balance">الرصيد</label>
                    <input type="number" class="form-control" id="balance" name="balance" required>
                </div>
                <div class="form-group">
                    <label for="company_name">اسم الشركة</label>
                    <input type="text" class="form-control" id="company_name" name="company_name" required>
                </div>
                <button type="submit" name="add_user" class="btn btn-primary btn-block">إضافة</button>
            </form>
        </div>
    </div>
<script>
        document.addEventListener('DOMContentLoaded', function() {
            const countrySelect = document.getElementById('country');

            // Fetch the list of countries from the API
            fetch('https://restcountries.com/v3.1/all?fields=translations')
                .then(response => response.json())
                .then(data => {
                    data.sort((a, b) => a.translations.ara.common.localeCompare(b.translations.ara.common)); // Sort countries alphabetically in Arabic
                    data.forEach(country => {
                        const option = document.createElement('option');
                        option.value = country.translations.ara.common;
                        option.textContent = country.translations.ara.common;
                        countrySelect.appendChild(option);
                    });
                })
                .catch(error => {
                    console.error('Error fetching countries:', error);
                    countrySelect.innerHTML = '<option value="">فشل في تحميل الدول</option>';
                });
        });
    </script>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
