<?php
include('../config.php');
include('includes/auth.php'); // Ensure admin authentication

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die('Invalid Ticket ID');
}

$ticket_id = (int)$_GET['id'];

// Fetch ticket details
$query = "SELECT * FROM tickets WHERE id = :ticket_id";
$stmt = $pdo->prepare($query);
$stmt->execute([':ticket_id' => $ticket_id]);
$ticket = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$ticket) {
    die('Ticket not found');
}

// Fetch messages for the ticket
$query = "SELECT ticket_messages.*, users.username FROM ticket_messages
          JOIN users ON ticket_messages.user_id = users.id
          WHERE ticket_id = :ticket_id
          ORDER BY created_at ASC";
$stmt = $pdo->prepare($query);
$stmt->execute([':ticket_id' => $ticket_id]);
$messages = $stmt->fetchAll(PDO::FETCH_ASSOC);

$stmt = $pdo->prepare("SELECT username FROM users WHERE id = ?");
$stmt->execute([$ticket['user_id']]);
$user = $stmt->fetch();
$username = $user['username'] ?? '';
?>
<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تفاصيل التذكرة</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .container {
            padding: 10px;
        }
        body, html {
            font-family: 'Cairo', sans-serif;
            background-color: #f9f9f9;
            margin: 0;
            padding: 0;
            min-height: 100vh;
            display: flex;
            flex-direction: column;
        }

        .ticket-details {
            background-color: #f1f1f1;
            padding: 15px;
            border-radius: 10px;
            margin-bottom: 10px;
            display: none;
        }

        .ticket-details h4 {
            margin: 0;
        }

        .ticket-status {
            font-weight: bold;
            padding: 8px 12px;
            border-radius: 5px;
        }

        .ticket-status.open {
            background-color: #28a745;
            color: #fff;
        }

        .ticket-status.closed {
            background-color: #dc3545;
            color: #fff;
        }

        .messages {
            flex-grow: 1;
            overflow-y: auto;
            max-height: 400px;
            margin-bottom: 20px;
            padding: 10px;
            border-radius: 10px;
            background-color: #ffffff;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }

        .message {
            padding: 10px 15px;
            margin-bottom: 10px;
            border-radius: 10px;
            background-color: #e9ecef;
            max-width: 70%;
            word-wrap: break-word;
            position: relative;
        }

        .message.client {
            background-color: #d4f1f4;
            margin-left: auto;
        }

        .message.admin {
            background-color: #f8d7da;
        }

        .message .info {
            font-size: 0.8rem;
            color: #555;
            margin-bottom: 5px;
        }

        .message img {
            max-width: 150px;
            height: auto;
            margin-top: 10px;
            border-radius: 5px;
        }

        #message-form {
            margin-top: 20px;
        }

        textarea.form-control {
            resize: none;
            border-radius: 10px;
        }

        button[type="submit"] {
            border-radius: 10px;
            width: 100%;
        }

        form.disabled textarea,
        form.disabled input,
        form.disabled button {
            background-color: #f1f1f1;
            pointer-events: none;
        }

        .disabled button {
            cursor: not-allowed;
        }

        .toggle-details {
            margin-bottom: 15px;
            cursor: pointer;
            color: #007bff;
        }

        .toggle-details:hover {
            text-decoration: underline;
        }

        /* Media Queries */
        @media (max-width: 768px) {
            .container {
                padding: 15px;
            }

            .messages {
                max-height: 300px;
            }

            .message {
                max-width: 100%;
            }
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <div class="page-header">
            <h2>تفاصيل التذكرة - <?php echo htmlspecialchars($ticket['subject']); ?></h2>
        </div>
        <div class="toggle-details">
            <i class="fas fa-info-circle"></i> عرض/إخفاء التفاصيل
        </div>
        <div class="ticket-details">
            <h4>الوصف:</h4>
            <p><?php echo htmlspecialchars($ticket['description']); ?></p>
            <h4>الحالة:</h4>
            <p class="ticket-status <?php echo ($ticket['status'] == 'Closed') ? 'closed' : 'open'; ?>">
                <?php echo htmlspecialchars($ticket['status']); ?>
            </p>
            <h4>الأولوية:</h4>
            <p><?php echo htmlspecialchars($ticket['priority']); ?></p>
            <h4>الفئة:</h4>
            <p><?php echo htmlspecialchars($ticket['category']); ?></p>
        </div>

        <div class="messages" id="messages">
            <?php foreach ($messages as $message): ?>
                <div class="message <?php echo ($message['user_id'] == $_SESSION['user_id']) ? 'client' : 'admin'; ?>">
                    <div class="info">
                        <strong><?php echo htmlspecialchars($message['username']); ?></strong> - <?php echo htmlspecialchars($message['created_at']); ?>
                    </div>
                    <p><?php echo htmlspecialchars($message['message']); ?></p>
                    <?php if ($message['image']): ?>
                        <img src="<?php echo htmlspecialchars($message['image']); ?>" alt="Image">
                    <?php endif; ?>
                </div>
            <?php endforeach; ?>
        </div>

        <form action="send_message.php" method="POST" enctype="multipart/form-data" id="message-form" <?php echo ($ticket['status'] === 'Closed') ? 'class="disabled"' : ''; ?>>
            <input type="hidden" name="ticket_id" value="<?php echo htmlspecialchars($ticket_id); ?>">
            <textarea name="message" class="form-control" rows="3" placeholder="أضف رسالة" <?php echo ($ticket['status'] === 'Closed') ? 'disabled' : ''; ?>></textarea>
            <input type="file" name="image" class="form-control mt-2" <?php echo ($ticket['status'] === 'Closed') ? 'disabled' : ''; ?>>
            <button type="submit" class="btn btn-primary mt-2" <?php echo ($ticket['status'] === 'Closed') ? 'disabled' : ''; ?>>إرسال</button>
        </form>

        <form action="close_ticket.php" method="POST" class="mt-2">
            <input type="hidden" name="ticket_id" value="<?php echo htmlspecialchars($ticket_id); ?>">
            <button type="submit" class="btn btn-danger" <?php echo ($ticket['status'] === 'Closed') ? 'disabled' : ''; ?>>إغلاق التذكرة</button>
        </form>
    </div>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script>
        $(document).ready(function() {
            $('.toggle-details').click(function() {
                $('.ticket-details').toggle();
            });
        });
    </script>
</body>
</html>
