<?php
include('../config.php');
include('includes/auth.php');

// Handle filtering based on priority, category, and status (default to open tickets)
$filters = [':status' => 'Open'];
$filterQuery = " AND t.status = :status";

if (isset($_GET['status']) && in_array($_GET['status'], ['Open', 'Closed'])) {
    $filters[':status'] = $_GET['status'];
}

if (isset($_GET['priority']) && in_array($_GET['priority'], ['Low', 'Medium', 'High', 'Urgent'])) {
    $filters[':priority'] = $_GET['priority'];
    $filterQuery .= " AND t.priority = :priority";
}

if (isset($_GET['category']) && in_array($_GET['category'], ['Technical', 'Financial', 'General'])) {
    $filters[':category'] = $_GET['category'];
    $filterQuery .= " AND t.category = :category";
}

// Fetch all tickets with filters applied and join with users to get usernames
$query = "
    SELECT t.id, t.subject, t.description, t.status, t.priority, t.category, t.created_at, u.username, u.id AS user_id 
    FROM tickets t
    JOIN users u ON t.user_id = u.id
    WHERE 1=1 $filterQuery
";
$stmt = $pdo->prepare($query);
$stmt->execute($filters);
$tickets = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة التذاكر</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        
        
        .page-header {
            text-align: center;
            margin-bottom: 40px;
        }

        .card {
            border: none;
            border-radius: 10px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.1);
            transition: transform 0.3s ease;
        }

        .card:hover {
            transform: translateY(-5px);
            box-shadow: 0 4px 15px rgba(0, 0, 0, 0.2);
        }

        .card h5 {
            font-size: 1.2rem;
            margin-bottom: 10px;
            font-weight: bold;
        }

        .card p {
            font-size: 0.9rem;
            color: #555;
            margin-bottom: 5px;
        }

        .card .btn {
            margin-top: 10px;
            font-size: 0.9rem;
            border-radius: 5px;
            padding: 10px 15px;
        }

        .btn-primary {
            background-color: #3498db;
            border: none;
        }

        .btn-primary:hover {
            background-color: #2980b9;
        }

        .btn-danger {
            background-color: #e74c3c;
            border: none;
        }

        .btn-danger:hover {
            background-color: #c0392b;
        }

        .form-row {
            margin-bottom: 20px;
        }

        .form-control {
            border-radius: 30px;
            font-size: 0.9rem;
            padding: 3px;
        }

        @media (max-width: 768px) {
            .card {
                margin-bottom: 20px;
            }

            .form-row {
                display: block;
            }

            .form-control {
                margin-bottom: 10px;
            }
        }
    </style>
</head>
<body>
     <nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">

                
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>

                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>

                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>

                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>

                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>

                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>

                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>

                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>

            <!-- Profile Menu -->
           
        </div>
    </div>
</nav>
    
    <div class="container mt-4">
        <div class="page-header">
            <h2>إدارة التذاكر</h2>
        </div>
        <form method="GET" class="mb-4">
            <div class="form-row">
                <div class="col">
                    <select name="status" class="form-control">
                        <option value="Open" <?php echo isset($_GET['status']) && $_GET['status'] === 'Open' ? 'selected' : ''; ?>>مفتوح</option>
                        <option value="Closed" <?php echo isset($_GET['status']) && $_GET['status'] === 'Closed' ? 'selected' : ''; ?>>مغلق</option>
                    </select>
                </div>
                <div class="col">
                    <select name="priority" class="form-control">
                        <option value="">كل الأولويات</option>
                        <option value="Low">منخفضة</option>
                        <option value="Medium">متوسطة</option>
                        <option value="High">عالية</option>
                        <option value="Urgent">عاجلة</option>
                    </select>
                </div>
                <div class="col">
                    <select name="category" class="form-control">
                        <option value="">كل الفئات</option>
                        <option value="Technical">تقني</option>
                        <option value="Financial">مالي</option>
                        <option value="General">عام</option>
                    </select>
                </div>
                <div class="col">
                    <button type="submit" class="btn btn-primary">تطبيق الفلاتر</button>
                </div>
            </div>
        </form>
        
        <div class="row">
            <?php if (empty($tickets)): ?>
                <p class="text-center">لا توجد تذاكر متاحة.</p>
            <?php else: ?>
                <?php foreach ($tickets as $ticket): ?>
                    <div class="col-md-6 col-lg-4 mb-4">
                        <div class="card h-100">
                            <div class="card-body">
                                <h5 class="card-title"><?php echo htmlspecialchars($ticket['subject'], ENT_QUOTES, 'UTF-8'); ?></h5>
                                <p class="card-text"><?php echo htmlspecialchars(substr($ticket['description'], 0, 100), ENT_QUOTES, 'UTF-8'); ?>...</p>
                                <p class="card-text"><strong>الحالة:</strong> <?php echo htmlspecialchars($ticket['status'], ENT_QUOTES, 'UTF-8'); ?></p>
                                <p class="card-text"><strong>الأولوية:</strong> <?php echo htmlspecialchars($ticket['priority'], ENT_QUOTES, 'UTF-8'); ?></p>
                                <p class="card-text"><strong>الفئة:</strong> <?php echo htmlspecialchars($ticket['category'], ENT_QUOTES, 'UTF-8'); ?></p>
                                <p class="card-text"><strong>اسم المستخدم:</strong> 
                                    <a href="manage_client.php?user_id=<?php echo htmlspecialchars($ticket['user_id'], ENT_QUOTES, 'UTF-8'); ?>">
                                        <?php echo htmlspecialchars($ticket['username'], ENT_QUOTES, 'UTF-8'); ?>
                                    </a>
                                </p>
                                <p class="card-text"><strong>تاريخ الإنشاء:</strong> <?php echo htmlspecialchars($ticket['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                                <a href="admin_ticket.php?id=<?php echo htmlspecialchars($ticket['id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-primary">عرض</a>
                                <form action="close_ticket.php" method="POST" class="mt-2">
                                    <input type="hidden" name="ticket_id" value="<?php echo htmlspecialchars($ticket['id'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <button type="submit" class="btn btn-danger <?php echo ($ticket['status'] === 'Closed') ? 'disabled' : ''; ?>" <?php echo ($ticket['status'] === 'Closed') ? 'disabled' : ''; ?>>إغلاق</button>
                                </form>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>
    <?php include 'footer.php'; ?>
        
        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>


</html>
