<?php
include('../config.php');
include('includes/auth.php');

$errors = [];

if (!isset($_GET['id'])) {
    header('Location: manage_domains.php');
    exit;
}

$id = $_GET['id'];

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $after_domain = $_POST['after_domain'];
    $registration_price = $_POST['registration_price'];
    $renewal_price = $_POST['renewal_price'];
    $transfer_price = $_POST['transfer_price'];
    $min_registration_price = $_POST['min_registration_price'];
    $min_renewal_price = $_POST['min_renewal_price'];
    $min_transfer_price = $_POST['min_transfer_price'];

    // Validation
    if ($min_registration_price > $registration_price) {
        $errors[] = "سعر التسجيل يجب أن يكون أكبر من أو يساوي أقل سعر للتسجيل.";
    }
    if ($min_renewal_price > $renewal_price) {
        $errors[] = "سعر التجديد يجب أن يكون أكبر من أو يساوي أقل سعر للتجديد.";
    }
    if ($min_transfer_price > $transfer_price) {
        $errors[] = "سعر النقل يجب أن يكون أكبر من أو يساوي أقل سعر للنقل.";
    }

    if (empty($errors)) {
        $query = "
            UPDATE domain_prices
            SET after_domain = ?, registration_price = ?, renewal_price = ?, transfer_price = ?, min_registration_price = ?, min_renewal_price = ?, min_transfer_price = ?
            WHERE id = ?";
        $stmt = $pdo->prepare($query);
        $stmt->execute([$after_domain, $registration_price, $renewal_price, $transfer_price, $min_registration_price, $min_renewal_price, $min_transfer_price, $id]);

        header('Location: manage_domains.php');
        exit;
    }
}

$query = "SELECT * FROM domain_prices WHERE id = ?";
$stmt = $pdo->prepare($query);
$stmt->execute([$id]);
$domainPrice = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$domainPrice) {
    header('Location: manage_domains.php');
    exit;
}
?>
<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تعديل سعر النطاق</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .form-container {
            margin-top: 50px;
        }
        .error-message {
            color: #e74c3c;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container form-container">
        <div class="page-header">
            <h2>تعديل سعر النطاق</h2>
        </div>
        <?php if (!empty($errors)): ?>
            <div class="alert alert-danger">
                <ul>
                    <?php foreach ($errors as $error): ?>
                        <li><?php echo htmlspecialchars($error, ENT_QUOTES, 'UTF-8'); ?></li>
                    <?php endforeach; ?>
                </ul>
            </div>
        <?php endif; ?>
        <form method="POST">
            <div class="form-group">
                <label for="after_domain">اسم النطاق</label>
                <input type="text" name="after_domain" id="after_domain" class="form-control" value="<?php echo htmlspecialchars($domainPrice['after_domain'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="registration_price">سعر التسجيل</label>
                <input type="text" name="registration_price" id="registration_price" class="form-control" value="<?php echo htmlspecialchars($domainPrice['registration_price'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="renewal_price">سعر التجديد</label>
                <input type="text" name="renewal_price" id="renewal_price" class="form-control" value="<?php echo htmlspecialchars($domainPrice['renewal_price'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="transfer_price">سعر النقل</label>
                <input type="text" name="transfer_price" id="transfer_price" class="form-control" value="<?php echo htmlspecialchars($domainPrice['transfer_price'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="min_registration_price">أقل سعر للتسجيل</label>
                <input type="text" name="min_registration_price" id="min_registration_price" class="form-control" value="<?php echo htmlspecialchars($domainPrice['min_registration_price'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="min_renewal_price">أقل سعر للتجديد</label>
                <input type="text" name="min_renewal_price" id="min_renewal_price" class="form-control" value="<?php echo htmlspecialchars($domainPrice['min_renewal_price'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="min_transfer_price">أقل سعر للنقل</label>
                <input type="text" name="min_transfer_price" id="min_transfer_price" class="form-control" value="<?php echo htmlspecialchars($domainPrice['min_transfer_price'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <button type="submit" class="btn btn-primary">تحديث</button>
        </form>
    </div>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>
</body>
</html>
