<?php
session_start();
include('../config.php');
include('includes/auth.php');

// Get the server ID from the query string
$serverId = isset($_GET['server_id']) ? $_GET['server_id'] : null;
$packageName = isset($_GET['name']) ? $_GET['name'] : '';

if (!$serverId || !$packageName) {
    die("Server ID and package name are required.");
}

// Fetch WHM credentials for the specific server
function getWhmCredentials($pdo, $serverId) {
    $query = "SELECT * FROM servers WHERE id = ?";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$serverId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

// Function to make API requests
function makeWhmApiRequest($url, $whmUsername, $whmApiToken) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
        "Authorization: whm $whmUsername:$whmApiToken"
    ));
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'cURL Error: ' . curl_error($ch);
        curl_close($ch);
        exit();
    }
    curl_close($ch);
    return json_decode($response, true);
}

// Fetch credentials for the selected server
$credentials = getWhmCredentials($pdo, $serverId);
$whmUsername = $credentials['whm_username'] ?? '';
$whmApiToken = $credentials['whm_api_token'] ?? '';
$whmHost = $credentials['whm_host'] ?? '';

// WHM API URL to get package details
$url = "https://$whmHost:2087/json-api/listpkgs?api.version=1";

// Fetch hosting packages
$result = makeWhmApiRequest($url, $whmUsername, $whmApiToken);

// Check if API call was successful
if (isset($result['metadata']['result']) && $result['metadata']['result'] == 1) {
    $packages = isset($result['data']['pkg']) ? $result['data']['pkg'] : [];
    $package = null;

    foreach ($packages as $pkg) {
        if (trim($pkg['name']) === $packageName) {
            $package = $pkg;
            break;
        }
    }

    if (!$package) {
        die("Package not found.");
    }
} else {
    die("API Error: " . htmlspecialchars($result['metadata']['reason'], ENT_QUOTES, 'UTF-8'));
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Edit Hosting Plan</title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .form-control[readonly] {
            background-color: #f9f9f9;
        }
        .form-control.unlimited {
            color: green;
            font-weight: bold;
        }
    </style>
</head>
<body>
    <nav>
        <?php include 'nav2.php'; ?>
    </nav>
    <div class="container mt-4">
        <div class="page-header">
            <h2>Edit Hosting Plan</h2>
        </div>
        <form action="update_hosting_plan.php" method="post">
            <input type="hidden" name="server_id" value="<?php echo htmlspecialchars($serverId, ENT_QUOTES, 'UTF-8'); ?>">
            <input type="hidden" name="name" value="<?php echo htmlspecialchars($package['name'], ENT_QUOTES, 'UTF-8'); ?>">

            <!-- Plan Name -->
            <div class="form-group">
                <label for="name">Plan Name</label>
                <input type="text" id="name" name="name" class="form-control" value="<?php echo htmlspecialchars($package['name'], ENT_QUOTES, 'UTF-8'); ?>" readonly>
            </div>

            <!-- Disk Quota -->
            <div class="form-group">
                <label for="disk">Disk Quota</label>
                <div class="input-group">
                    <input type="text" id="disk" name="disk" class="form-control <?php echo $package['QUOTA'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['QUOTA'] == 'unlimited' ? 'unlimited' : $package['QUOTA'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('disk')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Bandwidth -->
            <div class="form-group">
                <label for="bandwidth">Bandwidth</label>
                <div class="input-group">
                    <input type="text" id="bandwidth" name="bandwidth" class="form-control <?php echo $package['BWLIMIT'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['BWLIMIT'] == 'unlimited' ? 'unlimited' : $package['BWLIMIT'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('bandwidth')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Max Addon Domains -->
            <div class="form-group">
                <label for="maxaddondomains">Max Addon Domains</label>
                <div class="input-group">
                    <input type="text" id="maxaddondomains" name="maxaddondomains" class="form-control <?php echo $package['MAXADDON'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['MAXADDON'] == 'unlimited' ? 'unlimited' : $package['MAXADDON'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxaddondomains')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Max FTP Accounts -->
            <div class="form-group">
                <label for="maxftp">Max FTP Accounts</label>
                <div class="input-group">
                    <input type="text" id="maxftp" name="maxftp" class="form-control <?php echo $package['MAXFTP'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['MAXFTP'] == 'unlimited' ? 'unlimited' : $package['MAXFTP'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxftp')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Max SQL Databases -->
            <div class="form-group">
                <label for="maxsql">Max SQL Databases</label>
                <div class="input-group">
                    <input type="text" id="maxsql" name="maxsql" class="form-control <?php echo $package['MAXSQL'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['MAXSQL'] == 'unlimited' ? 'unlimited' : $package['MAXSQL'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxsql')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Max Email Accounts -->
            <div class="form-group">
                <label for="maxemail">Max Email Accounts</label>
                <div class="input-group">
                    <input type="text" id="maxemail" name="maxemail" class="form-control <?php echo $package['MAX_EMAILACCT_QUOTA'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['MAX_EMAILACCT_QUOTA'] == 'unlimited' ? 'unlimited' : $package['MAX_EMAILACCT_QUOTA'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxemail')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Max Subdomains -->
            <div class="form-group">
                <label for="maxsubdomain">Max Subdomains</label>
                <div class="input-group">
                    <input type="text" id="maxsubdomain" name="maxsubdomain" class="form-control <?php echo $package['MAXSUB'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['MAXSUB'] == 'unlimited' ? 'unlimited' : $package['MAXSUB'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxsubdomain')">Unlimited</button>
                    </div>
                </div>
            </div>

            <!-- Max Parked Domains -->
            <div class="form-group">
                <label for="maxparked">Max Parked Domains</label>
                <div class="input-group">
                    <input type="text" id="maxparked" name="maxparked" class="form-control <?php echo $package['MAXPARK'] == 'unlimited' ? 'unlimited' : ''; ?>" value="<?php echo htmlspecialchars($package['MAXPARK'] == 'unlimited' ? 'unlimited' : $package['MAXPARK'], ENT_QUOTES, 'UTF-8'); ?>">
                    <div class="input-group-append">
                        <button type="button" class="btn btn-outline-secondary" onclick="setUnlimited('maxparked')">Unlimited</button>
                    </div>
                </div>
            </div>

            <button type="submit" class="btn btn-warning">Update Plan</button>
        </form>
    </div>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>

    <script>
        function setUnlimited(fieldId) {
            var field = document.getElementById(fieldId);
            field.value = 'unlimited';
            field.classList.add('unlimited');
        }
    </script>
</body>
</html>
