<?php
session_start();
include('../config.php');
include('includes/auth.php');

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $id = $_POST['id'];
    $name = $_POST['name'];
    $whmUsername = $_POST['whm_username'];
    $whmApiToken = $_POST['whm_api_token'];
    $whmHost = $_POST['whm_host'];
    $enabled = isset($_POST['enabled']) ? 1 : 0;

    // Update server credentials
    $query = "UPDATE servers SET name = ?, whm_username = ?, whm_api_token = ?, whm_host = ?, enabled = ? WHERE id = ?";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$name, $whmUsername, $whmApiToken, $whmHost, $enabled, $id]);

    echo "<div class='alert alert-success'>تم تحديث الخادم بنجاح.</div>";
}

// Fetch server details
$serverId = $_GET['id'];
$query = "SELECT * FROM servers WHERE id = ?";
$stmt = $pdo->prepare($query);
$stmt->execute([$serverId]);
$server = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$server) {
    die("الخادم غير موجود.");
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>تعديل الخادم</title>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .btn-custom { font-size: 16px; } /* Adjust button size */
        .form-control { border-radius: 0.25rem; }
        .alert-success { margin-top: 10px; }
    </style>
</head>
<body>
    <nav>
        <?php include 'nav2.php'; ?>
    </nav>
    <div class="container mt-4">
        <div class="page-header">
            <h2>تعديل الخادم</h2>
        </div>
        <form method="post" action="">
            <input type="hidden" name="id" value="<?php echo htmlspecialchars($server['id'], ENT_QUOTES, 'UTF-8'); ?>">
            <div class="form-group">
                <label for="name">اسم الخادم</label>
                <input type="text" class="form-control" id="name" name="name" value="<?php echo htmlspecialchars($server['name'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="whm_username">اسم مستخدم WHM</label>
                <input type="text" class="form-control" id="whm_username" name="whm_username" value="<?php echo htmlspecialchars($server['whm_username'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="whm_api_token">رمز API لـ WHM</label>
                <input type="text" class="form-control" id="whm_api_token" name="whm_api_token" value="<?php echo htmlspecialchars($server['whm_api_token'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group">
                <label for="whm_host">مضيف WHM</label>
                <input type="text" class="form-control" id="whm_host" name="whm_host" value="<?php echo htmlspecialchars($server['whm_host'], ENT_QUOTES, 'UTF-8'); ?>" required>
            </div>
            <div class="form-group form-check">
                <input type="checkbox" class="form-check-input" id="enabled" name="enabled" <?php echo $server['enabled'] ? 'checked' : ''; ?>>
                <label class="form-check-label" for="enabled">تمكين</label>
            </div>
            <button type="submit" class="btn btn-primary btn-custom">تحديث الخادم</button>
        </form>
    </div>

    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.9.3/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
