<?php
// admin/invoices.php
include('../config.php');
session_start();
include('includes/auth.php');

// Fetch invoices
$stmt = $pdo->query("
    SELECT i.id, i.total_price, i.created_at, i.status, u.username
    FROM orders i
    JOIN users u ON i.user_id = u.id
");
$invoices = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Fetch products to map product_id to product_name
$productStmt = $pdo->query("SELECT id, name FROM products");
$products = $productStmt->fetchAll(PDO::FETCH_KEY_PAIR);

// Define translations and colors
$statusTranslations = [
    'paid' => 'مدفوع',
    'unpaid' => 'غير مدفوع'
];

$statusColors = [
    'paid' => 'green',
    'unpaid' => 'red'
];

// Fetch order details and determine billing cycle
$billingCycles = [];
$orderDetailsStmt = $pdo->query("
    SELECT od.order_id, od.product_id, od.price, p.price_monthly, p.price_yearly
    FROM order_details od
    JOIN products p ON od.product_id = p.id
");
while ($row = $orderDetailsStmt->fetch(PDO::FETCH_ASSOC)) {
    $billingCycle = '';
    if ($row['price'] == $row['price_monthly']) {
        $billingCycle = 'شهري';
    } elseif ($row['price'] == $row['price_yearly']) {
        $billingCycle = 'سنوي';
    }
    else
    {
        $billingCycle = 'دفعة واحدة/سنوي';
    }
    $billingCycles[$row['order_id']] = $billingCycle;
}
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة الفواتير</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .status-paid {
            color: green !important;
        }
        .status-unpaid {
            color: red !important;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg">
        <div class="container">
            <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
                <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
                <span>لوحة التحكم</span>
            </a>
            <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
                <span class="navbar-toggler-icon"></span>
            </button>
            <div class="collapse navbar-collapse" id="navbarNav">
                <ul class="navbar-nav mx-auto">
                    <!-- "جديد +" dropdown -->
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                        <ul class="dropdown-menu" aria-labelledby="newDropdown">
                            <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                            <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                            <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                            <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                            <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                            <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                        </ul>
                    </li>
                    <!-- "العملاء" dropdown -->
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                        <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                            <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                            <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                            <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                        </ul>
                    </li>
                    <!-- "الفواتير" link -->
                    <li class="nav-item">
                        <a class="nav-link" href="invoices.php">الفواتير</a>
                    </li>
                    <!-- "المنتجات" dropdown -->
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                        <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                            <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                            <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                            <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                            <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                        </ul>
                    </li>
                    <!-- "الدعم" dropdown -->
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                        <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                            <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                            <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                            <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                        </ul>
                    </li>
                    <!-- "الأعدادات" dropdown -->
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                        <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                            <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                            <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                            <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                            <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                            <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                            <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                        </ul>
                    </li>
                    <!-- "النشاطات" dropdown -->
                    <li class="nav-item dropdown">
                        <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                        <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                            <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                            <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                            <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                            <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                        </ul>
                    </li>
                    <!-- Logout button -->
                    <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
                </ul>
            </div>
        </div>
    </nav>

        <div class="container mt-4">
        <div class="page-header">
            <h2>إدارة الفواتير</h2>
        </div>
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>الرقم التسلسلي</th>
                        <th>المستخدم</th>
                        <th>المبلغ</th>
                        <th>الحالة</th>
                        <th>تاريخ الإنشاء</th>
                        <th>دورة الفوترة</th>
                        <th>التفاصيل</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($invoices as $invoice): ?>
                        <?php 
                        // Get the billing cycle for this invoice
                        $billingCycle = isset($billingCycles[$invoice['id']]) ? $billingCycles[$invoice['id']] : 'غير محدد';
                        ?>
                        <tr>
                            <td><?php echo htmlspecialchars($invoice['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($invoice['username'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($invoice['total_price'], ENT_QUOTES, 'UTF-8'); ?> $</td>
                            <td class="<?php echo 'status-' . $invoice['status'];?>">
                                <?php echo htmlspecialchars($statusTranslations[$invoice['status']], ENT_QUOTES, 'UTF-8'); ?>
                            </td>
                            <td><?php echo htmlspecialchars($invoice['created_at'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($billingCycle, ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>
                                <button class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#orderDetailsModal" data-id="<?php echo $invoice['id']; ?>">عرض التفاصيل</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Order Details Modal -->
    <div class="modal fade" id="orderDetailsModal" tabindex="-1" aria-labelledby="orderDetailsModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="orderDetailsModalLabel">تفاصيل الطلب</h5>
                        <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">&times;</button>
                </div>
                <div class="modal-body">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>الرقم التسلسلي</th>
                                <th>المنتج</th>
                                <th>الكمية</th>
                                <th>السعر</th>
                            </tr>
                        </thead>
                        <tbody id="orderDetailsBody">
                            <!-- Order details will be populated via JS -->
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
    </div>
    <?php include 'footer.php'; ?>

    <!-- jQuery and Bootstrap Scripts -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        document.getElementById('orderDetailsModal').addEventListener('show.bs.modal', function (event) {
            var button = event.relatedTarget;
            var orderId = button.getAttribute('data-id');
            var modal = this;
            var orderDetailsBody = document.getElementById('orderDetailsBody');

            // Clear previous data
            orderDetailsBody.innerHTML = '';

            // Fetch order details
            $.ajax({
                url: 'fetch_order_details.php',
                method: 'POST',
                data: { order_id: orderId },
                dataType: 'json',
                success: function(response) {
                    if (response.length > 0) {
                        response.forEach(function(detail) {
                            var productName = <?php echo json_encode($products); ?>[detail.product_id];
                            orderDetailsBody.insertAdjacentHTML('beforeend', `
                                <tr>
                                    <td>${detail.id}</td>
                                    <td>${productName}</td>
                                    <td>${detail.quantity}</td>
                                    <td>${detail.price} $</td>
                                </tr>
                            `);
                        });
                    } else {
                        orderDetailsBody.insertAdjacentHTML('beforeend', '<tr><td colspan="4">لا توجد تفاصيل للطلب.</td></tr>');
                    }
                }
            });
        });
    </script>
</body>
</html>
