<?php
include('../config.php');
include('includes/auth.php');

// Fetch all client login history from the database
$query = "SELECT clh.*, u.username FROM login_history clh JOIN users u ON clh.user_id = u.id";
$stmt = $pdo->prepare($query);
$stmt->execute();
$login_history = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Function to fetch user details by ID
function fetchUserDetails($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT u.*, c.name AS company_name
                           FROM users u
                           LEFT JOIN companies c ON u.company_id = c.id
                           WHERE u.id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

// Function to fetch user products by user ID
function fetchUserProducts($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT * FROM user_products WHERE user_id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Function to fetch user orders and associated products by user ID
function fetchUserOrders($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT o.*, od.product_id, p.name FROM orders o 
                           JOIN order_details od ON o.id = od.order_id 
                           JOIN products p ON od.product_id = p.id
                           WHERE o.user_id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>سجل تسجيل الدخول للعملاء</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
        <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        
        .table-container {
            margin-top: 20px;
        }
        .page-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
        }

    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>
                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>
                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>
                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>
                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>
                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>
                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>
                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>
        </div>
    </div>
</nav>
    <div class="container mt-4">
        <div class="table-container">
            <div class="page-header">
                <h2>سجل تسجيل الدخول للعملاء</h2>
            </div>

            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>الرقم التعريفي</th>
                        <th>اسم العميل</th>
                        <th>عنوان IP</th>
                        <th>وقت تسجيل الدخول</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($login_history as $login): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($login['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>
                                <a href="#" data-bs-toggle="modal" data-bs-target="#userDetailsModal<?php echo $login['user_id']; ?>">
                                    <?php echo htmlspecialchars($login['username'], ENT_QUOTES, 'UTF-8'); ?>
                                </a>
                            </td>
                            <td><?php echo htmlspecialchars($login['ip_address'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($login['login_time'], ENT_QUOTES, 'UTF-8'); ?></td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Modals for user details -->
<?php foreach ($login_history as $login): 
    $userDetails = fetchUserDetails($pdo, $login['user_id']);
    $userProducts = fetchUserProducts($pdo, $login['user_id']);
    $userOrders = fetchUserOrders($pdo, $login['user_id']);
?>
    <div class="modal" id="userDetailsModal<?php echo $login['user_id']; ?>" tabindex="-1" aria-labelledby="userDetailsModalLabel<?php echo $login['user_id']; ?>" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <!-- Modal Header -->
                <div class="modal-header">
                    <h2 id="userDetailsModalLabel<?php echo $login['user_id']; ?>">تفاصيل العميل - <?php echo htmlspecialchars($login['username'], ENT_QUOTES, 'UTF-8'); ?></h2>
                    <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">&times;</button>
                </div>
                
                <!-- Modal Body -->
                <div class="modal-body">
                    <p><strong>البريد الإلكتروني:</strong> <?php echo htmlspecialchars($userDetails['email'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>الدور:</strong> <?php echo htmlspecialchars($userDetails['role'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>الرصيد:</strong> $<?php echo htmlspecialchars($userDetails['balance'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>تاريخ الإنشاء:</strong> <?php echo htmlspecialchars($userDetails['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>اسم الشركة:</strong> <?php echo htmlspecialchars($userDetails['company_name'], ENT_QUOTES, 'UTF-8'); ?></p>

                    <!-- User Orders -->
                    <h5>الطلبات</h5>
                    <ul>
                        <?php foreach ($userOrders as $order): ?>
                            <li>Order ID: <?php echo htmlspecialchars($order['id'], ENT_QUOTES, 'UTF-8'); ?> - Total: $<?php echo htmlspecialchars($order['total_price'], ENT_QUOTES, 'UTF-8'); ?>
                                <ul>
                                    <?php 
                                        $productNames = array_unique(array_column($userOrders, 'product_name', 'product_id'));
                                        foreach ($productNames as $productName): ?>
                                            <li>Product: <?php echo htmlspecialchars($productName, ENT_QUOTES, 'UTF-8'); ?></li>
                                    <?php endforeach; ?>
                                </ul>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                </div>

                <!-- Modal Footer -->
                <div class="modal-footer">
                    <a href="user_invoices.php?user_id=<?php echo htmlspecialchars($login['user_id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-primary">عرض الفواتير</a>
                    <a href="user_products.php?user_id=<?php echo htmlspecialchars($login['user_id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-primary">عرض المنتجات</a>
                </div>
            </div>
        </div>
    </div>
<?php endforeach; ?>

        <?php include 'footer.php'; ?>

<script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.11.8/dist/umd/popper.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script></body>
</html>
