<?php
include('../config.php'); // Database configuration
include('includes/auth.php'); // Authentication check
session_start();

// Function to fetch client details by ID
function fetchClientDetails($pdo, $clientId) {
    try {
        $stmt = $pdo->prepare("SELECT * FROM users WHERE id = ?");
        $stmt->execute([$clientId]);
        return $stmt->fetch(PDO::FETCH_ASSOC);
    } catch (Exception $e) {
        die("Error fetching client details: " . $e->getMessage());
    }
}
function fetchCPanelCredentials($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT username, password FROM user_accounts WHERE user_id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}
function generateAutoLoginToken($pdo, $clientId) {
    // Generate a secure token
    $autologinToken = bin2hex(random_bytes(16));

    // Store the token in the database
    $stmt = $pdo->prepare("UPDATE users SET autologin_token = ? WHERE id = ?");
    $result = $stmt->execute([$autologinToken, $clientId]);

    if ($result) {
        // Generate the auto-login URL
        $autologinLink = "https://one.hostgoal.net/client/login.php?token=" . urlencode($autologinToken);
        return $autologinLink;
    } else {
        // Log or display the error if the token wasn't stored
        error_log("Failed to store autologin token for client ID: " . $clientId);
        return false;
    }
}


if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['generate_autologin'])) {
    $clientId = $_POST['client_id'];

    if ($clientId) {
        // Generate the auto-login link
        $autologinLink = generateAutoLoginToken($pdo, $clientId);

        if ($autologinLink) {
            // Set the message to display the link
            $_SESSION['message'] = "Auto-login link: <a href='{$autologinLink}' target='_blank'>Login as client</a>";
        } else {
            $_SESSION['message'] = "Failed to generate auto-login link.";
        }

        // Redirect back to the client management page
        exit();
    } else {
        $_SESSION['message'] = "Client ID is missing.";
        header("Location: manage_client.php");
        exit();
    }
}

// Access cPanel using WHM API token
function accessCPanel($cpanelUsername, $cpanelPassword) {
    $whmUsername = 'hostgoal';
    $whmApiToken = 'U2M8FSQKEB4KFDLBOSW6T7MPTL4AUV85';

    // Generate cPanel SSO token URL
    $cpanelSsoUrl = "https://hostgoal.net:2087/json-api/create_user_session?api.version=1&user={$cpanelUsername}&service=cpaneld";

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $cpanelSsoUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: whm $whmUsername:$whmApiToken"
    ]);
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
        curl_close($ch);
        exit();
    }
    curl_close($ch);

    $ssoResult = json_decode($response, true);

    if ($ssoResult['metadata']['result'] == 1) {
        $ssoTokenUrl = $ssoResult['data']['url'];
        header("Location: $ssoTokenUrl");
        exit();
    } else {
        $_SESSION['error'] = 'Error creating SSO token: ' . $ssoResult['metadata']['reason'];
        header("Location: manage_client.php");
        exit();
    }
}
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['suspend_product'])) {
        $productId = $_POST['product_id'];
        updateProductStatus($pdo, $productId, 'suspended');
    } elseif (isset($_POST['activate_product'])) {
        $productId = $_POST['product_id'];
        updateProductStatus($pdo, $productId, 'active');
    }
}
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['access_cpanel'])) {
    $cpanelUsername = $_POST['cpanel_username'];
    $cpanelPassword = $_POST['cpanel_password'];
    accessCPanel($cpanelUsername, $cpanelPassword);
}
// Function to fetch orders and join with product and price details
function fetchClientOrders($pdo, $clientId) {
    try {
        $stmt = $pdo->prepare("
            SELECT orders.id AS order_id, order_details.product_id, orders.total_price, orders.status
            FROM orders
            JOIN order_details ON orders.id = order_details.order_id
            WHERE orders.user_id = ?
        ");
        $stmt->execute([$clientId]);
        $orders = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Get product names and periods
        foreach ($orders as &$order) {
            $productStmt = $pdo->prepare("
                SELECT products.name AS product_name, 
                       CASE
                           WHEN products.price_monthly = :price THEN 'شهري'
                           WHEN products.price_yearly = :price THEN 'سنوي'
                           ELSE 'غير محدد'
                       END AS period
                FROM products
                WHERE products.id = :product_id
            ");
            $productStmt->execute([
                ':price' => $order['total_price'],
                ':product_id' => $order['product_id']
            ]);
            $product = $productStmt->fetch(PDO::FETCH_ASSOC);
            $order['product_name'] = $product['product_name'];
            $order['period'] = $product['period'];
            // Translate status
            $order['status'] = $order['status'] == 'paid' ? 'مدفوع' : 'غير مدفوع';
        }
        return $orders;
    } catch (Exception $e) {
        die("Error fetching client orders: " . $e->getMessage());
    }
}

// Function to fetch tickets
function fetchClientTickets($pdo, $clientId) {
    try {
        $stmt = $pdo->prepare("
            SELECT id, subject, status, created_at
            FROM tickets
            WHERE user_id = ?
        ");
        $stmt->execute([$clientId]);
        $tickets = $stmt->fetchAll(PDO::FETCH_ASSOC);
        
        // Translate status
        foreach ($tickets as &$ticket) {
            $ticket['status'] = $ticket['status'] == 'open' ? 'مفتوح' : 'مغلق';
        }
        return $tickets;
    } catch (Exception $e) {
        die("Error fetching client tickets: " . $e->getMessage());
    }
}

function fetchClientLoginHistory($pdo, $clientId) {
    try {
        // Update query to filter by user_id
        $query = "SELECT clh.*, u.username 
                  FROM login_history clh 
                  JOIN users u ON clh.user_id = u.id 
                  WHERE clh.user_id = ?";
        $stmt = $pdo->prepare($query);
        $stmt->execute([$clientId]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (Exception $e) {
        die("Error fetching login history: " . $e->getMessage());
    }
}
function fetchClientProducts($pdo, $clientId) {
    try {
        $stmt = $pdo->prepare("
            SELECT products.id AS product_id, products.name AS product_name, 
                   products.price_monthly, products.price_yearly, products.product_type, 
                   user_accounts.status
            FROM products
            JOIN order_details ON products.id = order_details.product_id
            JOIN orders ON orders.id = order_details.order_id
            LEFT JOIN user_accounts ON products.id = user_accounts.product_id AND user_accounts.user_id = ?
            WHERE orders.user_id = ?
            GROUP BY products.id
        ");
        $stmt->execute([$clientId, $clientId]);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (Exception $e) {
        die("Error fetching client products: " . $e->getMessage());
    }
}


function updateProductStatus($pdo, $productId, $status) {
    try {
        $stmt = $pdo->prepare("UPDATE user_accounts SET status = ? WHERE product_id = ?");
        $stmt->execute([$status, $productId]);
    } catch (Exception $e) {
        die("Error updating product status: " . $e->getMessage());
    }
}
$clientId = filter_var($_GET['user_id'], FILTER_VALIDATE_INT);
if ($clientId === false) {
    die("Invalid client ID");
}


// Fetch client details, orders, tickets, and login history
$client = fetchClientDetails($pdo, $clientId);
$orders = fetchClientOrders($pdo, $clientId);
$tickets = fetchClientTickets($pdo, $clientId);
$loginHistory = fetchClientLoginHistory($pdo, $clientId);
$products = fetchClientProducts($pdo, $clientId);
$cpanelCredentials = fetchCPanelCredentials($pdo, $clientId);
?>

<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة العميل</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
            direction: rtl;
        }
        .nav-tabs .nav-item .nav-link {
            border-radius: 0;
        }
        .tab-content {
            margin-top: 20px;
        }
        .btn-edit, .btn-delete, .btn-view {
            margin-right: 5px;
        }
        .btn-edit {
            background-color: #3498db;
            color: white;
        }
        .btn-delete {
            background-color: #e74c3c;
            color: white;
        }
        .btn-view {
            background-color: #2ecc71;
            color: white;
        }
        .profile-img {
            border-radius: 50%;
        }
        .btn-login {
            background-color: #2ecc71;
            color: white;
        }
        .table th, .table td {
            text-align: center;
        }
        .nav-tabs .nav-item {
            margin-bottom: -1px;
        }
        .footer {
            background-color: #f8f9fa;
            padding: 20px;
            margin-top: 20px;
        }
        .footer-section {
            margin-bottom: 10px;
        }
        .footer-section h5 {
            margin-bottom: 10px;
            font-weight: 700;
        }
        .status-paid {
            color: #2ecc71; /* Green for paid */
        }
        .status-unpaid {
            color: #e74c3c; /* Red for unpaid */
        }
        .form-group {
            margin-bottom: 1rem;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <div class="page-header">
            <h2>إدارة العميل</h2>
        </div>

        <!-- Tab Navigation -->
        <ul class="nav nav-tabs" id="clientTabs" role="tablist">
            <li class="nav-item">
                <a class="nav-link active" id="profile-tab" data-toggle="tab" href="#profile" role="tab">الملف الشخصي</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="edit-tab" data-toggle="tab" href="#edit" role="tab">تحرير</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="orders-tab" data-toggle="tab" href="#orders" role="tab">الطلبات</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="invoices-tab" data-toggle="tab" href="#invoices" role="tab">الفواتير</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="tickets-tab" data-toggle="tab" href="#tickets" role="tab">التذاكر</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="products-tab" data-toggle="tab" href="#products" role="tab">المنتجات</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="logins-tab" data-toggle="tab" href="#logins" role="tab">تسجيلات الدخول</a>
            </li>
        </ul>

        <!-- Tab Content -->
        <div class="tab-content" id="clientTabsContent">
            <!-- Profile Tab -->
            <div class="tab-pane fade show active" id="profile" role="tabpanel">
                <h3>الملف الشخصي</h3>
                <p><strong>الاسم:</strong> <?php echo htmlspecialchars($client['username'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>رقم العميل:</strong> <?php echo htmlspecialchars($client['id'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>الصورة:</strong> <img src="<?php echo htmlspecialchars($client['picture'], ENT_QUOTES, 'UTF-8'); ?>" alt="الصورة الشخصية" width="100" class="profile-img"></p>
                <p><strong>البريد الإلكتروني:</strong> <?php echo htmlspecialchars($client['email'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>عنوان بروتوكول الانترنت:</strong> <?php echo htmlspecialchars($client['last_ip'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>الدولة:</strong> <?php echo htmlspecialchars($client['country'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>تاريخ الإنشاء:</strong> <?php echo htmlspecialchars($client['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>الرصيد:</strong> <?php echo htmlspecialchars($client['balance'], ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>الجنس:</strong> <?php echo htmlspecialchars($client['gender'] == 'male' ? 'ذكر' : 'أنثى', ENT_QUOTES, 'UTF-8'); ?></p>
                <p><strong>رقم الهاتف:</strong> <?php echo htmlspecialchars($client['phone'], ENT_QUOTES, 'UTF-8'); ?></p>
        <form method="post" action="">
    <input type="hidden" name="client_id" value="<?php echo htmlspecialchars($clientId, ENT_QUOTES, 'UTF-8'); ?>">
    <button type="submit" name="generate_autologin" class="btn btn-login">تسجيل الدخول إلى منطقة العميل</button>
</form>
           
        </div>
            
            <!-- Edit Tab -->
<div class="tab-pane fade" id="edit" role="tabpanel">
    <h3>تحرير بيانات العميل</h3>
    <form action="update_client.php" method="POST">
        <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($clientId, ENT_QUOTES, 'UTF-8'); ?>">
        <div class="form-group">
            <label for="username">الاسم</label>
            <input type="text" class="form-control" id="username" name="username" value="<?php echo htmlspecialchars($client['username'], ENT_QUOTES, 'UTF-8'); ?>" required>
        </div>
        <div class="form-group">
            <label for="email">البريد الإلكتروني</label>
            <input type="email" class="form-control" id="email" name="email" value="<?php echo htmlspecialchars($client['email'], ENT_QUOTES, 'UTF-8'); ?>" required>
        </div>
        <div class="form-group">
            <label for="phone">رقم الهاتف</label>
            <input type="text" class="form-control" id="phone" name="phone" value="<?php echo htmlspecialchars($client['phone'], ENT_QUOTES, 'UTF-8'); ?>">
        </div>
        <div class="form-group">
            <label for="country">الدولة</label>
            <select class="form-control" id="country" name="country">
                <option value="egypt" <?php echo $client['country'] == 'egypt' ? 'selected' : ''; ?>>مصر</option>
                <option value="ksa" <?php echo $client['country'] == 'ksa' ? 'selected' : ''; ?>>السعودية</option>
                <option value="uae" <?php echo $client['country'] == 'uae' ? 'selected' : ''; ?>>الإمارات</option>
                <!-- Add other country options here -->
            </select>
        </div>
        <div class="form-group">
            <label for="balance">الرصيد</label>
            <input type="text" class="form-control" id="balance" name="balance" value="<?php echo htmlspecialchars($client['balance'], ENT_QUOTES, 'UTF-8'); ?>">
        </div>
        <div class="form-group">
            <label for="gender">الجنس</label>
            <select class="form-control" id="gender" name="gender">
                <option value="male" <?php echo $client['gender'] == 'male' ? 'selected' : ''; ?>>ذكر</option>
                <option value="female" <?php echo $client['gender'] == 'female' ? 'selected' : ''; ?>>أنثى</option>
            </select>
        </div>
        <button type="submit" class="btn btn-edit">تحديث البيانات</button>
    </form>
</div>
<!-- Products Tab -->
<div class="tab-pane fade" id="products" role="tabpanel">
    <h3>المنتجات</h3>
    <div class="row">
        <?php foreach ($products as $product): ?>
            <div class="col-md-4 mb-4">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title"><?php echo htmlspecialchars($product['product_name'], ENT_QUOTES, 'UTF-8'); ?></h5>
                        <p class="card-text">
                            <form method="post" action="">
                                <input type="hidden" name="product_id" value="<?php echo htmlspecialchars($product['product_id'], ENT_QUOTES, 'UTF-8'); ?>">
                                <?php if ($product['product_type'] === 'hosting'): ?>
                                    <input type="hidden" name="cpanel_username" value="<?php echo htmlspecialchars($cpanelCredentials['username'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <input type="hidden" name="cpanel_password" value="<?php echo htmlspecialchars($cpanelCredentials['password'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <button type="submit" name="access_cpanel" class="btn btn-login">دخول إلى cPanel</button>
                                    <?php if ($product['status'] === 'active'): ?>
                                    <button type="submit" name="suspend_product" class="btn btn-danger">وقف المنتج مؤقتا</button>
                                <?php else: ?>
                                    <button type="submit" name="activate_product" class="btn btn-success">تفعيل المنتج مرة أخرى</button>
                                <?php endif; ?>
                            <?php else: ?>
                                <!-- Optionally add more information or buttons for non-hosting products -->
                            <?php endif; ?>
                                
                            </form>
                        </p>
                    </div>
                </div>
            </div>
        <?php endforeach; ?>
    </div>
</div>

            <div class="tab-pane fade" id="logins" role="tabpanel">
                <h3>تاريخ تسجيل الدخول</h3>
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>رقم تسجيل الدخول</th>
                                <th>اسم المستخدم</th>
                                <th>تاريخ ووقت تسجيل الدخول</th>
                                <th>عنوان بروتوكول الانترنت</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($loginHistory as $login): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($login['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($login['username'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($login['login_time'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($login['ip_address'], ENT_QUOTES, 'UTF-8'); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
            <!-- Orders Tab -->
            <div class="tab-pane fade" id="orders" role="tabpanel">
                <h3>الطلبات</h3>
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>رقم الطلب</th>
                                <th>المنتج</th>
                                <th>الفترة</th>
                                <th>السعر الإجمالي</th>
                                <th>الحالة</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($orders as $order): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($order['order_id'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($order['product_name'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($order['period'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($order['total_price'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td class="<?php echo $order['status'] == 'مدفوع' ? 'status-paid' : 'status-unpaid'; ?>">
                                        <?php echo htmlspecialchars($order['status'], ENT_QUOTES, 'UTF-8'); ?>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- Tickets Tab -->
            <div class="tab-pane fade" id="tickets" role="tabpanel">
                <h3>التذاكر</h3>
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>رقم التذكرة</th>
                                <th>الموضوع</th>
                                <th>الحالة</th>
                                <th>تاريخ الإنشاء</th>
                                <th>العمليات</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($tickets as $ticket): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($ticket['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($ticket['subject'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($ticket['status'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($ticket['created_at'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td>
                                        <a href="admin_ticket.php?id=<?php echo htmlspecialchars($ticket['id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-custom btn-view">عرض</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>

            <!-- Other tabs (edit, invoices, products, logins) -->
            <!-- Add similar code for other tabs here -->
        </div>
    </div>


    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
