<?php
// Include necessary files and start session
include('../config.php');
include('includes/auth.php');
session_start();

// Redirect if not admin
if ($_SESSION['role'] !== 'admin') {
    header('Location: ../client/dashboard.php');
    exit();
}

// Fetch all gateways
function fetchGateways($pdo) {
    $stmt = $pdo->query("SELECT * FROM payment_gateways");
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Handle gateway status toggle
if (isset($_POST['toggle_status'])) {
    $gatewayId = $_POST['gateway_id'];
    $currentStatus = $_POST['current_status'];

    // Toggle status
    $newStatus = $currentStatus ? 0 : 1;
    $stmt = $pdo->prepare("UPDATE payment_gateways SET status = ? WHERE id = ?");
    $stmt->execute([$newStatus, $gatewayId]);

    header('Location: manage_gateways.php');
    exit();
}

// Fetch all gateways
$gateways = fetchGateways($pdo);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة بوابات الدفع</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .btn-custom {
            border-radius: 0;
            margin-right: 10px;
        }
        .table-custom {
            margin-top: 20px;
        }
        .modal-header, .modal-footer {
            border: none;
        }
        .badge-success {
            background-color: #28a745;
        }
        .badge-danger {
            background-color: #dc3545;
        }
        .btn-toggle {
            background-color: #007bff;
            color: white;
        }
    </style>
</head>
<body>
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>
                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>
                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>
                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>
                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>
                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>
                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>
                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>
        </div>
    </div>
</nav>
<div class="container mt-4">
        <div class="page-header">
            <h2>إدارة بوابات الدفع</h2>
        </div>
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th scope="col">الرقم</th>
                        <th scope="col">اسم البوابة</th>
                        <th scope="col">الحالة</th>
                        <th scope="col">الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($gateways as $gateway): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($gateway['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($gateway['name'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>
                                <?php if ($gateway['status']): ?>
                                    <span class="badge badge-success">مفعل</span>
                                <?php else: ?>
                                    <span class="badge badge-danger">معطل</span>
                                <?php endif; ?>
                            </td>
                            <td>
                                <form method="POST" style="display: inline;">
                                    <input type="hidden" name="gateway_id" value="<?php echo htmlspecialchars($gateway['id'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <input type="hidden" name="current_status" value="<?php echo htmlspecialchars($gateway['status'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <button type="submit" name="toggle_status" class="btn btn-custom btn-toggle">
                                        <?php echo $gateway['status'] ? 'تعطيل' : 'تفعيل'; ?>
                                    </button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

        <?php include 'footer.php'; ?>

    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
