<?php
// Include necessary files and start session
include('../config.php');
include('includes/auth.php');
session_start();

// Redirect if not admin
if ($_SESSION['role'] !== 'admin') {
    header('Location: ../client/dashboard.php');
    exit();
}

// Function to fetch gift cards
function fetchGiftCards($pdo) {
    $stmt = $pdo->query("SELECT * FROM giftcards");
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Handle delete gift card
if (isset($_POST['delete_giftcard'])) {
    $giftCardId = $_POST['giftcard_id'];

    // Check if the gift card is linked to a user
    $stmt = $pdo->prepare("SELECT user_id FROM giftcards WHERE id = ?");
    $stmt->execute([$giftCardId]);
    $userId = $stmt->fetchColumn();

    if ($userId === null) {
        // Delete the gift card if not linked to any user
        $stmt = $pdo->prepare("DELETE FROM giftcards WHERE id = ?");
        $stmt->execute([$giftCardId]);
    } else {
        // Show error message if linked to a user
        $deleteError = "لا يمكن حذف بطاقة الهدايا لأنها مستخدمة.";
    }

    header('Location: manage_giftcards.php');
    exit();
}

// Fetch all gift cards
$giftcards = fetchGiftCards($pdo);
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة بطاقات الهدايا</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .btn-custom {
            border-radius: 0;
            margin-right: 10px;
        }
        .btn-delete {
            background-color: #e74c3c;
            color: white;
        }
        .btn-edit {
            background-color: #3498db;
            color: white;
        }
        .btn-details {
            background-color: #f39c12;
            color: white;
        }
        .btn-invoices {
            background-color: #2ecc71;
            color: white;
        }
        .btn-products {
            background-color: #9b59b6;
            color: white;
        }
        .btn-cpanel {
            background-color: #e67e22;
            color: white;
        }
        .table-custom {
            margin-top: 20px;
        }
        .modal-header, .modal-footer {
            border: none;
        }
        .used {
            color: red;
        }
        .not-used {
            color: green;
        }
       
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>
                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>
                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>
                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>
                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>
                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>
                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>
                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>
        </div>
    </div>
</nav>
    <div class="container mt-4">
        <div class="page-header">
            <h2>إدارة بطاقات الهدايا</h2>
            <a href="add_giftcard.php" class="btn btn-primary">إضافة بطاقة هدايا جديدة</a>
        </div>
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th scope="col">الرقم</th>
                        <th scope="col">الكود</th>
                        <th scope="col">الرصيد</th>
                        <th scope="col">تاريخ الإنشاء</th>
                        <th scope="col">الحالة</th>
                        <th scope="col">الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($giftcards as $giftcard): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($giftcard['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($giftcard['code'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>$<?php echo htmlspecialchars($giftcard['balance'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($giftcard['created_at'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td class="<?php echo $giftcard['user_id'] ? 'used' : 'not-used'; ?>"><?php echo $giftcard['user_id'] ? 'مستخدمة' : 'غير مستخدمة'; ?></td>
                            <td>
                                <button type="button" class="btn btn-custom btn-details" data-bs-toggle="modal" data-bs-target="#giftcardDetailsModal<?php echo $giftcard['id']; ?>">تفاصيل</button>
<button type="button" class="btn btn-custom btn-delete" data-bs-toggle="modal" data-bs-target="#deleteGiftcardModal<?php echo $giftcard['id']; ?>">حذف</button>

                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Modals for gift card details -->
    <?php foreach ($giftcards as $giftcard): ?>
        <div class="modal fade" id="giftcardDetailsModal<?php echo $giftcard['id']; ?>" tabindex="-1" role="dialog" aria-labelledby="giftcardDetailsModalLabel<?php echo $giftcard['id']; ?>" aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="giftcardDetailsModalLabel<?php echo $giftcard['id']; ?>">تفاصيل بطاقة الهدايا</h5>
                        <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">&times;</button>
                    </div>
                    <div class="modal-body">
                        <p><strong>الكود:</strong> <?php echo htmlspecialchars($giftcard['code'], ENT_QUOTES, 'UTF-8'); ?></p>
                        <p><strong>الرصيد:</strong> $<?php echo htmlspecialchars($giftcard['balance'], ENT_QUOTES, 'UTF-8'); ?></p>
                        <p><strong>تاريخ الإنشاء:</strong> <?php echo htmlspecialchars($giftcard['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                        <p><strong>الحالة:</strong> <?php echo $giftcard['user_id'] ? 'مستخدمة' : 'غير مستخدمة'; ?></p>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>

                    </div>
                </div>
            </div>
        </div>
    <?php endforeach; ?>

    <!-- Modals for deleting gift cards -->
    <?php foreach ($giftcards as $giftcard): ?>
        <div class="modal fade" id="deleteGiftcardModal<?php echo $giftcard['id']; ?>" tabindex="-1" role="dialog" aria-labelledby="deleteGiftcardModalLabel<?php echo $giftcard['id']; ?>" aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="deleteGiftcardModalLabel<?php echo $giftcard['id']; ?>">حذف بطاقة الهدايا</h5>
                        <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">&times;</button>
                    </div>
                    <div class="modal-body">
                        <?php if ($giftcard['user_id']): ?>
                            <p>لا يمكن حذف بطاقة الهدايا لأنها مستخدمة.</p>
                        <?php else: ?>
                            <form method="POST">
                                <input type="hidden" name="giftcard_id" value="<?php echo htmlspecialchars($giftcard['id'], ENT_QUOTES, 'UTF-8'); ?>">
                                <p>هل أنت متأكد أنك تريد حذف بطاقة الهدايا هذه؟</p>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-secondary" data-dismiss="modal">إلغاء</button>
                                    <button type="submit" name="delete_giftcard" class="btn btn-danger">حذف</button>
                                </div>
                            </form>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>
    <?php endforeach; ?>

        <?php include 'footer.php'; ?>

     <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
