<?php
session_start();
include('../config.php');
include('includes/auth.php');

// Fetch WHM credentials for a specific server using PDO
function getWhmCredentials($pdo, $serverId) {
    $query = "SELECT * FROM servers WHERE id = ?";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$serverId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

// Fetch all servers
function getAllServers($pdo) {
    $query = "SELECT * FROM servers";
    $stmt = $pdo->prepare($query);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Function to make API requests
function makeWhmApiRequest($url, $whmUsername, $whmApiToken) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
        "Authorization: whm $whmUsername:$whmApiToken"
    ));
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        return array('error' => curl_error($ch));
    }
    curl_close($ch);
    return json_decode($response, true);
}

// Fetch servers for managing plans
$servers = getAllServers($pdo);

// Check if a server is selected
$selectedServerId = $_GET['server_id'] ?? null;
$packages = [];
$message = '';
$isApiError = false;

if ($selectedServerId) {
    $credentials = getWhmCredentials($pdo, $selectedServerId);
    $whmUsername = $credentials['whm_username'] ?? '';
    $whmApiToken = $credentials['whm_api_token'] ?? '';
    $whmHost = $credentials['whm_host'] ?? '';

    // WHM API URL to list packages
    $listPkgsUrl = "https://$whmHost:2087/json-api/listpkgs?api.version=1";

    // Fetch hosting packages
    $result = makeWhmApiRequest($listPkgsUrl, $whmUsername, $whmApiToken);

    // Handle API errors
    if (isset($result['error'])) {
        $errorMessage = htmlspecialchars($result['error'], ENT_QUOTES, 'UTF-8');
        $message = "حدث خطأ أثناء الاتصال بـ WHM: $errorMessage";
        $isApiError = true;
    } elseif (isset($result['cpanelresult']['error'])) {
        $message = "حدث خطأ في واجهة برمجة التطبيقات: " . htmlspecialchars($result['cpanelresult']['error']['reason'], ENT_QUOTES, 'UTF-8');
        $isApiError = true;
    } else {
        $packages = isset($result['data']['pkg']) ? $result['data']['pkg'] : [];
    }
}

// Function to get display value
function getDisplayValue($value) {
    if (is_null($value) || $value === '') {
        return '<span class="unlimited">غير محدود</span>';
    }
    return $value;
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة خطط الاستضافة</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .unlimited {
            color: green;
        }
        .alert-error {
            color: red;
        }
        .btn-disabled {
            pointer-events: none;
            opacity: 0.6;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>
                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>
                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>
                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>
                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>
                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>
                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>
                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>
        </div>
    </div>
</nav>
    <div class="container mt-4">
        <div class="page-header">
            <h2>إدارة خطط الاستضافة</h2>
        </div>
        <form method="GET" class="mb-4">
            <div class="form-group">
                <label for="server_id">اختر السيرفر</label>
                <select id="server_id" name="server_id" class="form-control" onchange="this.form.submit()">
                    <option value="">اختر السيرفر</option>
                    <?php foreach ($servers as $server): ?>
                        <option value="<?php echo htmlspecialchars($server['id'], ENT_QUOTES, 'UTF-8'); ?>" 
                                <?php echo $selectedServerId == $server['id'] ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($server['name'], ENT_QUOTES, 'UTF-8'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
        </form>

        <?php if ($selectedServerId && $message): ?>
            <div class="alert alert-danger alert-error">
                <?php echo $message; ?>
            </div>
        <?php endif; ?>

        <?php if ($selectedServerId && !$isApiError): ?>
            <a href="add_plan.php?server_id=<?php echo urlencode($selectedServerId); ?>" class="btn btn-primary mb-4">إضافة خطة استضافة جديدة</a>
            <div class="table-container">
                <table class="table table-striped">
                    <thead>
                        <tr>
                            <th>الرقم التسلسلي</th>
                            <th>اسم الخطة</th>
                            <th>حصة القرص</th>
                            <th>عرض النطاق الترددي</th>
                            <th>المجالات الإضافية</th>
                            <th>حسابات FTP</th>
                            <th>قواعد بيانات SQL</th>
                            <th>حسابات البريد الإلكتروني</th>
                            <th>النطاقات الفرعية</th>
                            <th>النطاقات الموقوفة</th>
                            <th>الإجراءات</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if (empty($packages)): ?>
                            <tr>
                                <td colspan="11">لا توجد خطط استضافة متاحة.</td>
                            </tr>
                        <?php else: ?>
                            <?php foreach ($packages as $index => $package): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($index + 1, ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars($package['name'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['QUOTA']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['BWLIMIT']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['MAXADDON']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['MAXFTP']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['MAXSQL']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['MAX_EMAILACCT']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['MAXSUB']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td><?php echo htmlspecialchars(getDisplayValue($package['MAXPARK']), ENT_QUOTES, 'UTF-8'); ?></td>
                                    <td>
                                        <a href="edit_plan.php?name=<?php echo urlencode($package['name']); ?>&server_id=<?php echo urlencode($selectedServerId); ?>" class="btn btn-warning btn-sm">تعديل</a>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>
        <?php elseif (!$selectedServerId): ?>
            <div class="alert alert-info">يرجى اختيار السيرفر لعرض خطط الاستضافة الخاصة به.</div>
        <?php endif; ?>
    </div>

        <?php include 'footer.php'; ?>
        <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
