<?php
session_start();
include('../config.php');
include('includes/auth.php');

// Disable server
if (isset($_GET['disable_id'])) {
    $serverId = $_GET['disable_id'];
    $query = "UPDATE servers SET enabled = 0 WHERE id = ?";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$serverId]);

    $_SESSION['notification'] = ['type' => 'success', 'message' => "تم تعطيل الخادم بنجاح."];
    header("Location: manage_server.php");
    exit();
}

// Enable server
if (isset($_GET['enable_id'])) {
    $serverId = $_GET['enable_id'];
    $query = "UPDATE servers SET enabled = 1 WHERE id = ?";
    $stmt = $pdo->prepare($query);
    $stmt->execute([$serverId]);

    $_SESSION['notification'] = ['type' => 'success', 'message' => "تم تفعيل الخادم بنجاح."];
    header("Location: manage_server.php");
    exit();
}

// Fetch all servers
function getAllServers($pdo) {
    $query = "SELECT * FROM servers";
    $stmt = $pdo->prepare($query);
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Function to make API requests
function makeWhmApiRequest($url, $whmUsername, $whmApiToken) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
        "Authorization: whm $whmUsername:$whmApiToken"
    ));
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        return array('error' => curl_error($ch));
    }
    curl_close($ch);
    return json_decode($response, true);
}

// Fetch servers for managing plans
$servers = getAllServers($pdo);
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة الخوادم</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .btn-action {
            margin-right: 5px;
        }
        .status-enabled {
            background-color: #28a745; /* Green */
            color: #fff;
            padding: 5px;
            border-radius: 4px;
        }
        .status-disabled {
            background-color: #dc3545; /* Red */
            color: #fff;
            padding: 5px;
            border-radius: 4px;
        }
    </style>
</head>
<body>
    <nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>
                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>
                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>
                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>
                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>
                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>
                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>
                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>
        </div>
    </div>
</nav>
    <div class="container mt-4">
        <div class="page-header">
            <h2>إدارة الخوادم</h2>
            <a href="add_server.php" class="btn btn-primary">إضافة خادم</a>
        </div>

        <!-- Toast Notifications -->
        <div aria-live="polite" aria-atomic="true" class="toast-container">
            <?php
            if (isset($_SESSION['notification'])) {
                $type = $_SESSION['notification']['type'];
                $message = $_SESSION['notification']['message'];
                $toastClass = $type === 'success' ? 'bg-success' : 'bg-danger';
                echo "<div class='toast align-items-center text-white $toastClass' role='alert' aria-live='assertive' aria-atomic='true'>
                    <div class='d-flex'>
                        <div class='toast-body'>
                            $message
                        </div>
                        <button type='button' class='btn-close btn-close-white' data-bs-dismiss='toast' aria-label='Close'></button>
                    </div>
                </div>";
                unset($_SESSION['notification']);
            }
            ?>
        </div>

        <div class="table-container mt-4">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th>الرقم التسلسلي</th>
                        <th>اسم الخادم</th>
                        <th>اسم مستخدم WHM</th>
                        <th>مضيف WHM</th>
                        <th>الحالة</th>
                        <th>الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if (empty($servers)): ?>
                        <tr>
                            <td colspan="6">لا توجد خوادم متاحة.</td>
                        </tr>
                    <?php else: ?>
                        <?php foreach ($servers as $index => $server): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($index + 1, ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($server['name'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($server['whm_username'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($server['whm_host'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td>
                                    <?php if ($server['enabled']): ?>
                                        <span class="status-enabled">مفعل</span>
                                    <?php else: ?>
                                        <span class="status-disabled">معطل</span>
                                    <?php endif; ?>
                                </td>
                                <td>
                                    <a href="edit_server.php?id=<?php echo urlencode($server['id']); ?>" class="btn btn-warning btn-sm btn-action">تعديل</a>
                                    <?php if ($server['enabled']): ?>
                                        <a href="?disable_id=<?php echo urlencode($server['id']); ?>" class="btn btn-danger btn-sm btn-action" onclick="return confirm('هل أنت متأكد أنك تريد تعطيل هذا الخادم؟')">تعطيل</a>
                                    <?php else: ?>
                                        <a href="?enable_id=<?php echo urlencode($server['id']); ?>" class="btn btn-success btn-sm btn-action" onclick="return confirm('هل أنت متأكد أنك تريد تفعيل هذا الخادم؟')">تفعيل</a>
                                    <?php endif; ?>
                                    <a href="#" class="btn btn-info btn-sm btn-action" data-toggle="modal" data-target="#testConnectionModal" data-id="<?php echo urlencode($server['id']); ?>">
                                        اختبار الاتصال
                                    </a>
                                    <a href="https://<?php echo htmlspecialchars($server['whm_host'], ENT_QUOTES, 'UTF-8'); ?>:2087" target="_blank" class="btn btn-success btn-sm btn-action">
                                        الوصول إلى لوحة WHM
                                    </a>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Modal for Test Connection -->
    <div class="modal fade" id="testConnectionModal" tabindex="-1" role="dialog" aria-labelledby="testConnectionModalLabel" aria-hidden="true">
        <div class="modal-dialog" role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="testConnectionModalLabel">نتائج اختبار الاتصال</h5>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                </div>
                <div class="modal-body">
                    <div id="testConnectionResult">النتائج هنا...</div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-dismiss="modal">إغلاق</button>
                </div>
            </div>
        </div>
    </div>

        <?php include 'footer.php'; ?>

   <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script>
        $('#testConnectionModal').on('show.bs.modal', function (event) {
            var button = $(event.relatedTarget); // Button that triggered the modal
            var serverId = button.data('id'); // Extract server ID from data attribute
            var resultContainer = $('#testConnectionResult');

            $.ajax({
                url: 'test_connection.php',
                method: 'POST',
                data: { id: serverId },
                success: function(response) {
                    resultContainer.html(response);
                },
                error: function() {
                    resultContainer.html('<div class="alert alert-danger">حدث خطأ أثناء اختبار الاتصال.</div>');
                }
            });
        });

        $(document).ready(function() {
            // Show toast notifications if any
            if ($('.toast').length) {
                $('.toast').toast({ delay: 5000 });
                $('.toast').toast('show');
            }
        });
    </script>
</body>
</html>
