<?php
// Include necessary files and start session
include('../config.php');
include('includes/auth.php');
session_start();

// Redirect if not admin
if ($_SESSION['role'] !== 'admin') {
    header('Location: ../client/dashboard.php');
    exit();
}

// Function to fetch users with company information based on filter
function fetchUsers($pdo, $filter, $search = '', $groupId = null) {
    $query = "SELECT u.id, u.username, u.email, u.role, u.balance, u.created_at, u.last_ip, u.country, u.company_id, 
                     c.name AS company_name_linked, g.name AS group_name, u.first_name, u.last_name
              FROM `users` u
              LEFT JOIN `companies` c ON u.company_id = c.id
              LEFT JOIN `groups` g ON u.group_id = g.id";
    
    $conditions = [];
    $params = [];
    
    if ($filter === 'clients') {
        $conditions[] = "u.role != 'admin'";
    } elseif ($filter === 'admins') {
        $conditions[] = "u.role = 'admin'";
    }
    
    if (!empty($search)) {
        $conditions[] = "(u.username LIKE ? OR u.email LIKE ?)";
        $params[] = "%$search%";
        $params[] = "%$search%";
    }

    if (!empty($groupId)) {
        $conditions[] = "u.group_id = ?";
        $params[] = $groupId;
    }
    
    if (!empty($conditions)) {
        $query .= " WHERE " . implode(' AND ', $conditions);
    }

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Handle delete user
if (isset($_POST['delete_user'])) {
    $userId = $_POST['user_id'];

    // Delete related data
    $tables = ['login_history'];
    foreach ($tables as $table) {
        $stmt = $pdo->prepare("DELETE FROM $table WHERE user_id = ?");
        $stmt->execute([$userId]);
    }

    // Delete user
    $stmt = $pdo->prepare("DELETE FROM users WHERE id = ?");
    $stmt->execute([$userId]);

    // Delete related company if no other users are linked
    $stmt = $pdo->prepare("SELECT COUNT(*) AS user_count FROM users WHERE company_id = (SELECT company_id FROM users WHERE id = ?)");
    $stmt->execute([$userId]);
    $userCount = $stmt->fetchColumn();

    if ($userCount === 0) {
        $stmt = $pdo->prepare("DELETE FROM companies WHERE id = (SELECT company_id FROM users WHERE id = ?)");
        $stmt->execute([$userId]);
    }

    header('Location: manage_users.php');
    exit();
}

// Fetch all clients by default
$filter = 'clients';
$search = '';
$groupId = null;

if (isset($_POST['filter'])) {
    $filter = $_POST['filter'];
}

if (isset($_POST['search'])) {
    $search = $_POST['search'];
}

if (isset($_POST['group_id'])) {
    $groupId = $_POST['group_id'];
}

$users = fetchUsers($pdo, $filter, $search, $groupId);

// Fetch groups for filter dropdown
$stmt = $pdo->query("SELECT id, name FROM `groups`");
$groups = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>إدارة المستخدمين والعملاء</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
   <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .btn-custom {
            color: white;
        }
        .btn-delete { background-color: #e74c3c; }
        .btn-edit { background-color: #3498db; }
        .btn-details { background-color: #f39c12; }
        .btn-invoices { background-color: #2ecc71; }
        .table-custom { margin-top: 20px; }
    </style>
</head>
<body>
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="https://one.hostgoal.net/admin/dashboard.php">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <!-- "جديد +" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="newDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">جديد +</a>
                    <ul class="dropdown-menu" aria-labelledby="newDropdown">
                        <li><a class="dropdown-item" href="add_user.php">إضافة مستخدم</a></li>
                        <li><a class="dropdown-item" href="add_product.php">إضافة منتج</a></li>
                        <li><a class="dropdown-item" href="add_company.php">إضافة شركة</a></li>
                        <li><a class="dropdown-item" href="add_coupon.php">إضافة كوبون</a></li>
                        <li><a class="dropdown-item" href="add_giftcard.php">إضافة بطاقة هدايا</a></li>
                        <li><a class="dropdown-item" href="add_plan.php">إضافة خطة استضافة</a></li>
                    </ul>
                </li>
                <!-- "العملاء" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="clientsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">العملاء</a>
                    <ul class="dropdown-menu" aria-labelledby="clientsDropdown">
                        <li><a class="dropdown-item" href="manage_users.php">إدارة المستخدمين</a></li>
                        <li><a class="dropdown-item" href="manage_groups.php">إدارة المجموعات</a></li>
                        <li><a class="dropdown-item" href="manage_companies.php">إدارة الشركات</a></li>
                    </ul>
                </li>
                <!-- "الفواتير" link -->
                <li class="nav-item">
                    <a class="nav-link" href="invoices.php">الفواتير</a>
                </li>
                <!-- "المنتجات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="productsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">المنتجات</a>
                    <ul class="dropdown-menu" aria-labelledby="productsDropdown">
                        <li><a class="dropdown-item" href="manage_categories.php">إدارة الأقسام</a></li>
                        <li><a class="dropdown-item" href="manage_products.php">إدارة المنتجات</a></li>
                        <li><a class="dropdown-item" href="manage_domains.php">إدارة النطاقات</a></li>
                        <li><a class="dropdown-item" href="manage_ssl_requests.php">إدارة طلبات SSL</a></li>
                    </ul>
                </li>
                <!-- "الدعم" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="supportDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="supportDropdown">
                        <li><a class="dropdown-item" href="forum_management.php">المنتدي</a></li>
                        <li><a class="dropdown-item" href="manage_q_and_a.php">إدارة Q&A</a></li>
                        <li><a class="dropdown-item" href="admin_tickets.php">إدارة التذاكر</a></li>
                    </ul>
                </li>
                <!-- "الأعدادات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="settingsDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الأعدادات</a>
                    <ul class="dropdown-menu" aria-labelledby="settingsDropdown">
                        <li><a class="dropdown-item" href="settings.php">العامة</a></li>
                        <li><a class="dropdown-item" href="manage_server.php">الخادم</a></li>
                        <li><a class="dropdown-item" href="manage_plans.php">إدارة خطط الاستضافات</a></li>
                        <li><a class="dropdown-item" href="manage_giftcards.php">بطاقات الهدايا</a></li>
                        <li><a class="dropdown-item" href="manage_coupons.php">كوبونات</a></li>
                        <li><a class="dropdown-item" href="manage_gateways.php">بوابات الدفع</a></li>
                    </ul>
                </li>
                <!-- "النشاطات" dropdown -->
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="activitiesDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">النشاطات</a>
                    <ul class="dropdown-menu" aria-labelledby="activitiesDropdown">
                        <li><a class="dropdown-item" href="login_history.php">سجل تسجيل الدخول العملاء</a></li>
                        <li><a class="dropdown-item" href="admin_login_history.php">سجل تسجيل الدخول المسئولين</a></li>
                        <li><a class="dropdown-item" href="email_history.php">سجل البريد الإلكتروني</a></li>
                        <li><a class="dropdown-item" href="password_resets_log.php">سجل إعادة تعيين كلمة المرور</a></li>
                    </ul>
                </li>
                <!-- Logout button -->
                 <li class="nav-item">
                        <a class="nav-link logout" href="logout.php">تسجيل خروج</a>
                    </li>
            </ul>
        </div>
    </div>
</nav>
<div class="container mt-4">
        <div class="page-header">
            <h2>إدارة العملاء</h2>
            <a href="add_user.php" class="btn btn-primary">إضافة مستخدم جديد</a>
        </div>

        <!-- Filter Form -->
        <form method="POST" class="mb-4">
            <div class="form-group">
                <label for="search">بحث</label>
                <input type="text" name="search" id="search" class="form-control" value="<?php echo htmlspecialchars($search, ENT_QUOTES, 'UTF-8'); ?>">
            </div>
            <div class="form-group">
                <label for="group_id">المجموعة</label>
                <select name="group_id" id="group_id" class="form-control">
                    <option value="">كل المجموعات</option>
                    <?php foreach ($groups as $group): ?>
                        <option value="<?php echo htmlspecialchars($group['id'], ENT_QUOTES, 'UTF-8'); ?>" <?php echo ($groupId == $group['id']) ? 'selected' : ''; ?>>
                            <?php echo htmlspecialchars($group['name'], ENT_QUOTES, 'UTF-8'); ?>
                        </option>
                    <?php endforeach; ?>
                </select>
            </div>
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="radio" name="filter" id="filterClients" value="clients" <?php echo ($filter === 'clients') ? 'checked' : ''; ?>>
                <label class="form-check-label" for="filterClients">العملاء</label>
            </div>
            <div class="form-check form-check-inline">
                <input class="form-check-input" type="radio" name="filter" id="filterAdmins" value="admins" <?php echo ($filter === 'admins') ? 'checked' : ''; ?>>
                <label class="form-check-label" for="filterAdmins">المشرفين</label>
            </div>
            <button type="submit" class="btn btn-secondary">تطبيق الفلتر</button>
        </form>

        <!-- User Table -->
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th scope="col">الرقم</th>
                        <th scope="col">اسم المستخدم</th>
                        <th scope="col">البريد الإلكتروني</th>
                        <th scope="col">الدور</th>
                        <th scope="col">الرصيد</th>
                        <th scope="col">تاريخ الإنشاء</th>
                        <th scope="col">المجموعة</th>
                        <th scope="col">الإجراءات</th>
                    </tr>
                </thead>
                <tbody id="user-table-body">
                    <?php foreach ($users as $user): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($user['email'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($user['role'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>$<?php echo htmlspecialchars($user['balance'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($user['created_at'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>
                                <select class="form-control group-select" data-user-id="<?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <option value="">اختر مجموعة</option>
                                    <?php foreach ($groups as $group): ?>
                                        <option value="<?php echo htmlspecialchars($group['id'], ENT_QUOTES, 'UTF-8'); ?>" <?php echo ($user['group_name'] == $group['name']) ? 'selected' : ''; ?>>
                                            <?php echo htmlspecialchars($group['name'], ENT_QUOTES, 'UTF-8'); ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </td>
                            <td>
                                <a href="edit_user.php?id=<?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-custom btn-edit">تعديل</a>
<button type="button" class="btn btn-custom btn-details" data-bs-toggle="modal" data-bs-target="#userDetailsModal<?php echo $user['id']; ?>">تفاصيل</button>
                                <a href="user_invoices.php?user_id=<?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-custom btn-invoices">الفواتير</a>
                                <form method="POST" style="display:inline;">
                                    <input type="hidden" name="user_id" value="<?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?>">
                                    <button type="submit" name="delete_user" class="btn btn-custom btn-delete" onclick="return confirm('هل أنت متأكد أنك تريد حذف هذا المستخدم؟')">حذف</button>
                                </form>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        
        <!-- Modal Template -->
<?php foreach ($users as $user): ?>
    <div class="modal fade" id="userDetailsModal<?php echo $user['id']; ?>" tabindex="-1" aria-labelledby="userDetailsModalLabel<?php echo $user['id']; ?>" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="userDetailsModalLabel<?php echo $user['id']; ?>">تفاصيل المستخدم</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <p><strong>اسم المستخدم:</strong> <?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>البريد الإلكتروني:</strong> <?php echo htmlspecialchars($user['email'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>الدور:</strong> <?php echo htmlspecialchars($user['role'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>الرصيد:</strong> $<?php echo htmlspecialchars($user['balance'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>تاريخ الإنشاء:</strong> <?php echo htmlspecialchars($user['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>اسم الشركة:</strong> <?php echo htmlspecialchars($user['company_name_linked'], ENT_QUOTES, 'UTF-8'); ?></p>
                </div>
                <div class="modal-footer">
                                            <a href="manage_client.php?user_id=<?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-custom btn-invoices">إدارة العميل</a>
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">إغلاق</button>
                </div>
            </div>
        </div>
    </div>
<?php endforeach; ?>

    </div>

    <!-- Include Toast for Notifications -->
    <div id="toast-container" style="position: absolute; top: 20px; right: 20px;">
        <!-- Bootstrap Toast Notifications will appear here -->
    </div>
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.6.0/jquery.min.js"></script>
    <script>
        // Logic for deleting users, changing group, and other user management actions

        // Auto-dismiss Bootstrap toast after 5 seconds
        $(document).ready(function() {
            setTimeout(function() {
                $('.toast').toast('hide');
            }, 5000);
        });
    </script>
</body>
</html>
