<?php
include('../config.php');
include('includes/auth.php');

function fetchUsers($pdo, $filter, $search = '', $groupId = null) {
    $query = "SELECT u.id, u.username, u.email, u.role, u.balance, u.created_at, u.company_id, c.name AS company_name_linked, g.name AS group_name
              FROM `users` u
              LEFT JOIN `companies` c ON u.company_id = c.id
              LEFT JOIN `groups` g ON u.group_id = g.id";
    
    $conditions = [];
    $params = [];
    
    if ($filter === 'clients') {
        $conditions[] = "u.role != 'admin'";
    } elseif ($filter === 'admins') {
        $conditions[] = "u.role = 'admin'";
    }
    
    if (!empty($search)) {
        $conditions[] = "(u.username LIKE ? OR u.email LIKE ?)";
        $params[] = "$search%"; // Match the start of the string
        $params[] = "$search%";
    }

    if (!empty($groupId)) {
        $conditions[] = "u.group_id = ?";
        $params[] = $groupId;
    }
    
    if (!empty($conditions)) {
        $query .= " WHERE " . implode(' AND ', $conditions);
    }

    $stmt = $pdo->prepare($query);
    $stmt->execute($params);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch users based on AJAX request parameters
$filter = $_POST['filter'] ?? 'clients';
$search = $_POST['search'] ?? '';
$groupId = $_POST['group_id'] ?? null;

$users = fetchUsers($pdo, $filter, $search, $groupId);

// Return the filtered user rows
foreach ($users as $user) {
    echo '<tr>';
    echo '<td>' . htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8') . '</td>';
    echo '<td>' . htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8') . '</td>';
    echo '<td>' . htmlspecialchars($user['email'], ENT_QUOTES, 'UTF-8') . '</td>';
    echo '<td>' . htmlspecialchars($user['role'], ENT_QUOTES, 'UTF-8') . '</td>';
    echo '<td>' . htmlspecialchars($user['balance'], ENT_QUOTES, 'UTF-8') . '</td>';
    echo '<td>' . htmlspecialchars($user['created_at'], ENT_QUOTES, 'UTF-8') . '</td>';
    echo '<td>';
    // Add action buttons here
    echo '</td>';
    echo '</tr>';
}
?>
