<?php
// Include necessary files and start session
include('../config.php');
include('includes/auth.php');
session_start();

// Redirect if not admin
if ($_SESSION['role'] !== 'admin') {
    header('Location: ../client/dashboard.php');
    exit();
}

// Fetch invoices for a specific user
function fetchUserInvoices($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT * FROM orders WHERE user_id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch order details for a specific invoice
function fetchOrderDetails($pdo, $invoiceId) {
    $stmt = $pdo->prepare("SELECT od.*, p.name as product_name FROM order_details od
                           JOIN products p ON od.product_id = p.id
                           WHERE od.order_id = ?");
    $stmt->execute([$invoiceId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

$userId = $_GET['user_id'];
$invoices = fetchUserInvoices($pdo, $userId);
?>

<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>فواتير العميل</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .table-custom {
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <div class="page-header">
            <h2>فواتير العميل</h2>
        </div>
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th scope="col">الرقم</th>
                        <th scope="col">المبلغ</th>
                        <th scope="col">التاريخ</th>
                        <th scope="col">الحالة</th>
                        <th scope="col">الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($invoices as $invoice): ?>
                        <tr>
                            <td><?php echo htmlspecialchars($invoice['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>$<?php echo htmlspecialchars($invoice['total_price'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($invoice['created_at'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($invoice['status'], ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>
                                <button type="button" class="btn btn-custom btn-details" data-toggle="modal" data-target="#invoiceDetailsModal<?php echo $invoice['id']; ?>">عرض التفاصيل</button>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Modals for invoice details -->
    <?php foreach ($invoices as $invoice): 
        $orderDetails = fetchOrderDetails($pdo, $invoice['id']);
    ?>
        <div class="modal fade" id="invoiceDetailsModal<?php echo $invoice['id']; ?>" tabindex="-1" role="dialog" aria-labelledby="invoiceDetailsModalLabel<?php echo $invoice['id']; ?>" aria-hidden="true">
            <div class="modal-dialog" role="document">
                <div class="modal-content">
                    <div class="modal-header">
                        <h5 class="modal-title" id="invoiceDetailsModalLabel<?php echo $invoice['id']; ?>">تفاصيل الفاتورة - <?php echo htmlspecialchars($invoice['id'], ENT_QUOTES, 'UTF-8'); ?></h5>
                        <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                            <span aria-hidden="true">&times;</span>
                        </button>
                    </div>
                    <div class="modal-body">
                        <p><strong>المبلغ:</strong> $<?php echo htmlspecialchars($invoice['price'], ENT_QUOTES, 'UTF-8'); ?></p>
                        <p><strong>التاريخ:</strong> <?php echo htmlspecialchars($invoice['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                        <p><strong>الحالة:</strong> <?php echo htmlspecialchars($invoice['status'], ENT_QUOTES, 'UTF-8'); ?></p>
                        <hr>
                        <h5>تفاصيل الطلب:</h5>
                        <ul>
                            <?php foreach ($orderDetails as $detail): ?>
                                <li><?php echo htmlspecialchars($detail['product_name'], ENT_QUOTES, 'UTF-8'); ?> - $<?php echo htmlspecialchars($detail['price'], ENT_QUOTES, 'UTF-8'); ?></li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-dismiss="modal">إغلاق</button>
                    </div>
                </div>
            </div>
        </div>
    <?php endforeach; ?>

    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
