<?php
// Include necessary files and start session
include('../config.php');
include('includes/auth.php');
session_start();

// Redirect if not admin
if ($_SESSION['role'] !== 'admin') {
    header('Location: ../client/dashboard.php');
    exit();
}

// Fetch orders for a specific user
function fetchUserOrders($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT * FROM orders WHERE user_id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch products from order details
function fetchOrderProducts($pdo, $orderId) {
    $stmt = $pdo->prepare("
        SELECT od.*, p.name as product_name, p.product_type as product_type, i.created_at, i.status as invoice_status 
        FROM order_details od
        JOIN products p ON od.product_id = p.id
        JOIN orders i ON od.order_id = i.id
        WHERE od.order_id = ?
    ");
    $stmt->execute([$orderId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch cPanel credentials for a user account
function fetchCPanelCredentials($pdo, $userId) {
    $stmt = $pdo->prepare("SELECT username, password FROM user_accounts WHERE user_id = ?");
    $stmt->execute([$userId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

// Access cPanel using WHM API token
function accessCPanel($cpanelUsername, $cpanelPassword) {
    $whmUsername = 'hostgoal';
    $whmApiToken = 'U2M8FSQKEB4KFDLBOSW6T7MPTL4AUV85';

    // Generate cPanel SSO token URL
    $cpanelSsoUrl = "https://hostgoal.net:2087/json-api/create_user_session?api.version=1&user={$cpanelUsername}&service=cpaneld";

    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $cpanelSsoUrl);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "Authorization: whm $whmUsername:$whmApiToken"
    ]);
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
        curl_close($ch);
        exit();
    }
    curl_close($ch);

    $ssoResult = json_decode($response, true);

    if ($ssoResult['metadata']['result'] == 1) {
        $ssoTokenUrl = $ssoResult['data']['url'];
        header("Location: $ssoTokenUrl");
        exit();
    } else {
        $_SESSION['error'] = 'Error creating SSO token: ' . $ssoResult['metadata']['reason'];
        header("Location: services.php");
        exit();
    }
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['access_cpanel'])) {
    $cpanelUsername = $_POST['cpanel_username'];
    $cpanelPassword = $_POST['cpanel_password'];
    accessCPanel($cpanelUsername, $cpanelPassword);
}

$userId = $_GET['user_id'];
$orders = fetchUserOrders($pdo, $userId);
$cpanelCredentials = fetchCPanelCredentials($pdo, $userId);
?>

<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>منتجات العميل</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
        }
        .table-custom {
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <div class="page-header">
            <h2>منتجات العميل</h2>
        </div>
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th scope="col">الرقم</th>
                        <th scope="col">اسم المنتج</th>
                        <th scope="col">السعر</th>
                        <th scope="col">تاريخ الشراء</th>
                        <th scope="col">حالة الفاتورة</th>
                        <th scope="col">الإجراءات</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($orders as $order): 
                        $products = fetchOrderProducts($pdo, $order['id']);
                        foreach ($products as $product): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($product['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($product['product_name'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td>$<?php echo htmlspecialchars($product['price'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($product['created_at'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($product['invoice_status'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td>
                                    <?php if ($product['product_type'] === 'hosting'): ?>
                                        <form method="post" action="">
                                            <input type="hidden" name="cpanel_username" value="<?php echo htmlspecialchars($cpanelCredentials['username'], ENT_QUOTES, 'UTF-8'); ?>">
                                            <input type="hidden" name="cpanel_password" value="<?php echo htmlspecialchars($cpanelCredentials['password'], ENT_QUOTES, 'UTF-8'); ?>">
                                            <button type="submit" name="access_cpanel" class="btn btn-custom btn-access">دخول إلى cPanel</button>
                                        </form>
                                    <?php else: ?>
                                        <button type="button" class="btn btn-custom btn-details" data-toggle="modal" data-target="#productDetailsModal<?php echo $product['id']; ?>">عرض التفاصيل</button>
                                    <?php endif; ?>
                                    <form method="post" action="delete_product.php" style="display:inline;">
                                        <input type="hidden" name="product_id" value="<?php echo $product['id']; ?>">
                                    </form>
                                </td>
                            </tr>
                        <?php endforeach;
                    endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>

    <!-- Modals for product details -->
    <?php foreach ($orders as $order): 
        $products = fetchOrderProducts($pdo, $order['id']);
        foreach ($products as $product): ?>
            <div class="modal fade" id="productDetailsModal<?php echo $product['id']; ?>" tabindex="-1" role="dialog" aria-labelledby="productDetailsModalLabel<?php echo $product['id']; ?>" aria-hidden="true">
                <div class="modal-dialog" role="document">
                    <div class="modal-content">
                        <div class="modal-header">
                            <h5 class="modal-title" id="productDetailsModalLabel<?php echo $product['id']; ?>">تفاصيل المنتج - <?php echo htmlspecialchars($product['product_name'], ENT_QUOTES, 'UTF-8'); ?></h5>
                            <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                <span aria-hidden="true">&times;</span>
                            </button>
                        </div>
                        <div class="modal-body">
                            <p><strong>اسم المنتج:</strong> <?php echo htmlspecialchars($product['product_name'], ENT_QUOTES, 'UTF-8'); ?></p>
                            <p><strong>السعر:</strong> $<?php echo htmlspecialchars($product['price'], ENT_QUOTES, 'UTF-8'); ?></p>
                            <p><strong>تاريخ الشراء:</strong> <?php echo htmlspecialchars($product['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                            <p><strong>حالة الفاتورة:</strong> <?php echo htmlspecialchars($product['invoice_status'], ENT_QUOTES, 'UTF-8'); ?></p
                            <p><strong>حالة الفاتورة:</strong> <?php echo htmlspecialchars($product['invoice_status'], ENT_QUOTES, 'UTF-8'); ?></p>
                        </div>
                        <div class="modal-footer">
                            <button type="button" class="btn btn-secondary" data-dismiss="modal">إغلاق</button>
                        </div>
                    </div>
                </div>
            </div>
        <?php endforeach;
    endforeach; ?>

    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>

    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.3/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
</body>
</html>
