<?php
include('../config.php');
include('includes/auth.php');
session_start();

// Enable error reporting for debugging
error_reporting(E_ALL);
ini_set('display_errors', 1);

// Get the group ID from the query parameter
$groupId = isset($_GET['group_id']) ? (int)$_GET['group_id'] : 0;

// Fetch users associated with the group
function fetchUsersByGroup($pdo, $groupId) {
    $stmt = $pdo->prepare("
        SELECT * FROM users
        WHERE group_id = :groupId OR group_id2 = :groupId
    ");
    $stmt->execute(['groupId' => $groupId]);
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

$users = fetchUsersByGroup($pdo, $groupId);

// Fetch group details for display
function fetchGroupDetails($pdo, $groupId) {
    $stmt = $pdo->prepare("SELECT * FROM `groups` WHERE id = :groupId");
    $stmt->execute(['groupId' => $groupId]);
    return $stmt->fetch(PDO::FETCH_ASSOC);
}

$group = fetchGroupDetails($pdo, $groupId);
?>

<!DOCTYPE html>
<html lang="ar">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>المستخدمين في المجموعة</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        .table-custom {
            margin-top: 20px;
        }
    </style>
</head>
<body>
    <?php include 'nav2.php'; ?>
    <div class="container mt-4">
        <h2>المستخدمين في المجموعة: <?php echo htmlspecialchars($group['name'] ?? 'غير معروف', ENT_QUOTES, 'UTF-8'); ?></h2>
        <div class="table-responsive table-custom">
            <table class="table table-striped">
                <thead>
                    <tr>
                        <th scope="col">الرقم التعريفي</th>
                        <th scope="col">اسم المستخدم</th>
                        <th scope="col">البريد الإلكتروني</th>
                    </tr>
                </thead>
                <tbody>
                    <?php if ($users): ?>
                        <?php foreach ($users as $user): ?>
                            <tr>
                                <td><?php echo htmlspecialchars($user['id'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?></td>
                                <td><?php echo htmlspecialchars($user['email'], ENT_QUOTES, 'UTF-8'); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    <?php else: ?>
                        <tr>
                            <td colspan="3">لا يوجد مستخدمين في هذه المجموعة.</td>
                        </tr>
                    <?php endif; ?>
                </tbody>
            </table>
        </div>
    </div>
</body>
</html>
