const express = require('express');
const http = require('http');
const socketIo = require('socket.io');
const mysql = require('mysql2');
const bcrypt = require('bcryptjs');

const app = express();
const server = http.createServer(app);
const io = socketIo(server);

const db = mysql.createConnection({
    host: 'localhost',
    user: 'root',
    password: 'password',
    database: 'chat_db'
});

db.connect(err => {
    if (err) throw err;
    console.log('Connected to database');
});

app.use(express.static('public'));

io.on('connection', socket => {
    console.log('New client connected');

    socket.on('join', ({ userId, sessionId }) => {
        socket.join(sessionId);
        console.log(`User ${userId} joined session ${sessionId}`);
    });

    socket.on('message', ({ sessionId, senderId, message }) => {
        const query = 'INSERT INTO chat_messages (session_id, sender_id, message) VALUES (?, ?, ?)';
        db.query(query, [sessionId, senderId, message], (err, result) => {
            if (err) throw err;
            io.to(sessionId).emit('message', { senderId, message, sentAt: new Date() });
        });
    });

    socket.on('disconnect', () => {
        console.log('Client disconnected');
    });
});

server.listen(3000, () => {
    console.log('Server is running on port 3000');
});
