<?php
session_start();
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

include('../config.php');

// Fetch user ID from session
$user_id = $_SESSION['user_id'];

// Validate and fetch product ID from the request (make sure to sanitize and validate this)
$product_id = isset($_GET['product_id']) ? (int)$_GET['product_id'] : 0;

if ($product_id === 0) {
    $_SESSION['error'] = 'Invalid product ID.';
    header("Location: services.php");
    exit();
}

// Fetch the order_id linked to this product and validate the user
$stmt = $pdo->prepare("
    SELECT o.id AS order_id, o.status AS order_status, ua.*, s.whm_username, s.whm_api_token, s.whm_host
    FROM orders o
    JOIN order_details od ON o.id = od.order_id
    JOIN user_accounts ua ON ua.product_id = od.product_id
    JOIN servers s
    WHERE o.user_id = ? AND od.product_id = ?
");

$stmt->execute([$user_id, $product_id]);

$product = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$product) {
    // No valid order/product found
    $_SESSION['error'] = 'No associated account found for this product.';
    header("Location: services.php");
    exit();
}

// Access WHM/cPanel account using credentials fetched from the database
$whmUsername = $product['whm_username'];
$whmApiToken = $product['whm_api_token'];
$whmHost = $product['whm_host'];
$cpanelUsername = $product['username']; // Assuming the cPanel username is stored in user_accounts

// Generate cPanel SSO token URL
$cpanelSsoUrl = "https://{$whmHost}:2087/json-api/create_user_session?api.version=1&user={$cpanelUsername}&service=cpaneld";

// Function to make WHM API request
function makeWhmApiRequest($url, $whmUsername, $whmApiToken) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
        "Authorization: whm $whmUsername:$whmApiToken"
    ));
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
        curl_close($ch);
        exit();
    }
    curl_close($ch);
    return json_decode($response, true);
}

// Get SSO token response
$ssoResult = makeWhmApiRequest($cpanelSsoUrl, $whmUsername, $whmApiToken);

if ($ssoResult['metadata']['result'] == 1) {
    // Redirect to cPanel
    $ssoTokenUrl = $ssoResult['data']['url'];
    header("Location: $ssoTokenUrl");
    exit();
} else {
    $_SESSION['error'] = 'Error creating SSO token: ' . $ssoResult['metadata']['reason'];
    header("Location: services.php");
    exit();
}
