<?php
// client/confirm_email.php
include('../config.php');
session_start();

if (isset($_GET['code'])) {
    $code = $_GET['code'];

    // Verify the code and update the email
    $stmt = $pdo->prepare("SELECT id, new_email FROM users WHERE verification_token = ?");
    $stmt->execute([$code]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($user) {
        $newEmail = $user['new_email'];
        $user_id = $user['id'];

        // Update the user's email
        $stmt = $pdo->prepare("UPDATE users SET email = ?, verification_token = NULL, new_email = NULL WHERE id = ?");
        $stmt->execute([$newEmail, $user_id]);

        $message = "Your email address has been updated successfully.";
    } else {
        $message = "Invalid verification code.";
    }
} else {
    $message = "Missing verification code.";
}
?>
<!DOCTYPE html>
<html>
<head>
    <title>Confirm Email</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
            background-color: #f8f9fa;
        }
        .container {
            margin-top: 50px;
        }
        .message-box {
            background-color: #fff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
            text-align: center;
        }
        @media (max-width: 768px) {
            .message-box {
                padding: 15px;
            }
        }
        .alert {
            transition: opacity 1s ease-out;
        }
    </style>
    <script>
        document.addEventListener('DOMContentLoaded', function () {
            setTimeout(function () {
                const alert = document.querySelector('.alert');
                if (alert) {
                    alert.style.opacity = '0';
                    setTimeout(function () {
                        alert.remove();
                    }, 1000);
                }
            }, 10000);
        });
    </script>
</head>
<body>
    <nav>
        <?php include 'nav.php'; ?>
    </nav>
    <div class="container">
        <div class="message-box">
            <h2>Email Confirmation</h2>
            <div class="alert alert-info"><?php echo htmlspecialchars($message, ENT_QUOTES, 'UTF-8'); ?></div>
        </div>
    </div>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>
</body>
</html>
