<?php
session_start();
include('../config.php');
require_once __DIR__.'/../vendor/autoload.php'; // Ensure PHPMailer is autoloaded

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

// Fetch user ID from session
$user_id = $_SESSION['user_id'];

// Fetch user information from the database
$stmt_user = $pdo->prepare("SELECT username, email FROM users WHERE id = ?");
$stmt_user->execute([$user_id]);
$user = $stmt_user->fetch();

if (!$user) {
    $_SESSION['error'] = 'User not found.';
    header("Location: services.php");
    exit();
}

$username = $user['username'] . rand(10, 99); // Add two random digits to the username

// Secure password generation function
function generateSecurePassword($length = 16) {
    $upperCase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';
    $lowerCase = 'abcdefghijklmnopqrstuvwxyz';
    $numbers = '0123456789';
    $specialChars = '!@#$%^&*()_+{}[]|:;<>,.?';

    $allChars = $upperCase . $lowerCase . $numbers . $specialChars;

    // Ensure password contains at least one of each character type
    $password = $upperCase[rand(0, strlen($upperCase) - 1)] .
                $lowerCase[rand(0, strlen($lowerCase) - 1)] .
                $numbers[rand(0, strlen($numbers) - 1)] .
                $specialChars[rand(0, strlen($specialChars) - 1)];

    // Fill the remaining length with random characters from all groups
    for ($i = 4; $i < $length; $i++) {
        $password .= $allChars[rand(0, strlen($allChars) - 1)];
    }

    // Shuffle the password to randomize character positions
    return str_shuffle($password);
}

// Generate a more secure password with 16 characters
$password = generateSecurePassword(16);

$domain = filter_var($_POST['domain'], FILTER_VALIDATE_DOMAIN);
$internal_name = $_POST['internal_name'];
$email = $user['email'];

if (!$domain || !$internal_name || !$email) {
    $_SESSION['error'] = 'Invalid input. Please try again.';
    header("Location: services.php");
    exit();
}

// Check DNS records for the domain
$dnsRecords = dns_get_record($domain, DNS_NS);

if ($dnsRecords === false || empty($dnsRecords)) {
    $_SESSION['error'] = 'Failed to retrieve DNS records for the domain.';
    header("Location: services.php");
    exit();
}

$nameservers = [];
foreach ($dnsRecords as $record) {
    $nameservers[] = $record['target'];
}

// Check if the nameservers match the expected HostGoal nameservers
$hostgoal_ns = ['dns1.hostgoal.net', 'dns2.hostgoal.net'];
if (empty(array_intersect($nameservers, $hostgoal_ns))) {
    $_SESSION['error'] = 'The domain is not linked to the nameservers of HostGoal. Please update your nameservers to dns1.hostgoal.net and dns2.hostgoal.net.';
    header("Location: services.php");
    exit();
}

// Function to make WHM API requests
function makeWhmApiRequest($url, $whmUsername, $whmApiToken) {
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($ch, CURLOPT_HTTPHEADER, array(
        "Authorization: whm $whmUsername:$whmApiToken"
    ));
    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        echo 'Error:' . curl_error($ch);
        curl_close($ch);
        exit();
    }
    curl_close($ch);
    return json_decode($response, true);
}

// Fetch available servers from the database
$stmt_servers = $pdo->prepare("SELECT whm_username, whm_api_token, whm_host FROM servers");
$stmt_servers->execute();
$servers = $stmt_servers->fetchAll(PDO::FETCH_ASSOC);

$account_created = false;

foreach ($servers as $server) {
    $whmUsername = $server['whm_username'];
    $whmApiToken = $server['whm_api_token'];
    $whmHost = $server['whm_host'];

    // Check if the package exists on the server
    $url = "https://$whmHost:2087/json-api/listpkgs?api.version=1";
    $result = makeWhmApiRequest($url, $whmUsername, $whmApiToken);

    if (isset($result['data']['pkg'])) {
        foreach ($result['data']['pkg'] as $pkg) {
            if ($pkg['name'] === $internal_name) {
                // Create the account on this server
                $create_url = "https://$whmHost:2087/json-api/createacct?api.version=1&username={$username}&domain={$domain}&password={$password}&contactemail={$email}&pkgname={$internal_name}";
                $create_result = makeWhmApiRequest($create_url, $whmUsername, $whmApiToken);

                if ($create_result['metadata']['result'] == 1) {
                    // Account creation successful, save details to the database
                    $hashed_password = password_hash($password, PASSWORD_BCRYPT);
                    $stmt = $pdo->prepare("INSERT INTO user_accounts (user_id, product_id, domain, email, username, password, created_at) VALUES (?, ?, ?, ?, ?, ?, NOW())");
                    $stmt->execute([$user_id, $_POST['product_id'], $domain, $email, $username, $hashed_password]);

                    // Send a success email to the user
                    $mail = new PHPMailer(true);
                    try {
                        $mail->isSMTP();
                        $mail->Host       = 'mail.hostgoal.net'; 
                        $mail->SMTPAuth   = true;
                        $mail->Username   = 'help@hostgoal.net'; 
                        $mail->Password   = '2719243214kK'; 
                        $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
                        $mail->Port       = 465; 

                        $mail->setFrom('help@hostgoal.net', 'Host Goal Support');
                        $mail->addAddress($email);

                        $mail->isHTML(true);
                        $mail->Subject = "Your cPanel Account has been created";
                        $mail->Body    = "<p>Dear {$user['username']},</p>
                                          <p>Your cPanel account has been created successfully. Below are your login details:</p>
                                          <p><strong>Domain:</strong> {$domain}<br>
                                             <strong>Username:</strong> {$username}<br>
                                             <strong>Password:</strong> {$password}</p>
                                          <p>Please change your password after your first login for security reasons.</p>
                                          <p>Best regards,<br>Host Goal Support Team</p>";

                        $mail->send();
                    } catch (Exception $e) {
                        error_log('Email sending failed: ' . $mail->ErrorInfo);
                    }

                    $_SESSION['success'] = 'Account created successfully.';
                    $account_created = true;
                    break 2; // Exit both loops as account has been created
                } else {
                    $_SESSION['error'] = 'Error creating account: ' . $create_result['metadata']['reason'];
                }
            }
        }
    }
}

if ($account_created === false) {
    $_SESSION['error'] = 'Could not find the package on any available server or failed to create the account.';
}
else
{
    $_SESSION['success'] = 'Account created successfully.';
}

header("Location: services.php");
exit();
?>
