<?php
include('../config.php');
session_start();
include('includes/auth.php');

// Fetch categories and topics
$categoriesStmt = $pdo->prepare("SELECT * FROM forum_categories");
$categoriesStmt->execute();
$categories = $categoriesStmt->fetchAll();

$postsStmt = $pdo->prepare("SELECT forum_posts.*, forum_topics.title AS topic_title, forum_categories.name AS category_name, users.username AS author FROM forum_posts
    JOIN forum_topics ON forum_posts.topic_id = forum_topics.id
    JOIN forum_categories ON forum_topics.category_id = forum_categories.id
    JOIN users ON forum_posts.user_id = users.id");
$postsStmt->execute();
$posts = $postsStmt->fetchAll();

$stmt = $pdo->prepare("SELECT username, balance FROM users WHERE id = ?");
$stmt->execute([$_SESSION['user_id']]);
$user = $stmt->fetch();
$username = $user['username'] ?? '';
$balance = $user['balance'] ?? 0;

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $description = $_POST['description'];
    $content = $_POST['content'];
    $topic_id = $_POST['topic'];
    $user_id = $_SESSION['user_id'];

    $stmt = $pdo->prepare("INSERT INTO forum_posts (description, content, topic_id, user_id) VALUES (?, ?, ?, ?)");
    $stmt->execute([$description, $content, $topic_id, $user_id]);

    header('Location: forum.php');
    exit();
}
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>منتدى HostGoal</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.min.css">

    <style>
        button:hover {
            background-color: #0f8a8a;
        }

        body, html {
            font-family: 'Cairo', sans-serif;
            background-color: #f9f9f9;
            margin: 0;
            padding: 0;
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }

        .navbar {
            background-color: #2c2c2c;
            padding: 10px 20px;
        }

        .navbar-brand {
            display: flex;
            align-items: center;
            color: white;
        }

        .navbar-brand img {
            height: 40px;
            margin-right: 10px;
        }

        .navbar-nav {
            text-align: center;
            flex-grow: 1;
            justify-content: center;
        }

        .navbar-nav .nav-item {
            margin: 0 15px;
        }

        .navbar-nav .nav-link {
            color: #FFF !important;
            font-size: 18px;
            padding: 10px 20px;
            background-color: #17a2b8;
            text-align: center;
            border-radius: 30px;
            transition: background-color 0.3s ease;
        }

        .navbar-nav .nav-link:hover {
            background-color: #0f8a8a;
        }

        .profile-menu .dropdown-toggle {
            color: #fff;
            background-color: #17a2b8;
            border-radius: 30px;
            padding: 12px 24px;
            min-width: 180px;
        }

        .profile-menu .dropdown-menu {
            background-color: #2c2c2c;
            color: #fff;
            border-radius: 8px;
            width: 300px;
            padding: 20px;
        }

        .cart-nav-item {
            margin-left: auto;
            display: flex;
            align-items: center;
        }

        .cart-nav-item .nav-link {
            padding: 10px 20px;
            background-color: transparent;
            color: #FFF !important;
            font-size: 20px;
            transition: transform 0.3s ease;
        }

        .cart-nav-item .nav-link:hover {
            transform: scale(1.1);
        }

        .profile-menu .dropdown-menu a {
            color: #fff;
            padding: 10px 20px;
            display: block;
        }

        .profile-menu .dropdown-menu a:hover {
            background-color: #17a2b8;
        }

        .profile-name {
            font-size: 1.2rem;
            font-weight: bold;
            text-align: center;
            margin-bottom: 10px;
        }

        .profile-balance {
            padding: 10px;
            color: #fff;
            text-align: center;
            font-size: 1.2rem;
            margin-bottom: 15px;
        }

        .container {
            padding: 10px;
        }

        .post {
            background-color: #fff;
            border-radius: 10px;
            padding: 20px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            margin-bottom: 20px;
        }

        .post h4 {
            font-size: 1.25rem;
            margin-bottom: 10px;
        }

        .post p {
            font-size: 1rem;
            margin-bottom: 10px;
        }

        .post .author-info {
            font-size: 0.9rem;
            color: #888;
        }

        .post .content {
            margin-top: 10px;
            font-size: 1rem;
            color: #333;
        }

        .post .actions {
            margin-top: 15px;
        }

        .post .actions .btn {
            margin-right: 10px;
        }

        .add-post {
            background-color: #fff;
            border-radius: 10px;
            padding: 20px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            margin-top: 20px;
        }

        .footer {
            background-color: #2c2c2c;
            color: #FFF;
            padding: 40px 0;
            text-align: center;
            margin-top: auto;
        }

        .bottom-footer {
            background-color: #1a1a1a;
            padding: 15px 0;
            color: #bbb;
            text-align: center;
        }

        /* Mobile responsiveness */
        @media (max-width: 768px) {
            .navbar-nav {
                flex-direction: column;
            }

            .navbar-nav .nav-link {
                width: 100%;
                margin-bottom: 10px;
            }

            .profile-menu .dropdown-toggle {
                min-width: 100%;
            }
        }
        .navbar-toggler {
        border: none;
    }

    .navbar-toggler-icon {
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='rgba%28255, 255, 255, 1%29' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
    }
    </style>
</head>
<body>
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="#">
            <img src="../assets/images/logo.png" alt="HostGoal Logo">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <li class="nav-item"><a class="nav-link" href="new_order.php">أطلب</a></li>
                <li class="nav-item"><a class="nav-link" href="services.php">منتجاتي</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">طلباتك</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">الفواتير</a></li>
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                        الدعم
                    </a>
                    <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                        <li><a class="dropdown-item" href="client_tickets.php">التذاكر</a></li>
                        <li><a class="dropdown-item" href="forum.php">المنتدى</a></li>
                        <li><a class="dropdown-item" href="q_and_a.php">Q&A</a></li>
                    </ul>
                </li>
            </ul>
            <li class="nav-item cart-nav-item">
                <a class="nav-link" href="/client/cart.php">
                    <i class="fas fa-shopping-cart"></i>
                </a>
            </li>
            <div class="dropdown profile-menu">
                <a class="btn btn-primary dropdown-toggle" href="#" role="button" id="dropdownMenuLink" data-bs-toggle="dropdown" aria-expanded="false">
                    <i class="fas fa-user"></i> <?php echo htmlspecialchars($username, ENT_QUOTES, 'UTF-8'); ?>
                </a>
                <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
                    <li class="profile-name"><?php echo htmlspecialchars($username, ENT_QUOTES, 'UTF-8'); ?></li>
                    <li class="profile-balance">الرصيد: $<?php echo number_format($balance, 2); ?></li>
                    <li><a class="dropdown-item" href="dashboard.php">لوحة التحكم</a></li>
                    <li><a class="dropdown-item" href="services.php">منتجاتي</a></li>
                    <li><a class="dropdown-item" href="profile.php">الإعدادات</a></li>
                                        <li><a class="dropdown-item" href="logout.php">تسجيل الخروج</a></li>

                </ul>
            </div>
        </div>
    </div>
</nav>

<div class="container">
    <h2>المنتدى</h2>
    <div class="row">
        <div class="col-md-8">
            <?php foreach ($posts as $post): ?>
                <div class="post">
                    <h4><?php echo htmlspecialchars($post['topic_title'], ENT_QUOTES); ?></h4>
                    <p><?php echo htmlspecialchars($post['description'], ENT_QUOTES); ?></p>
                    <small class="author-info">نشر بواسطة <?php echo htmlspecialchars($post['author'], ENT_QUOTES); ?> في <?php echo htmlspecialchars($post['category_name'], ENT_QUOTES); ?></small>
                    <p class="content"><?php echo htmlspecialchars($post['content'], ENT_QUOTES); ?></p>
                    <div class="actions">
                        <?php if ($_SESSION['user_id'] == $post['user_id']): ?>
                            <a href="edit_post.php?id=<?php echo $post['id']; ?>" class="btn btn-primary btn-sm">تعديل</a>
                            <button class="btn btn-danger btn-sm delete-btn" data-id="<?php echo $post['id']; ?>">حذف</button>
                        <?php endif; ?>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        <div class="col-md-4">
            <div class="add-post">
                <h3>إضافة منشور</h3>
                <form action="forum.php" method="POST">
                    <div class="form-group">
                        <label for="description">الوصف:</label>
                        <textarea id="description" name="description" class="form-control" required></textarea>
                    </div>
                    <div class="form-group">
                        <label for="content">المحتوى:</label>
                        <textarea id="content" name="content" class="form-control" required></textarea>
                    </div>
                    <div class="form-group">
                        <label for="category">الفئة:</label>
                        <select id="category" name="category" class="form-control" required>
                            <option value="">اختر الفئة</option>
                            <?php foreach ($categories as $category): ?>
                                <option value="<?php echo $category['id']; ?>"><?php echo $category['name']; ?></option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="form-group">
                        <label for="topic">الموضوع:</label>
                        <select id="topic" name="topic" class="form-control" required>
                            <option value="">اختر الموضوع</option>
                        </select>
                    </div>
                    <button type="submit" class="btn btn-primary mt-2">إضافة منشور</button>
                </form>
            </div>
        </div>
    </div>
</div>

    <?php include 'footer.php'; ?>

<script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/sweetalert2@11/dist/sweetalert2.all.min.js"></script>

<script>
    $(document).ready(function() {
        $('#category').change(function() {
            var categoryId = $(this).val();
            if (categoryId) {
                $.ajax({
                    type: 'POST',
                    url: 'fetch_topics.php',
                    data: 'category_id=' + categoryId,
                    success: function(html) {
                        $('#topic').html(html);
                    }
                });
            } else {
                $('#topic').html('<option value="">اختر الفئة أولاً</option>');
            }
        });

        // Delete confirmation with animation
        $('.delete-btn').click(function(e) {
            e.preventDefault();
            var postId = $(this).data('id');
            Swal.fire({
                title: 'هل أنت متأكد؟',
                text: 'لن تتمكن من استعادة هذا المنشور بعد الآن!',
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#d33',
                cancelButtonColor: '#3085d6',
                confirmButtonText: 'نعم، احذفه!',
                cancelButtonText: 'إلغاء'
            }).then((result) => {
                if (result.isConfirmed) {
                    // Perform the deletion using an AJAX request
                    $.ajax({
                        url: 'delete_post.php',
                        type: 'POST',
                        data: {id: postId},
                        success: function(response) {
                            if (response === 'success') {
                                Swal.fire(
                                    'تم الحذف!',
                                    'تم حذف المنشور بنجاح.',
                                    'success'
                                ).then(() => {
                                    location.reload();
                                });
                            } else {
                                Swal.fire(
                                    'خطأ!',
                                    'حدث خطأ أثناء محاولة حذف المنشور.',
                                    'error'
                                );
                            }
                        }
                    });
                }
            });
        });
    });
</script>
</body>
</html>
