<?php
include('../config.php');
include('includes/auth.php');
require_once __DIR__.'/../client/dna.php';

session_start();

$user_id = $_SESSION['user_id'];

// Initialize Domain API
$dna = new \DomainNameApi\DomainNameAPI_PHPLibrary('hostgoal', '2719243214kK!');

// Function to load domain details
function loadDomainDetails($domain_name, $dna) {
    $domain_details = $dna->GetDetails($domain_name);
    if ($domain_details['result'] !== 'OK') {
        return null;
    }
    return $domain_details;
}

// Fetch user's balance
$stmt = $pdo->prepare("SELECT username, balance FROM users WHERE id = ?");
$stmt->execute([$user_id]);
$user = $stmt->fetch();
$username = $user['username'] ?? '';
$balance = $user['balance'] ?? 0;
$userBalance = $user['balance'] ?? 0;

// Fetch invoices for the user
$stmt = $pdo->prepare("SELECT * FROM orders WHERE user_id = ?");
$stmt->execute([$user_id]);
$invoices = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Initialize an array to store detailed invoice information
$invoiceDetails = [];
function suspendCpanelAccount($username, $pdo) {
    // Fetch WHM credentials from the active server
    $stmt = $pdo->prepare("SELECT whm_username, whm_api_token, whm_host FROM servers WHERE enabled = '1' LIMIT 1");
    $stmt->execute();
    $server = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$server) {
        // Log an error if no active server is found
        error_log("No active server found in the servers table.");
        return null;
    }

    // Use the fetched WHM credentials
    $whm_user = $server['whm_username'];
    $whm_token = $server['whm_api_token'];
    $whm_server = $server['server_url']; // Assuming server_url is stored in the servers table
    
    $url = "https://$whm_server:2087/json-api/suspendacct?api.version=1&user=$username";
    
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_HTTPHEADER, [
        "Authorization: whm $whm_user:$whm_token"
    ]);

    $response = curl_exec($curl);
    $http_status = curl_getinfo($curl, CURLINFO_HTTP_CODE);
    curl_close($curl);

    $decoded_response = json_decode($response, true);

    // Log the response for debugging
    error_log("WHM API Response: " . print_r($decoded_response, true));
    error_log("HTTP Status Code: " . $http_status);

    if ($http_status != 200) {
        // Log an error if the request failed
        error_log("Failed to connect to WHM API. HTTP Status: " . $http_status);
    }

    return $decoded_response;
}




foreach ($invoices as $invoice) {
    // Fetch order details for each invoice
    $stmt = $pdo->prepare("SELECT od.*, p.name, p.product_type, p.price_monthly, p.price_yearly, ua.username
                           FROM order_details od
                           JOIN products p ON od.product_id = p.id
                           LEFT JOIN user_accounts ua ON ua.product_id = p.id AND ua.user_id = ?
                           WHERE od.order_id = ?");
    $stmt->execute([$user_id, $invoice['id']]);
    $orderDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

    $details = [];
    foreach ($orderDetails as $detail) {
        $billingCycle = '';

        if ($detail['product_type'] === 'domain') {
            // Fetch domain details from user_products
            $stmt_user_product = $pdo->prepare("SELECT up.billing_cycle, up.domain_name, up.expire_date, up.id as user_product_id 
                                                FROM user_products up 
                                                WHERE up.product_id = ? AND up.order_id = ? AND up.user_id = ?");
            $stmt_user_product->execute([$detail['product_id'], $invoice['id'], $user_id]);
            $userProduct = $stmt_user_product->fetch(PDO::FETCH_ASSOC);

            if ($userProduct) {
                $billingCycle = $userProduct['billing_cycle'] . ' سنوات';

                // Extract TLD from domain name
                $domainNameParts = explode('.', $userProduct['domain_name']);
                $tld = end($domainNameParts);

                // Fetch the renewal price for the domain's TLD
                $stmt_domain_price = $pdo->prepare("SELECT renewal_price FROM domain_prices WHERE after_domain = ?");
                $stmt_domain_price->execute([$tld]);
                $renewPrice = $stmt_domain_price->fetchColumn();

                if ($renewPrice !== false) {
                    // Use the renewal price in the invoice
                    $detail['price'] = $renewPrice;

                    // Update the price in order details
                    $stmt_update_order_detail = $pdo->prepare("UPDATE order_details SET price = ? WHERE id = ?");
                    $stmt_update_order_detail->execute([$renewPrice, $detail['id']]);
                }

                // Check if the domain has expired
                $domain_details = loadDomainDetails($userProduct['domain_name'], $dna);

                if ($domain_details) {
                    $remaining_days = $domain_details['data']['Dates']['RemainingDays'];

                    if ($remaining_days <= 0) {
                        // Mark the domain as inactive
                        $stmt = $pdo->prepare("UPDATE orders SET status = 'unpaid' WHERE id = ?");
                        $stmt->execute([$invoice['id']]);

                        // Add a warning message to the session to notify the user
                        $_SESSION['invoice_notifications'][] = "النطاق " . htmlspecialchars($userProduct['domain_name'], ENT_QUOTES, 'UTF-8') . " قد انتهت صلاحيته. يرجى تجديده لتجنب فقدان النطاق.";
                    }
                }
            } else {
                $billingCycle = 'غير معروف';
            }
        } elseif ($detail['product_type'] === 'hosting') {
            // Determine the billing cycle based on the product price
            if ($detail['price'] == $detail['price_monthly']) {
                $billingCycle = 'شهري';
            } elseif ($detail['price'] == $detail['price_yearly']) {
                $billingCycle = 'سنوي';
            }

            // Activate hosting account if necessary
            if ($invoice['status'] === 'unpaid' && !empty($detail['username'])) {
$stmt = $pdo->prepare("UPDATE user_accounts SET status = 'suspended' WHERE product_id = ? AND user_id = ?");
                $stmt->execute([$detail['product_id'], $user_id]);
}
            else if ($invoice['status'] === 'paid') {
                $stmt = $pdo->prepare("UPDATE user_accounts SET status = 'active' WHERE product_id = ? AND user_id = ?");
                $stmt->execute([$detail['product_id'], $user_id]);
            }
            
        }

        $detail['billing_cycle'] = $billingCycle;
        $details[] = $detail;
    }

    // Calculate the new total price for the order based on updated details
    $newTotalPrice = array_sum(array_column($details, 'price'));

    // Update the total price in the orders table
    $stmt_update_order_total = $pdo->prepare("UPDATE orders SET total_price = ? WHERE id = ?");
    $stmt_update_order_total->execute([$newTotalPrice, $invoice['id']]);

    // Add invoice details to the array
    $invoiceDetails[$invoice['id']] = [
        'details' => $details,
        'total_price' => $newTotalPrice,
    ];

    // Calculate months since creation
    $createdDate = new DateTime($invoice['created_at']);
    $currentDate = new DateTime();
    $interval = $currentDate->diff($createdDate);
    $totalMonths = $interval->y * 12 + $interval->m;

    // Determine status based on billing cycle and time elapsed
    if ($billingCycle === 'شهري' && $totalMonths >= 1) {
        if ($invoice['status'] === 'paid') {
            $stmt = $pdo->prepare("UPDATE orders SET status = 'unpaid' WHERE id = ?");
            $stmt->execute([$invoice['id']]);
             header("Location: " . $_SERVER['PHP_SELF']);
        }
    } elseif ($billingCycle === 'سنوي' && $totalMonths >= 12) {
        if ($invoice['status'] === 'paid') {
            $stmt = $pdo->prepare("UPDATE orders SET status = 'unpaid' WHERE id = ?");
            $stmt->execute([$invoice['id']]);
             header("Location: " . $_SERVER['PHP_SELF']);
        }
    }
                   

}

// Function to get the total amount from the orders table
function getTotalAmount($invoiceId, $pdo) {
    $stmt = $pdo->prepare("SELECT total_price FROM orders WHERE id = ?");
    $stmt->execute([$invoiceId]);
    return $stmt->fetchColumn();
}

// Handle balance payment
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['pay_with_balance'])) {
    $invoiceId = $_POST['invoice_id'];
    $totalAmount = getTotalAmount($invoiceId, $pdo);

    if ($userBalance >= $totalAmount) {
        // Deduct the balance
        $newBalance = $userBalance - $totalAmount;
        $stmt = $pdo->prepare("UPDATE users SET balance = ? WHERE id = ?");
        $stmt->execute([$newBalance, $user_id]);


        // Redirect to update_invoice_status.php to process other actions (like domain renewal or hosting activation)
        header("Location: update_invoice_status.php?order_id=$invoiceId&status=paid");

        exit();
    } else {
        $_SESSION['invoice_notifications'][] = "رصيدك غير كافٍ لدفع الفاتورة.";
    }
}
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>الفواتير</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
     <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
     .profile-menu .dropdown-toggle {
        color: #fff;
        background-color: #17a2b8;
        border-radius: 30px;
        padding: 12px 24px;
        min-width: 180px;
    }

    .profile-menu .dropdown-menu {
        background-color: #2c2c2c;
        color: #fff;
        border-radius: 8px;
        width: 300px;
        padding: 20px;
    }

    .profile-menu .dropdown-menu a {
        color: #fff;
        padding: 10px 20px;
        display: block;
    }

    .profile-menu .dropdown-menu a:hover {
        background-color: #17a2b8;
    }

    .profile-name {
        font-size: 1.2rem;
        font-weight: bold;
        text-align: center;
        margin-bottom: 10px;
    }

    .profile-balance {
        padding: 10px;
        color: #fff;
        text-align: center;
        font-size: 1.2rem;
        margin-bottom: 15px;
    }

    /* Navbar */
    .navbar {
        background-color: #2c2c2c;
        padding: 10px 20px;
    }

    .navbar-brand {
        display: flex;
        align-items: center;
    }

    .navbar-brand img {
        margin-right: 10px;
    }

    .navbar-brand span {
        color: #fff;
        font-size: 20px;
    }

    .navbar-nav {
        text-align: center;
        flex-grow: 1;
        justify-content: center;
    }

    .navbar-nav .nav-item {
        margin: 0 15px;
    }

    .navbar-nav .nav-link {
        color: #FFF !important;
        font-size: 18px;
        padding: 10px 20px;
        background-color: #17a2b8;
        text-align: center;
        border-radius: 30px;
        transition: background-color 0.3s ease;
    }

    .navbar-nav .nav-link:hover {
        background-color: #0f8a8a;
    }

    .navbar-toggler {
        border: none;
    }

    .navbar-toggler-icon {
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='rgba%28255, 255, 255, 1%29' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
    }

    /* Cart */
    .cart-nav-item {
        margin-left: auto;
        display: flex;
        align-items: center;
    }

    .cart-nav-item .nav-link {
        padding: 10px 20px;
        background-color: transparent;
        color: #FFF !important;
        font-size: 20px;
        transition: transform 0.3s ease;
    }

    .cart-nav-item .nav-link:hover {
        transform: scale(1.1);
    }
button:hover {
    background-color: #0f8a8a;
}


    /* Responsive Navbar */
    @media (max-width: 1200px) {
        .navbar-nav .nav-link {
            padding: 8px 16px;
            font-size: 16px;
        }
    }

    @media (max-width: 992px) {
        .navbar-nav {
            flex-direction: column;
            width: 100%;
        }

        .navbar-nav .nav-link {
            width: 100%;
        }
    }

        body, html {
        font-family: 'Cairo', sans-serif;
        background-color: #f9f9f9;
        margin: 0;
        min-height: 100vh;
        display: flex;
        flex-direction: column;
    }
        
        .invoice-card {
            border: none;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
            transition: all 0.3s ease;
            padding: 20px;
            background-color: #fff;
            display: flex;
            flex-direction: column;
            justify-content: space-between;
        }
        .invoice-card:hover {
            transform: translateY(-10px);
            box-shadow: 0 8px 16px rgba(0, 0, 0, 0.2);
        }
        .invoice-header {
            display: flex;
            justify-content: space-between;
            margin-bottom: 20px;
        }
        .invoice-header h2 {
            font-size: 1.5rem;
            margin: 0;
            font-weight: 700;
        }
        .invoice-status {
            font-size: 1rem;
            font-weight: 700;
            padding: 5px 10px;
            border-radius: 5px;
            background-color: #f5f5f5;
            color: #fff;
        }
        .status-paid {
            background-color: #28a745;
        }
        .status-unpaid {
            background-color: #dc3545;
        }
        .invoice-details {
            margin-bottom: 20px;
        }
        .invoice-details p {
            margin: 0;
            font-size: 1rem;
        }
        .invoice-table {
            width: 100%;
            margin-bottom: 20px;
            border-collapse: collapse;
        }
        .invoice-table th,
        .invoice-table td {
            padding: 10px;
            text-align: left;
            border-bottom: 1px solid #dee2e6;
        }
        .invoice-table th {
            background-color: #f8f9fa;
            font-weight: 700;
        }
        .invoice-footer {
            display: flex;
            justify-content: space-between;
            align-items: center;
            margin-top: 20px;
        }
        .invoice-footer .total-amount {
            font-size: 1.25rem;
            font-weight: 700;
            color: #000;
        }
        .paypal-button-container,
        .balance-button-container {
            margin-top: 15px;
        }
        .container {
            padding: 10px;
        }
        .balance-button-container button {
            background-color: #ffc107;
            color: #fff;
            border: none;
            padding: 10px 20px;
            border-radius: 5px;
            font-size: 1rem;
            cursor: pointer;
            margin-left: 10px; /* Added spacing between buttons */
        }
        .balance-button-container button:hover {
            background-color: #e0a800;
        }
        .alert {
            border-radius: 8px;
            margin-bottom: 30px;
        }
        .alert h4 {
            font-size: 1.25rem;
            margin-bottom: 10px;
        }
        .alert ul {
            padding-left: 20px;
            list-style-type: disc;
        }
        .footer {
        background-color: #2c2c2c;
        color: #FFF;
        padding: 40px 0;
        text-align: center;
        margin-top: auto;
    }

    .bottom-footer {
        background-color: #1a1a1a;
        padding: 15px 0;
        color: #bbb;
        text-align: center;
    }
     @media (max-width: 768px) {
            .invoice-card {
                margin-bottom: 20px;
                padding: 15px;
            }

            .invoice-header h2 {
                font-size: 1rem;
            }

            .invoice-status {
                font-size: 0.8rem;
            }

            .invoice-details p {
                font-size: 0.8rem;
            }

            .total-amount {
                font-size: 0.9rem;
            }

            .balance-button-container button {
                padding: 8px 12px;
            }
        }
    </style>
</head>
<body>
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="#">
            <img src="../assets/images/logo.png" alt="HostGoal Logo" style="height: 40px;">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <li class="nav-item"><a class="nav-link" href="new_order.php">أطلب</a></li>
                <li class="nav-item"><a class="nav-link" href="services.php">منتجاتي</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">طلباتك</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">الفواتير</a></li>
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">
                        الدعم
                    </a>
                    <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                        <li><a class="dropdown-item" href="client_tickets.php">التذاكر</a></li>
                        <li><a class="dropdown-item" href="forum.php">المجتمع</a></li>
                        <li><a class="dropdown-item" href="q_and_a.php">Q&A</a></li>
                    </ul>
                </li>
            </ul>
            <li class="nav-item cart-nav-item">
                <a class="nav-link" href="/client/cart.php">
                    <i class="fas fa-shopping-cart"></i>
                </a>
            </li>
            <div class="dropdown profile-menu">
                <a class="btn btn-primary dropdown-toggle" href="#" role="button" id="dropdownMenuLink" data-bs-toggle="dropdown" aria-expanded="false">
                    <i class="fas fa-user"></i> <?php echo htmlspecialchars($username, ENT_QUOTES, 'UTF-8'); ?>
                </a>
                <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
                    <li class="profile-name"><?php echo htmlspecialchars($username, ENT_QUOTES, 'UTF-8'); ?></li>
                    <li class="profile-balance">الرصيد: $<?php echo number_format($balance, 2); ?></li>
                    <li><a class="dropdown-item" href="dashboard.php">لوحة التحكم</a></li>
                    <li><a class="dropdown-item" href="services.php">منتجاتي</a></li>
                    <li><a class="dropdown-item" href="profile.php">الإعدادات</a></li>
                                        <li><a class="dropdown-item" href="logout.php">تسجيل الخروج</a></li>

                </ul>
            </div>
        </div>
    </div>
</nav>
    <div class="container">
        <h2 class="mb-4">الفواتير</h2>
        <?php if (isset($_SESSION['api_responses']) && !empty($_SESSION['api_responses'])) : ?>
            <div class="alert alert-info">
                <h4>نتائج تجديد النطاق:</h4>
                <ul>
                    <?php foreach ($_SESSION['api_responses'] as $response) : ?>
                        <li><strong>يرجى التواصل مع الدعم الفني وفتح تذكرة</strong></li>
                    <?php endforeach; ?>
                </ul>
            </div>
            <?php unset($_SESSION['api_responses']); ?>
        <?php endif; ?>
        <?php if (isset($_SESSION['invoice_notifications'])): ?>
            <div class="alert alert-warning">
                <?php foreach ($_SESSION['invoice_notifications'] as $notification): ?>
                    <p><?php echo $notification; ?></p>
                <?php endforeach; ?>
                <?php unset($_SESSION['invoice_notifications']); ?>
            </div>
        <?php endif; ?>
        <div class="row">
            <?php foreach ($invoices as $invoice) : ?>
                <div class="col-md-6 col-lg-4 mb-4">
                    <div class="invoice-card">
                        <div class="invoice-header">
                            <h2>فاتورة رقم <?php echo htmlspecialchars($invoice['id'], ENT_QUOTES, 'UTF-8'); ?></h2>
                            <span class="invoice-status status-<?php echo $invoice['status'] == 'paid' ? 'paid' : 'unpaid'; ?>"><?php echo htmlspecialchars($invoice['status'] == 'paid' ? 'مدفوعة' : 'غير مدفوعة', ENT_QUOTES, 'UTF-8'); ?></span>
                        </div>
                        <div class="invoice-details">
                            <p>المجموع: $<?php echo htmlspecialchars($invoiceDetails[$invoice['id']]['total_price'], ENT_QUOTES, 'UTF-8'); ?></p>
                            <p>عدد المنتجات: <?php echo count($invoiceDetails[$invoice['id']]['details']); ?></p>
                            <p>تاريخ الإنشاء: <?php echo htmlspecialchars($invoice['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                        </div>
                        <table class="invoice-table">
                            <thead>
                                <tr>
                                    <th>المنتج</th>
                                    <th>السعر</th>
                                    <th>الدورة</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($invoiceDetails[$invoice['id']]['details'] as $detail) : ?>
                                    <tr>
                                        <td><?php echo htmlspecialchars($detail['name'], ENT_QUOTES, 'UTF-8'); ?></td>
                                        <td>$<?php echo htmlspecialchars($detail['price'], ENT_QUOTES, 'UTF-8'); ?></td>
                                        <td><?php echo htmlspecialchars($detail['billing_cycle'], ENT_QUOTES, 'UTF-8'); ?></td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                        <div class="invoice-footer">
                            <span class="total-amount">الإجمالي: $<?php echo htmlspecialchars($invoiceDetails[$invoice['id']]['total_price'], ENT_QUOTES, 'UTF-8'); ?></span>
                            <div class="payment-buttons">
                                <?php if ($invoice['status'] == 'unpaid') : ?>
                                    <div class="paypal-button-container" id="paypal-button-container-<?php echo $invoice['id']; ?>"></div>
                                    <div class="balance-button-container">
                                        <form method="POST">
                                            <input type="hidden" name="invoice_id" value="<?php echo htmlspecialchars($invoice['id'], ENT_QUOTES, 'UTF-8'); ?>">
                                            <button type="submit" name="pay_with_balance">الدفع من الرصيد</button>
                                            <div class="balance-info">
                                                <p>الرصيد الحالي: $<?php echo htmlspecialchars($userBalance, ENT_QUOTES, 'UTF-8'); ?></p>
                                            </div>
                                        </form>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Invoice Details Modal -->
                <div class="modal fade" id="invoiceModal<?php echo $invoice['id']; ?>" tabindex="-1" role="dialog" aria-labelledby="invoiceModalLabel<?php echo $invoice['id']; ?>" aria-hidden="true">
                    <div class="modal-dialog" role="document">
                        <div class="modal-content">
                            <div class="modal-header">
                                <h5 class="modal-title" id="invoiceModalLabel<?php echo $invoice['id']; ?>">تفاصيل الفاتورة</h5>
                                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                                    <span aria-hidden="true">&times;</span>
                                </button>
                            </div>
                            <div class="modal-body">
                                <p>الحالة: <span class="status-<?php echo $invoice['status'] == 'paid' ? 'paid' : 'unpaid'; ?>"><?php echo htmlspecialchars($invoice['status'], ENT_QUOTES, 'UTF-8'); ?></span></p>
                                <?php if (count($invoiceDetails[$invoice['id']]['details']) > 0) : ?>
                                    <h6>تفاصيل المنتجات</h6>
                                    <ul class="product-detail-list">
                                        <?php foreach ($invoiceDetails[$invoice['id']]['details'] as $detail) : ?>
                                            <li><?php echo htmlspecialchars($detail['name'], ENT_QUOTES, 'UTF-8'); ?> - $<?php echo htmlspecialchars($detail['price'], ENT_QUOTES, 'UTF-8'); ?> (<?php echo htmlspecialchars($detail['billing_cycle'], ENT_QUOTES, 'UTF-8'); ?>)</li>
                                        <?php endforeach; ?>
                                    </ul>
                                <?php endif; ?>
                                <p>تاريخ الإنشاء: <?php echo htmlspecialchars($invoice['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                            </div>
                            <div class="modal-footer">
                                <button type="button" class="btn btn-secondary" data-dismiss="modal">إغلاق</button>
                            </div>
                        </div>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
    </div>
    <?php include 'footer.php'; ?>

     <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://www.paypal.com/sdk/js?client-id=ARk_oSf0EtN4fiB5LRucpzAKp21O3Ca_lmA-2MHNzwQHRK2GE2ZMxU0vJ9JaUT4kDRS2jXjc9q04AnNN&currency=USD"></script>
    <script>
    document.addEventListener('DOMContentLoaded', function() {
    <?php foreach ($invoices as $invoice) : ?>
        <?php if ($invoice['status'] == 'unpaid') : ?>
            paypal.Buttons({
                createOrder: function(data, actions) {
                    let totalAmount = <?php echo getTotalAmount($invoice['id'], $pdo); ?>;
                    return actions.order.create({
                        purchase_units: [{
                            amount: {
                                value: totalAmount.toFixed(2) // Ensure the value is a string with two decimal places
                            }
                        }]
                    });
                },
                onApprove: function(data, actions) {
                    return actions.order.capture().then(function(details) {
                        alert('تم معالجة الدفع بنجاح من قبل ' + details.payer.name.given_name);
                        
                        setTimeout(function() {
                            window.location.href = 'update_invoice_status.php?order_id=<?php echo $invoice['id']; ?>&status=paid';
                        }, 1000);
                    });
                },
                disableFunding: 'credit,card'
            }).render('#paypal-button-container-<?php echo $invoice['id']; ?>');
        <?php endif; ?>
    <?php endforeach; ?>
});
    </script>

</body>
</html>