<?php
// client/login.php
include('../config.php');
session_start();
if (isset($_SESSION['user_id'])) {
    header('Location: dashboard.php');
    exit();
}

// Enable error reporting
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Include autoload.php from the correct path
require_once __DIR__ . '/../vendor/autoload.php';

// Standard login flow
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $usernameOrEmail = $_POST['username_or_email'];
    $password = $_POST['password'];

    $stmt = $pdo->prepare("SELECT * FROM users WHERE username = ? OR email = ?");
    $stmt->execute([$usernameOrEmail, $usernameOrEmail]);
    $user = $stmt->fetch();

    if ($user && password_verify($password, $user['password']) && $user['verified'] == 1) {
        // Set session variables
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['role'] = $user['role'];

        // Log the login event
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $stmt = $pdo->prepare("INSERT INTO login_history (user_id, ip_address) VALUES (?, ?)");
        $stmt->execute([$user['id'], $ip_address]);

        // Update last IP address
        $stmt = $pdo->prepare("UPDATE users SET last_ip = ? WHERE id = ?");
        $stmt->execute([$ip_address, $user['id']]);

        header('Location: dashboard.php');
        exit();
    } else {
        $error_message = "اسم المستخدم/البريد الإلكتروني أو كلمة المرور غير صحيحة، أو لم يتم التحقق من الحساب.";
    }
} elseif (isset($_GET['token'])) {
    // Handle auto-login with token
    $autologinToken = $_GET['token'];

    // Verify the autologin token
    $stmt = $pdo->prepare("SELECT * FROM users WHERE autologin_token = ?");
    $stmt->execute([$autologinToken]);
    $user = $stmt->fetch();

    if ($user) {
        // Clear the autologin token after use
        $stmt = $pdo->prepare("UPDATE users SET autologin_token = NULL WHERE id = ?");
        $stmt->execute([$user['id']]);

        // Set session variables
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['role'] = $user['role'];

        // Log the login event
        $ip_address = $_SERVER['REMOTE_ADDR'];
        $stmt = $pdo->prepare("INSERT INTO login_history (user_id, ip_address) VALUES (?, ?)");
        $stmt->execute([$user['id'], $ip_address]);

        // Update last IP address
        $stmt = $pdo->prepare("UPDATE users SET last_ip = ? WHERE id = ?");
        $stmt->execute([$ip_address, $user['id']]);

        // Redirect to client dashboard
        header('Location: dashboard.php');
        exit();
    } else {
        $error_message = "رمز تسجيل الدخول التلقائي غير صالح أو منتهي الصلاحية.";
    }
}
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>تسجيل الدخول</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link rel="stylesheet" href="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/css/bootstrap.min.css">
    <link rel="stylesheet" href="/assets/css/styles.css?version=1">
    <style>
        body {
            font-family: 'Cairo', sans-serif;
            background-color: #f8f9fa;
        }
        .container {
            max-width: 500px;
            margin-top: 50px;
        }
        .form-container {
            background-color: #fff;
            padding: 30px;
            border-radius: 10px;
            box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);
        }
        .form-container h2 {
            margin-bottom: 20px;
            font-weight: 700;
        }
        .form-container .form-group input {
            margin-bottom: 15px;
        }
        .register-link, .forgot-link {
            display: block;
            margin-top: 10px;
            text-align: center;
        }
        .error-message {
            color: red;
            margin-bottom: 15px;
        }
        .google-btn {
            display: flex;
            align-items: center;
            justify-content: center;
            width: 100%;
            height: 50px;
            margin-top: 20px;
            background-color: #4285F4;
            color: white;
            border: none;
            border-radius: 5px;
            font-size: 16px;
            font-weight: bold;
            cursor: pointer;
            transition: background-color 0.3s ease;
            text-decoration: none;
        }
        .google-btn:hover {
            background-color: #357ae8;
        }
        .google-btn img {
            height: 20px;
            margin-right: 10px;
        }
    </style>
</head>
<body>
    <nav>
        <?php include 'nav2.php'; ?>
    </nav>
    <script src="https://accounts.google.com/gsi/client" async></script>
    <script>
    function handleCredentialResponse(response) {
        fetch("auth_init.php", {
            method: "POST",
            headers: { "Content-Type": "application/json" },
            body: JSON.stringify({ request_type: 'user_auth', credential: response.credential }),
        })
        .then(response => response.json())
        .then(data => {
            if (data.status == 1) {
                // Successful authentication
                window.location.href = data.redirect_url; // Redirect to the URL returned from the server
            } else {
                // Handle errors
                console.error('Authentication failed:', data.error || 'Unknown error');
                alert('فشل في المصادقة: ' + (data.error || 'خطأ غير معروف'));
            }
        })
        .catch(console.error);
    }
    </script>
    <div class="container">
        <div class="form-container">
            <h2>تسجيل الدخول</h2>
            <form action="login.php" method="POST">
                <?php if (isset($error_message)): ?>
                    <p class="error-message"><?php echo htmlspecialchars($error_message, ENT_QUOTES, 'UTF-8'); ?></p>
                <?php endif; ?>
                <div class="form-group">
                    <label for="username_or_email">اسم المستخدم أو البريد الإلكتروني</label>
                    <input type="text" class="form-control" name="username_or_email" placeholder="اسم المستخدم أو البريد الإلكتروني" required>
                </div>
                <div class="form-group">
                    <label for="password">كلمة المرور</label>
                    <input type="password" class="form-control" name="password" placeholder="كلمة المرور" required>
                </div>
                <button type="submit" class="btn btn-primary btn-block">تسجيل الدخول</button>
                <a href="register.php" class="register-link">ليس لديك حساب؟ سجل هنا</a>
                <a href="forgot_password.php" class="forgot-link">نسيت كلمة المرور؟</a>
                <div id="g_id_onload"
                    data-client_id="352207058673-2tpub3pss0a6515gjhdo5tmiqttp05nc.apps.googleusercontent.com"
                    data-context="signin"
                    data-ux_mode="popup"
                    data-callback="handleCredentialResponse"
                    data-auto_prompt="false">
                </div>
                <div class="g_id_signin"
                    data-type="standard"
                    data-shape="rectangular"
                    data-theme="filled_blue"
                    data-text="signin_with"
                    data-size="small"
                    data-logo_alignment="left">
                </div>
            </form>
        </div>
    </div>
    <footer class="footer mt-4">
        <?php include 'footer.php'; ?>
    </footer>
</body>
</html>
