<?php
session_start();
include('../config.php');
require_once __DIR__.'/../client/dna.php';
use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

require '../vendor/autoload.php';

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die('معرف النطاق غير صالح.');
}

$domain_id = $_GET['id'];

$stmt = $pdo->prepare("SELECT up.id as user_product_id, up.domain_name, up.billing_cycle, up.epp_code, up.order_id, 
                                up.purchase_date, up.expire_date, 
                                p.id as product_id, p.name, p.description, p.internal_name
                         FROM user_products up
                         JOIN products p ON up.product_id = p.id
                         WHERE up.id = ?");
$stmt->execute([$domain_id]);
$domain = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$domain) {
    die('النطاق غير موجود.');
}

// Fetch the price from order_details using order_id and product_id
$order_details_stmt = $pdo->prepare("SELECT price FROM order_details WHERE order_id = ? AND product_id = ?");
$order_details_stmt->execute([$domain['order_id'], $domain['product_id']]);
$order_details = $order_details_stmt->fetch(PDO::FETCH_ASSOC);

$price = $order_details ? $order_details['price'] : 'غير متاح';

$username = 'hostgoal';
$password = '2719243214kK!';

$dna = new \DomainNameApi\DomainNameAPI_PHPLibrary($username, $password);

function loadDomainDetails($domain_name, $dna) {
    global $domain_details, $contacts, $remaining_days;
    $domain_details = $dna->GetDetails($domain_name);

    if ($domain_details['result'] !== 'OK') {
        die('فشل في استرجاع تفاصيل النطاق.');
    }

    $remaining_days = $domain_details['data']['Dates']['RemainingDays'];

    $contacts = $dna->GetContacts($domain_name);
    return $domain_details;
}

// Load domain details initially
$domain_details = loadDomainDetails($domain['domain_name'], $dna);

$domain_status = $domain_details['data']['Status'];
$auth_code = $domain_details['data']['AuthCode'];
$lock_status = $domain_details['data']['LockStatus'];
$privacy_protection_status = $domain_details['data']['PrivacyProtectionStatus'];
$name_servers = $domain_details['data']['NameServers'];
$dates = $domain_details['data']['Dates'];
$remaining_days = $dates['RemainingDays'];
$registrant = $contacts['data']['contacts']['Registrant'];

// TLD check for privacy protection support
$tld_supported = in_array(pathinfo($domain['domain_name'], PATHINFO_EXTENSION), ['com', 'net']);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    $domain_name = $domain['domain_name'];

    if (isset($_POST['update_nameservers'])) {
        $nameserver1 = $_POST['nameserver1'];
        $nameserver2 = $_POST['nameserver2'];

        $ns_change = $dna->ModifyNameServer($domain_name, [
            'ns1' => $nameserver1,
            'ns2' => $nameserver2
        ]);

        if ($ns_change['result'] === 'OK') {
            $_SESSION['message'] = "<div class='alert alert-success'>تم تحديث خوادم الأسماء بنجاح.</div>";
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>فشل في تحديث خوادم الأسماء. الرجاء المحاولة لاحقاً.</div>";
        }
        $domain_details = loadDomainDetails($domain_name, $dna);
        header("Location: " . $_SERVER['PHP_SELF'] . "?id=" . $_GET['id']);
        exit();
    }

    if (isset($_POST['set_default_nameservers'])) {
        // Fetch default nameservers from the settings table
        $settings_stmt = $pdo->prepare("SELECT nameserver1, nameserver2 FROM settings WHERE id = 1");
        $settings_stmt->execute();
        $settings = $settings_stmt->fetch(PDO::FETCH_ASSOC);

        // Perform the nameserver update using the default values
        $ns_change = $dna->ModifyNameServer($domain_name, [
            'ns1' => $settings['nameserver1'],
            'ns2' => $settings['nameserver2']
        ]);

        if ($ns_change['result'] === 'OK') {
            $_SESSION['message'] = "<div class='alert alert-success'>تم تعيين خوادم الأسماء الافتراضية بنجاح.</div>";
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>فشل في تعيين خوادم الأسماء الافتراضية. الرجاء المحاولة لاحقاً.</div>";
        }
        $domain_details = loadDomainDetails($domain_name, $dna);
        header("Location: " . $_SERVER['PHP_SELF'] . "?id=" . $_GET['id']);
        exit();
    }

    if (isset($_POST['toggle_privacy']) && $tld_supported) {
        $privacy_protection_status = !$privacy_protection_status;

        $privacy_change = $dna->ModifyPrivacyProtectionStatus($domain_name, $privacy_protection_status, 'Optional owner comment');

        if ($privacy_change['result'] === 'OK') {
            $_SESSION['message'] = "<div class='alert alert-success'>تم تحديث حماية الخصوصية بنجاح.</div>";
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>فشل في تحديث الحماية. الرجاء المحاولة لاحقاً.</div>";
        }
        $domain_details = loadDomainDetails($domain_name, $dna);
        header("Location: " . $_SERVER['PHP_SELF'] . "?id=" . $_GET['id']);
        exit();
    }

    if (isset($_POST['toggle_protection'])) {
        if ($lock_status === 'true') {
            $lock = $dna->DisableTheftProtectionLock($domain_name);
            $_SESSION['message'] = "<div class='alert alert-success'>تم تعطيل حماية النقل بنجاح.</div>";
        } else {
            $lock = $dna->EnableTheftProtectionLock($domain_name);
            $_SESSION['message'] = "<div class='alert alert-success'>تم تفعيل حماية النقل بنجاح.</div>";
        }
        $domain_details = loadDomainDetails($domain_name, $dna);
        header("Location: " . $_SERVER['PHP_SELF'] . "?id=" . $_GET['id']);
        exit();
    }

    if (isset($_POST['send_epp'])) {
        $user_id = $_SESSION['user_id'];

        $stmt = $pdo->prepare("SELECT email FROM users WHERE id = ?");
        $stmt->execute([$user_id]);
        $user = $stmt->fetch(PDO::FETCH_ASSOC);

        if ($user) {
            $email = $user['email'];

            $mail = new PHPMailer(true);

            try {
                $mail->isSMTP();
                $mail->Host       = 'mail.hostgoal.net';
                $mail->SMTPAuth   = true;
                $mail->Username   = 'help@hostgoal.net';
                $mail->Password   = '2719243214kK';
                $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
                $mail->Port       = 465;

                $mail->setFrom('help@hostgoal.net', 'Host Goal Support');
                $mail->addAddress($email);

                $mail->isHTML(true);
                $mail->Subject = 'Your Auth/EPP Code for ' . $domain['domain_name'];

                $mail->Body = "
                    <html lang='ar'>
                    <head>
                        <meta charset='UTF-8'>
                        <meta name='viewport' content='width=device-width, initial-scale=1.0'>
                        <style>
                            body { font-family: Arial, sans-serif; background-color: #f4f4f4; color: #333; line-height: 1.6; }
                            .container { max-width: 600px; margin: 20px auto; background: #fff; padding: 20px; border-radius: 8px; box-shadow: 0 0 10px rgba(0, 0, 0, 0.1); }
                            h1 { color: #15B1B1; font-size: 24px; margin-bottom: 20px; }
                            p { font-size: 16px; margin-bottom: 20px; }
                            .code-box { background: #f8f9fa; border: 1px solid #ddd; padding: 10px; font-size: 18px; font-weight: bold; color: #333; text-align: center; border-radius: 5px; margin-bottom: 20px; }
                            .footer { text-align: center; font-size: 14px; color: #777; margin-top: 30px; }
                        </style>
                    </head>
                    <body>
                        <div class='container'>
                            <h1>Auth/EPP Code for Your Domain</h1>
                            <p>We have generated the Auth/EPP code for your domain <strong>{$domain['domain_name']}</strong>. This code is required if you wish to transfer your domain to another registrar.</p>
                            <div class='code-box'>{$auth_code}</div>
                            <p>Please keep this code secure, as it allows the transfer of your domain.</p>
                            <p>If you did not request this code or have any questions, please contact our support team immediately.</p>
                            <div class='footer'>Best regards,<br>HostGoal Support Team</div>
                        </div>
                    </body>
                    </html>
                ";

                $mail->send();
                $_SESSION['message'] = "<div class='alert alert-success'>تم إرسال كود EPP إلى بريدك الإلكتروني.</div>";
            } catch (Exception $e) {
                $_SESSION['message'] = "<div class='alert alert-danger'>Message could not be sent. Mailer Error: {$mail->ErrorInfo}</div>";
            }
        }
        $domain_details = loadDomainDetails($domain_name, $dna);
        header("Location: " . $_SERVER['PHP_SELF'] . "?id=" . $_GET['id']);
        exit();
    }
}

if ($remaining_days <= 0) {
    // Mark the domain as inactive
    $domain_status = 'Inactive';

    // Mark the order as unpaid
    $stmt = $pdo->prepare("UPDATE orders SET status = 'unpaid' WHERE id = ?");
    $stmt->execute([$domain['order_id']]);

    // Notify user via email (Optional)
    $stmt = $pdo->prepare("SELECT email FROM users WHERE id = ?");
    $stmt->execute([$_SESSION['user_id']]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if ($user) {
        $email = $user['email'];
        $mail = new PHPMailer(true);

        try {
            $mail->isSMTP();
            $mail->Host       = 'mail.hostgoal.net';
            $mail->SMTPAuth   = true;
            $mail->Username   = 'help@hostgoal.net';
            $mail->Password   = '2719243214kK';
            $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
            $mail->Port       = 465;

            $mail->setFrom('help@hostgoal.net', 'Host Goal Support');
            $mail->addAddress($email);

            $mail->isHTML(true);
            $mail->Subject = "Domain Expiry Notice: " . $domain['domain_name'];
            $mail->Body    = "<p>Your domain <strong>{$domain['domain_name']}</strong> has expired. Please renew it to avoid any disruption.</p><p>Best regards,<br>HostGoal Support Team</p>";

            $mail->send();
        } catch (Exception $e) {
            // Log email failure or take appropriate action
        }
    }
}
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>HostGoal - إدارة النطاق</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
       .container {
            padding: 10px;
        }
        body, html {
    font-family: 'Cairo', sans-serif;
    background-color: #f9f9f9;
    margin: 0;
    padding: 0;
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}


h1 {
    text-align: center;
    color: #333;
    margin-bottom: 30px;
    font-size: 28px;
    font-weight: bold;
}

.product-card {
    background-color: #ffffff;
    border-radius: 10px;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
    padding: 20px;
    margin-bottom: 20px;
    transition: transform 0.3s ease, box-shadow 0.3s ease;
}

.product-card h3 {
    font-size: 24px;
    color: #17a2b8;
    margin-bottom: 10px;
}

.product-card p {
    font-size: 16px;
    color: #555;
    line-height: 1.6;
}

.product-card:hover {
    transform: translateY(-5px);
    box-shadow: 0 8px 20px rgba(0, 0, 0, 0.15);
}

.form-group {
    margin-bottom: 20px;
}

.form-group label {
    font-weight: bold;
    color: #333;
    display: block;
    margin-bottom: 8px;
}

.form-group input[type="text"],
.form-group input[type="password"],
.form-group input[type="number"] {
    width: 100%;
    padding: 10px;
    border-radius: 5px;
    border: 1px solid #ced4da;
    box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.1);
    transition: border-color 0.3s ease, box-shadow 0.3s ease;
}

.form-group input[type="text"]:focus,
.form-group input[type="password"]:focus,
.form-group input[type="number"]:focus {
    border-color: #17a2b8;
    box-shadow: 0 0 8px rgba(23, 162, 184, 0.25);
    outline: none;
}

.submit-btn {
    background-color: #17a2b8;
    color: white;
    padding: 10px 20px;
    border-radius: 5px;
    border: none;
    font-size: 16px;
    font-weight: bold;
    cursor: pointer;
    transition: background-color 0.3s ease, box-shadow 0.3s ease;
    width: 100%;
    margin-top: 10px;
}

.submit-btn:hover {
    background-color: #138496;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
}

.disabled-btn {
    background-color: #e0e0e0;
    color: #a0a0a0;
    cursor: not-allowed;
}

.access-btn {
    background-color: #28a745;
    color: white;
    padding: 10px 15px;
    border-radius: 5px;
    font-size: 14px;
    text-decoration: none;
    display: inline-block;
    margin-top: 10px;
    transition: background-color 0.3s ease, box-shadow 0.3s ease;
}

.access-btn:hover {
    background-color: #218838;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
}

.alert {
    margin-bottom: 20px;
}

.alert-success {
    background-color: #d4edda;
    color: #155724;
    border-color: #c3e6cb;
    padding: 15px;
    border-radius: 5px;
}

.alert-danger {
    background-color: #f8d7da;
    color: #721c24;
    border-color: #f5c6cb;
    padding: 15px;
    border-radius: 5px;
}

.tab-pane {
    margin-top: 20px;
}

.tab-pane h3 {
    font-size: 22px;
    margin-bottom: 15px;
    color: #333;
}


        .navbar {
            background-color: #2c2c2c;
            padding: 10px 20px;
        }

        .navbar-brand {
            display: flex;
            align-items: center;
            color: white;
        }

        .navbar-brand img {
            height: 40px;
            margin-right: 10px;
        }

        .navbar-nav {
        text-align: center;
        flex-grow: 1;
        justify-content: center;
    }

    .navbar-nav .nav-item {
        margin: 0 15px;
    }
         .navbar-nav .nav-link {
        color: #FFF !important;
        font-size: 18px;
        padding: 10px 20px;
        background-color: #17a2b8;
        text-align: center;
        border-radius: 30px;
        transition: background-color 0.3s ease;
    }

        .navbar-nav .nav-link:hover {
            background-color: #0f8a8a;
        }

        .profile-container {
            margin: 50px auto;
            max-width: 600px;
            background-color: #fff;
            padding: 100px;
            border-radius: 10px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .profile-container h2 {
            font-size: 24px;
            margin-bottom: 20px;
            color: #333;
        }

        .profile-picture {
            width: 120px;
            height: 120px;
            border-radius: 50%;
            object-fit: cover;
            margin-bottom: 20px;
        }

        .form-container .form-group {
            text-align: right;
            margin-bottom: 15px;
        }
 .profile-menu .dropdown-toggle {
        color: #fff;
        background-color: #17a2b8;
        border-radius: 30px;
        padding: 12px 24px;
        min-width: 180px;
    }

    .profile-menu .dropdown-menu {
        background-color: #2c2c2c;
        color: #fff;
        border-radius: 8px;
        width: 300px;
        padding: 20px;
    }

    .profile-menu .dropdown-menu a {
        color: #fff;
        padding: 10px 20px;
        display: block;
    }

    .profile-menu .dropdown-menu a:hover {
        background-color: #17a2b8;
    }

    .profile-name {
        font-size: 1.2rem;
        font-weight: bold;
        text-align: center;
        margin-bottom: 10px;
    }
.navbar-toggler {
        border: none;
    }
button:hover {
    background-color: #0f8a8a;
}
    .navbar-toggler-icon {
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='rgba%28255, 255, 255, 1%29' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
    }
    .profile-balance {
        padding: 10px;
        color: #fff;
        text-align: center;
        font-size: 1.2rem;
        margin-bottom: 15px;
    }
         .cart-nav-item {
        margin-left: auto;
        display: flex;
        align-items: center;
    }

    .cart-nav-item .nav-link {
        padding: 10px 20px;
        background-color: transparent;
        color: #FFF !important;
        font-size: 20px;
        transition: transform 0.3s ease;
    }
/* Tabs */
    .nav-tabs .nav-link {
        font-size: 18px;
        background-color: #f8f9fa;
        border: 1px solid #dee2e6;
        margin-right: 5px;
        transition: background-color 0.3s ease;
    }

    .nav-tabs .nav-link.active {
        background-color: #17a2b8;
        color: white;
        border-color: #17a2b8;
    }

    /* Responsive Adjustments */
    @media (max-width: 768px) 

        .nav-tabs {
            justify-content: center;
        }

        .nav-tabs .nav-item {
            margin-bottom: 10px;
        }
    }
    .cart-nav-item .nav-link:hover {
        transform: scale(1.1);
    }
    button:hover {
    background-color: #0f8a8a;
}
    .loading-overlay {
            display: none;
            position: fixed;
            z-index: 9999;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(255, 255, 255, 0.8);
            pointer-events: none;
        }
 @media (max-width: 768px) {
            .domain-checker input[type="text"],
            .domain-checker select {
                width: 100%;
            }
        }
        .loading-overlay .spinner-wrapper {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
        }

        .custom-spinner {
            border: 8px solid rgba(0, 0, 0, 0.1);
            border-top: 8px solid #15B1B1;
            border-radius: 50%;
            width: 60px;
            height: 60px;
            animation: spin 1s linear infinite;
        }

        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        .footer {
        background-color: #2c2c2c;
        color: #FFF;
        padding: 40px 0;
        text-align: center;
        margin-top: auto;
    }

    .bottom-footer {
        background-color: #1a1a1a;
        padding: 15px 0;
        color: #bbb;
        text-align: center;
    }
    </style>
</head>
<body>
    <div class="loading-overlay">
        <div class="spinner-wrapper">
            <div class="custom-spinner"></div>
        </div>
    </div>
 <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>


    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="#">
            <img src="../assets/images/logo.png" alt="HostGoal Logo">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <li class="nav-item"><a class="nav-link" href="new_order.php">أطلب</a></li>
                <li class="nav-item"><a class="nav-link" href="services.php">منتجاتي</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">طلباتك</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">الفواتير</a></li>
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                        <li><a class="dropdown-item" href="client_tickets.php">التذاكر</a></li>
                        <li><a class="dropdown-item" href="forum.php">المجتمع</a></li>
                        <li><a class="dropdown-item" href="q_and_a.php">Q&A</a></li>
                    </ul>
                </li>
            </ul>
            <li class="nav-item cart-nav-item">
                <a class="nav-link" href="/client/cart.php">
                    <i class="fas fa-shopping-cart"></i>
                </a>
            </li>
            <div class="dropdown profile-menu">
                <a class="btn btn-primary dropdown-toggle" href="#" role="button" id="dropdownMenuLink" data-bs-toggle="dropdown" aria-expanded="false">
                    <i class="fas fa-user"></i> <?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?>
                </a>
                <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
                    <li class="profile-name"><?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?></li>
                    <li class="profile-balance">الرصيد: $<?php echo number_format($user['balance'], 2); ?></li>
                    <li><a class="dropdown-item" href="dashboard.php">لوحة التحكم</a></li>
                    <li><a class="dropdown-item" href="services.php">منتجاتي</a></li>
                    <li><a class="dropdown-item" href="profile.php">الإعدادات</a></li>
                                       <li><a class="dropdown-item" href="logout.php">تسجيل الخروج</a></li>

                </ul>
            </div>
        </div>
    </div>
</nav>
    <div class="container">
        <h1>إدارة النطاق: <?php echo htmlspecialchars($domain['domain_name'], ENT_QUOTES, 'UTF-8'); ?></h1>

        <ul class="nav nav-tabs" id="domainTabs" role="tablist">
            <li class="nav-item">
                <a class="nav-link active" id="nameserver-tab" data-toggle="tab" href="#nameserver" role="tab" aria-controls="nameserver" aria-selected="true">إدارة خوادم الأسماء</a>
            </li>
            <li class="nav-item">
                <a class="nav-link <?php echo !$tld_supported ? 'disabled-btn' : ''; ?>" id="whois-tab" data-toggle="tab" href="#whois" role="tab" aria-controls="whois" aria-selected="false">إدارة بيانات Whois</a>
            </li>
            <li class="nav-item">
                <a class="nav-link <?php echo !$tld_supported ? 'disabled-btn' : ''; ?>" id="privacy-tab" data-toggle="tab" href="#privacy" role="tab" aria-controls="privacy" aria-selected="false">حماية الخصوصية</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="lock-tab" data-toggle="tab" href="#lock" role="tab" aria-controls="lock" aria-selected="false">حماية النقل</a>
            </li>
            <li class="nav-item">
                <a class="nav-link" id="epp-tab" data-toggle="tab" href="#epp" role="tab" aria-controls="epp" aria-selected="false">إرسال كود EPP</a>
            </li>
        </ul>

        <div class="tab-content" id="domainTabContent">
            <!-- Nameserver Management -->
            <div class="tab-pane fade show active" id="nameserver" role="tabpanel" aria-labelledby="nameserver-tab">
                <form method="POST">
                    <div class="form-group">
                        <label for="nameserver1">خادم الأسماء 1</label>
                        <input type="text" name="nameserver1" class="form-control" value="<?php echo htmlspecialchars($name_servers['0'], ENT_QUOTES, 'UTF-8'); ?>" required>
                    </div>
                    <div class="form-group">
                        <label for="nameserver2">خادم الأسماء 2</label>
                        <input type="text" name="nameserver2" class="form-control" value="<?php echo htmlspecialchars($name_servers['1'], ENT_QUOTES, 'UTF-8'); ?>" required>
                    </div>
                    <button type="submit" name="update_nameservers" class="btn submit-btn">تحديث خوادم الأسماء</button>
                    <button type="submit" name="set_default_nameservers" class="btn submit-btn nameserver-btn">تعيين خوادم الأسماء الافتراضية</button>
                </form>
            </div>

            <!-- WHOIS Management -->
            <div class="tab-pane fade" id="whois" role="tabpanel" aria-labelledby="whois-tab">
                <div class="alert alert-info">هذه الميزة غير متوفرة حالياً.</div>
            </div>

            <!-- Privacy Protection Management -->
            <div class="tab-pane fade" id="privacy" role="tabpanel" aria-labelledby="privacy-tab">
                <form method="POST">
                    <div class="form-group">
                        <label>حماية الخصوصية</label>
                        <div>
                            <button type="submit" name="toggle_privacy" class="btn submit-btn">
                                <?php echo $privacy_protection_status ? 'تعطيل حماية الخصوصية' : 'تفعيل حماية الخصوصية'; ?>
                            </button>
                        </div>
                        <p>الحماية حالياً: <strong><?php echo $privacy_protection_status ? 'مفعلة' : 'معطلة'; ?></strong></p>
                    </div>
                </form>
            </div>

            <!-- Protection Lock Management -->
            <div class="tab-pane fade" id="lock" role="tabpanel" aria-labelledby="lock-tab">
                <form method="POST">
                    <div class="form-group">
                        <label>حماية النقل</label>
                        <div>
                            <button type="submit" name="toggle_protection" class="btn submit-btn">
                                <?php echo $lock_status === 'true' ? 'تعطيل حماية النقل' : 'تفعيل حماية النقل'; ?>
                            </button>
                        </div>
                        <p>الحماية حالياً: <strong><?php echo $lock_status === 'true' ? 'مفعلة' : 'معطلة'; ?></strong></p>
                    </div>
                </form>
            </div>

            <!-- EPP Code Sending -->
            <div class="tab-pane fade" id="epp" role="tabpanel" aria-labelledby="epp-tab">
                <form method="POST">
                    <div class="form-group">
                        <label>كود EPP</label>
                        <div>
                            <button type="submit" name="send_epp" class="btn submit-btn">إرسال كود EPP</button>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
    <?php include 'footer.php'; ?>

    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script>
        $(document).ready(function(){
            // Hide the spinner and make the page interactable after the page fully loads
            $(window).on('load', function() {
                $('.loading-overlay').fadeOut('slow', function() {
                    $(this).css('display', 'none');
                });
            });

            // Show the spinner and disable interaction when any form is submitted
            $('form').on('submit', function(){
                $('.loading-overlay').show();
                $('.loading-overlay').css('pointer-events', 'auto'); // Disable interactions
            });
        });
    </script>
</body>
</html>
