<?php 
session_start();
include('../config.php');

// Fetch WHM credentials from the servers table
class WHMAPI {
    private $whm_username;
    private $whm_api_token;
    private $whm_host;

    public function __construct($whm_username, $whm_api_token, $whm_host) {
        $this->whm_username = $whm_username;
        $this->whm_api_token = $whm_api_token;
        $this->whm_host = $whm_host;
    }

    private function sendRequest($endpoint, $params) {
        $url = "https://{$this->whm_host}:2087/json-api/{$endpoint}";
        $params['api.version'] = 1;

        $curl = curl_init();
        curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_HTTPHEADER, [
            "Authorization: whm {$this->whm_username}:{$this->whm_api_token}"
        ]);
        curl_setopt($curl, CURLOPT_URL, $url . '?' . http_build_query($params));

        $result = curl_exec($curl);
        if (curl_errno($curl)) {
            $error_msg = curl_error($curl);
            curl_close($curl);
            return ['error' => true, 'message' => $error_msg];
        }
        curl_close($curl);

        return json_decode($result, true);
    }

    public function listDomains($cpanel_username) {
        return $this->sendRequest('listdomains', [
            'user' => $cpanel_username
        ]);
    }

    public function installAutoSSL($domain) {
        return $this->sendRequest('install_autossl_certificate_for_domain', [
            'domain' => $domain
        ]);
    }
}

// Fetch WHM credentials from the servers table
$stmt = $pdo->prepare("SELECT whm_username, whm_api_token, whm_host FROM servers WHERE enabled = 1 LIMIT 1");
$stmt->execute();
$server = $stmt->fetch(PDO::FETCH_ASSOC);

if (!$server) {
    die('WHM credentials not found or no server is enabled.');
}

$whm_username = $server['whm_username'];
$whm_api_token = $server['whm_api_token'];
$whm_host = $server['whm_host'];

// Instantiate WHMAPI using credentials from the database
$whm = new WHMAPI($whm_username, $whm_api_token, $whm_host);

$user_id = $_SESSION['user_id'];
$stmt = $pdo->prepare("SELECT username, balance FROM users WHERE id = ?");
$stmt->execute([$user_id]);
$user = $stmt->fetch();
$username = $user['username'] ?? '';
$balance = $user['balance'] ?? 0;

if (isset($_GET['product_id']) && is_numeric($_GET['product_id'])) {
    $product_id = $_GET['product_id'];

    $stmt = $pdo->prepare("SELECT p.name, p.description, p.internal_name, ua.domain, ua.username as cpanel_username, ua.password, ua.created_at, ua.status
                           FROM products p
                           JOIN user_accounts ua ON p.id = ua.product_id
                           WHERE p.id = ? AND ua.user_id = ?");
    $stmt->execute([$product_id, $user_id]);
    $product = $stmt->fetch(PDO::FETCH_ASSOC);
    
$domains_response = $whm->listDomains($product['cpanel_username']);
    $domain_list = [];

    if (isset($domains_response['data']['main_domain'])) {
        $domain_list[] = $domains_response['data']['main_domain'];
    }

    if (!empty($domains_response['data']['addon_domains'])) {
        $domain_list = array_merge($domain_list, array_keys($domains_response['data']['addon_domains']));
    }

    if (!empty($domains_response['data']['sub_domains'])) {
        $domain_list = array_merge($domain_list, array_keys($domains_response['data']['sub_domains']));
    }

    if (!empty($domains_response['data']['parked_domains'])) {
        $domain_list = array_merge($domain_list, $domains_response['data']['parked_domains']);
    }
    if (!$product) {
        die('المنتج غير موجود أو ليس لديك إذن لإدارته.');
    }

    $stmt_order = $pdo->prepare("SELECT od.price, p.price_monthly, p.price_yearly, o.status as order_status
                                 FROM order_details od
                                 JOIN products p ON od.product_id = p.id
                                 JOIN orders o ON od.order_id = o.id
                                 WHERE od.product_id = ? AND o.user_id = ?");
    $stmt_order->execute([$product_id, $user_id]);
    $order_details = $stmt_order->fetch(PDO::FETCH_ASSOC);

    if ($order_details) {
    $price = $order_details['price'];

    // Determine the billing cycle based on the price
    if ($price == $order_details['price_monthly']) {
        $billing_cycle = 'شهري';
        $renewal_interval = '1 month'; // Set renewal interval for 1 month
    } elseif ($price == $order_details['price_yearly']) {
        $billing_cycle = 'سنوي';
        $renewal_interval = '1 year';  // Set renewal interval for 1 year
    } else {
        $billing_cycle = 'غير معروف';
        $renewal_interval = null;  // Unknown cycle
    }

    if ($renewal_interval) {
        // Calculate the next renewal date based on the billing cycle
        $created_at = new DateTime($product['created_at']);
        $next_renewal_date = clone $created_at;
        
        while ($next_renewal_date <= new DateTime()) {
            // Add the renewal interval repeatedly until the date exceeds the current date
            $next_renewal_date->modify("+$renewal_interval");
        }

        // Calculate days until the next renewal
        $current_date = new DateTime();
        $interval_to_renewal = $current_date->diff($next_renewal_date);
        $days_until_renewal = $interval_to_renewal->days;
    } else {
        $days_until_renewal = 'غير معروف';
    }
} else {
    $price = 'غير متاح';
    $billing_cycle = 'غير معروف';
    $days_until_renewal = 'غير معروف';
}


} else {
    die('معرف المنتج غير صالح.');
}

$is_paid = isset($order_details['order_status']) && $order_details['order_status'] === 'paid';

if (!$is_paid) {
    $days_until_renewal = 0;
    $product['status'] = 'غير نشط';
}

if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['update_password'])) {
    $new_password = $_POST['new_password'];

    if (strlen($new_password) < 8 || !preg_match('/[A-Z]/', $new_password) || !preg_match('/[a-z]/', $new_password) || !preg_match('/[0-9]/', $new_password)) {
        $_SESSION['message'] = "<div class='alert alert-danger'>يجب أن تكون كلمة المرور قوية (تتضمن أحرف كبيرة وصغيرة وأرقام وطولها لا يقل عن 8 أحرف).</div>";
    } else {
        $result = $whm->updatePassword($product['username'], $new_password);

        if (isset($result['metadata']['result']) && $result['metadata']['result'] == 1) {
            $hashed_password = password_hash($new_password, PASSWORD_BCRYPT);
            $stmt = $pdo->prepare("UPDATE user_accounts SET password = ? WHERE product_id = ? AND user_id = ?");
            $stmt->execute([$hashed_password, $product_id, $user_id]);

            $_SESSION['message'] = "<div class='alert alert-success'>تم تحديث كلمة المرور بنجاح.</div>";
        } else {
            $_SESSION['message'] = "<div class='alert alert-danger'>فشل في تحديث كلمة المرور. الرجاء المحاولة لاحقاً.</div>";
        }
    }

    header("Location: manage_host.php?product_id=" . $product_id);
    exit();
}

// Handling SSL/TLS Management
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['install_autossl'])) {
    $selected_domain = $_POST['selected_domain'];

    $result = $whm->installAutoSSL($selected_domain);

    if (isset($result['metadata']['result']) && $result['metadata']['result'] == 1) {
        $_SESSION['message'] = "<div class='alert alert-success'>تم تثبيت شهادة SSL بنجاح على النطاق: {$selected_domain}.</div>";
    } else {
        $_SESSION['message'] = "<div class='alert alert-danger'>فشل في تثبيت شهادة SSL. الرجاء المحاولة لاحقاً.</div>";
    }

    header("Location: manage_host.php?product_id=" . $product_id);
    exit();
}
?>

<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>HostGoal - إدارة المضيف</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">

    <style>
        .container {
            padding: 10px;
        }
        body, html {
    font-family: 'Cairo', sans-serif;
    background-color: #f9f9f9;
    margin: 0;
    padding: 0;
    display: flex;
    flex-direction: column;
    min-height: 100vh;
}


h1 {
    text-align: center;
    color: #333;
    margin-bottom: 30px;
    font-size: 28px;
    font-weight: bold;
}

.product-card {
    background-color: #ffffff;
    border-radius: 10px;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
    padding: 20px;
    margin-bottom: 20px;
    transition: transform 0.3s ease, box-shadow 0.3s ease;
}

.product-card h3 {
    font-size: 24px;
    color: #17a2b8;
    margin-bottom: 10px;
}

.product-card p {
    font-size: 16px;
    color: #555;
    line-height: 1.6;
}

.product-card:hover {
    transform: translateY(-5px);
    box-shadow: 0 8px 20px rgba(0, 0, 0, 0.15);
}

.form-group {
    margin-bottom: 20px;
}

.form-group label {
    font-weight: bold;
    color: #333;
    display: block;
    margin-bottom: 8px;
}

.form-group input[type="text"],
.form-group input[type="password"],
.form-group input[type="number"] {
    width: 100%;
    padding: 10px;
    border-radius: 5px;
    border: 1px solid #ced4da;
    box-shadow: inset 0 2px 4px rgba(0, 0, 0, 0.1);
    transition: border-color 0.3s ease, box-shadow 0.3s ease;
}

.form-group input[type="text"]:focus,
.form-group input[type="password"]:focus,
.form-group input[type="number"]:focus {
    border-color: #17a2b8;
    box-shadow: 0 0 8px rgba(23, 162, 184, 0.25);
    outline: none;
}

.submit-btn {
    background-color: #17a2b8;
    color: white;
    padding: 10px 20px;
    border-radius: 5px;
    border: none;
    font-size: 16px;
    font-weight: bold;
    cursor: pointer;
    transition: background-color 0.3s ease, box-shadow 0.3s ease;
    width: 100%;
    margin-top: 10px;
}

.submit-btn:hover {
    background-color: #138496;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
}

.disabled-btn {
    background-color: #e0e0e0;
    color: #a0a0a0;
    cursor: not-allowed;
}

.access-btn {
    background-color: #28a745;
    color: white;
    padding: 10px 15px;
    border-radius: 5px;
    font-size: 14px;
    text-decoration: none;
    display: inline-block;
    margin-top: 10px;
    transition: background-color 0.3s ease, box-shadow 0.3s ease;
}

.access-btn:hover {
    background-color: #218838;
    box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
}

.alert {
    margin-bottom: 20px;
}

.alert-success {
    background-color: #d4edda;
    color: #155724;
    border-color: #c3e6cb;
    padding: 15px;
    border-radius: 5px;
}

.alert-danger {
    background-color: #f8d7da;
    color: #721c24;
    border-color: #f5c6cb;
    padding: 15px;
    border-radius: 5px;
}

.tab-pane {
    margin-top: 20px;
}

.tab-pane h3 {
    font-size: 22px;
    margin-bottom: 15px;
    color: #333;
}


        .navbar {
            background-color: #2c2c2c;
            padding: 10px 20px;
        }

        .navbar-brand {
            display: flex;
            align-items: center;
            color: white;
        }

        .navbar-brand img {
            height: 40px;
            margin-right: 10px;
        }

        .navbar-nav {
        text-align: center;
        flex-grow: 1;
        justify-content: center;
    }

    .navbar-nav .nav-item {
        margin: 0 15px;
    }
         .navbar-nav .nav-link {
        color: #FFF !important;
        font-size: 18px;
        padding: 10px 20px;
        background-color: #17a2b8;
        text-align: center;
        border-radius: 30px;
        transition: background-color 0.3s ease;
    }

        .navbar-nav .nav-link:hover {
            background-color: #0f8a8a;
        }

        .profile-container {
            margin: 50px auto;
            max-width: 600px;
            background-color: #fff;
            padding: 100px;
            border-radius: 10px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .profile-container h2 {
            font-size: 24px;
            margin-bottom: 20px;
            color: #333;
        }

        .profile-picture {
            width: 120px;
            height: 120px;
            border-radius: 50%;
            object-fit: cover;
            margin-bottom: 20px;
        }

        .form-container .form-group {
            text-align: right;
            margin-bottom: 15px;
        }
 .profile-menu .dropdown-toggle {
        color: #fff;
        background-color: #17a2b8;
        border-radius: 30px;
        padding: 12px 24px;
        min-width: 180px;
    }

    .profile-menu .dropdown-menu {
        background-color: #2c2c2c;
        color: #fff;
        border-radius: 8px;
        width: 300px;
        padding: 20px;
    }

    .profile-menu .dropdown-menu a {
        color: #fff;
        padding: 10px 20px;
        display: block;
    }

    .profile-menu .dropdown-menu a:hover {
        background-color: #17a2b8;
    }

    .profile-name {
        font-size: 1.2rem;
        font-weight: bold;
        text-align: center;
        margin-bottom: 10px;
    }
.navbar-toggler {
        border: none;
    }
button:hover {
    background-color: #0f8a8a;
}
    .navbar-toggler-icon {
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='rgba%28255, 255, 255, 1%29' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
    }
    .profile-balance {
        padding: 10px;
        color: #fff;
        text-align: center;
        font-size: 1.2rem;
        margin-bottom: 15px;
    }
         .cart-nav-item {
        margin-left: auto;
        display: flex;
        align-items: center;
    }

    .cart-nav-item .nav-link {
        padding: 10px 20px;
        background-color: transparent;
        color: #FFF !important;
        font-size: 20px;
        transition: transform 0.3s ease;
    }
/* Tabs */
    .nav-tabs .nav-link {
        font-size: 18px;
        background-color: #f8f9fa;
        border: 1px solid #dee2e6;
        margin-right: 5px;
        transition: background-color 0.3s ease;
    }

    .nav-tabs .nav-link.active {
        background-color: #17a2b8;
        color: white;
        border-color: #17a2b8;
    }

    /* Responsive Adjustments */
    @media (max-width: 768px) 

        .nav-tabs {
            justify-content: center;
        }

        .nav-tabs .nav-item {
            margin-bottom: 10px;
        }
    }
    .cart-nav-item .nav-link:hover {
        transform: scale(1.1);
    }
    button:hover {
    background-color: #0f8a8a;
}
    .loading-overlay {
            display: none;
            position: fixed;
            z-index: 9999;
            top: 0;
            left: 0;
            width: 100%;
            height: 100%;
            background-color: rgba(255, 255, 255, 0.8);
            pointer-events: none;
        }
 @media (max-width: 768px) {
            .domain-checker input[type="text"],
            .domain-checker select {
                width: 100%;
            }
        }
        .loading-overlay .spinner-wrapper {
            position: absolute;
            top: 50%;
            left: 50%;
            transform: translate(-50%, -50%);
        }

        .custom-spinner {
            border: 8px solid rgba(0, 0, 0, 0.1);
            border-top: 8px solid #15B1B1;
            border-radius: 50%;
            width: 60px;
            height: 60px;
            animation: spin 1s linear infinite;
        }

        @keyframes spin {
            0% { transform: rotate(0deg); }
            100% { transform: rotate(360deg); }
        }
        
         .footer {
        background-color: #2c2c2c;
        color: #FFF;
        padding: 40px 0;
        text-align: center;
        margin-top: auto;
    }

    .bottom-footer {
        background-color: #1a1a1a;
        padding: 15px 0;
        color: #bbb;
        text-align: center;
    }
    </style>
</head>
<body>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>


    <script src="https://code.jquery.com/jquery-3.5.1.min.js"></script>
    
     <div class="loading-overlay">
        <div class="spinner-wrapper">
            <div class="custom-spinner"></div>
        </div>
    </div>
    <nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="#">
            <img src="../assets/images/logo.png" alt="HostGoal Logo">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <li class="nav-item"><a class="nav-link" href="new_order.php">أطلب</a></li>
                <li class="nav-item"><a class="nav-link" href="services.php">منتجاتي</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">طلباتك</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">الفواتير</a></li>
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                        <li><a class="dropdown-item" href="client_tickets.php">التذاكر</a></li>
                        <li><a class="dropdown-item" href="forum.php">المجتمع</a></li>
                        <li><a class="dropdown-item" href="q_and_a.php">Q&A</a></li>
                    </ul>
                </li>
            </ul>
            <li class="nav-item cart-nav-item">
                <a class="nav-link" href="/client/cart.php">
                    <i class="fas fa-shopping-cart"></i>
                </a>
            </li>
            <div class="dropdown profile-menu">
                <a class="btn btn-primary dropdown-toggle" href="#" role="button" id="dropdownMenuLink" data-bs-toggle="dropdown" aria-expanded="false">
                    <i class="fas fa-user"></i> <?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?>
                </a>
                <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
                    <li class="profile-name"><?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?></li>
                    <li class="profile-balance">الرصيد: $<?php echo number_format($user['balance'], 2); ?></li>
                    <li><a class="dropdown-item" href="dashboard.php">لوحة التحكم</a></li>
                    <li><a class="dropdown-item" href="services.php">منتجاتي</a></li>
                    <li><a class="dropdown-item" href="profile.php">الإعدادات</a></li>
                                        <li><a class="dropdown-item" href="logout.php">تسجيل الخروج</a></li>

                </ul>
            </div>
        </div>
    </div>
</nav>
    <div class="container">
        <h1 style="text-align: center;">إدارة المضيف</h1>

        <?php 
        if (isset($_SESSION['message'])) {
            echo $_SESSION['message'];
            unset($_SESSION['message']);
        }
        ?>

        <div style="text-align: center; margin-bottom: 20px;">
            <?php if (!$is_paid): ?>
                <a href="invoice.php?product_id=<?php echo htmlspecialchars($product_id, ENT_QUOTES, 'UTF-8'); ?>" class="btn btn-warning">تجديد</a>
            <?php endif; ?>
            <a href="access_account.php?product_id=<?php echo htmlspecialchars($product_id, ENT_QUOTES, 'UTF-8'); ?>" class="access-btn <?php echo !$is_paid ? 'disabled-btn' : ''; ?>">الوصول إلى Cpanel</a>
        </div>

        <ul class="nav nav-tabs" id="myTab" role="tablist">
            <li class="nav-item">
                <a class="nav-link active" id="details-tab" data-toggle="tab" href="#details" role="tab" aria-controls="details" aria-selected="true">التفاصيل</a>
            </li>
            <li class="nav-item">
                <a class="nav-link <?php echo !$is_paid ? 'disabled-btn' : ''; ?>" id="ssl-tab" data-toggle="tab" href="#ssl" role="tab" aria-controls="ssl" aria-selected="false">إدارة SSL/TLS</a>
            </li>
            <li class="nav-item">
                <a class="nav-link <?php echo !$is_paid ? 'disabled-btn' : ''; ?>" id="password-tab" data-toggle="tab" href="#password" role="tab" aria-controls="password" aria-selected="false">تحديث كلمة المرور</a>
            </li>
           
        </ul>

        <div class="tab-content" id="myTabContent">
            <div class="tab-pane fade show active" id="details" role="tabpanel" aria-labelledby="details-tab">
                <div class="product-card">
                    <h3><?php echo htmlspecialchars($product['name'], ENT_QUOTES, 'UTF-8'); ?></h3>
                    <p><?php echo htmlspecialchars($product['description'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>سعر الاشتراك:</strong> <?php echo htmlspecialchars($price, ENT_QUOTES, 'UTF-8'); ?> USD</p>
                    <p><strong>دورة الفوترة:</strong> <?php echo htmlspecialchars($billing_cycle, ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>اسم النطاق:</strong> <?php echo htmlspecialchars($product['domain'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>اسم المستخدم:</strong> <?php echo htmlspecialchars($product['cpanel_username'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>تاريخ الإنشاء:</strong> <?php echo htmlspecialchars($product['created_at'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>حالة الحساب:</strong> <?php echo htmlspecialchars($product['status'], ENT_QUOTES, 'UTF-8'); ?></p>
                    <p><strong>أيام متبقية للتجديد:</strong> <?php echo htmlspecialchars($days_until_renewal, ENT_QUOTES, 'UTF-8'); ?> أيام</p>
                </div>
            </div>


            <div class="tab-pane fade <?php echo !$is_paid ? 'disabled' : ''; ?>" id="username" role="tabpanel" aria-labelledby="username-tab">
                <div class="product-card">
                    <form method="post" action="">
                        <div class="form-group">
                            <label for="new_username">تحديث اسم المستخدم:</label>
                            <input type="text" id="new_username" name="new_username" class="form-control" value="<?php echo htmlspecialchars($product['username'], ENT_QUOTES, 'UTF-8'); ?>">
                        </div>
                        <button type="submit" name="update_username" class="submit-btn">تحديث اسم المستخدم</button>
                    </form>
                </div>
            </div>

            <div class="tab-pane fade <?php echo !$is_paid ? 'disabled' : ''; ?>" id="password" role="tabpanel" aria-labelledby="password-tab">
                <div class="product-card">
                    <form method="post" action="">
                        <div class="form-group">
                            <label for="new_password">تحديث كلمة المرور:</label>
                            <input type="password" id="new_password" name="new_password" class="form-control">
                        </div>
                        <button type="submit" name="update_password" class="submit-btn">تحديث كلمة المرور</button>
                    </form>
                </div>
            </div>

           <div class="tab-pane fade <?php echo !$is_paid ? 'disabled' : ''; ?>" id="ssl" role="tabpanel" aria-labelledby="ssl-tab">
                <div class="product-card">
                    <h3>إدارة SSL/TLS</h3>
                    <form method="post" action="">
                        <div class="form-group">
                            <label for="selected_domain">حدد النطاق:</label>
                            <select id="selected_domain" name="selected_domain" class="form-control" required>
                                <?php foreach ($domain_list as $domain): ?>
                                    <option value="<?php echo htmlspecialchars($domain, ENT_QUOTES, 'UTF-8'); ?>">
                                        <?php echo htmlspecialchars($domain, ENT_QUOTES, 'UTF-8'); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        <button type="submit" name="install_autossl" class="submit-btn">تثبيت شهادة SSL تلقائيًا</button>
                    </form>
                </div>
            </div>
        </div>
    </div>
        <?php include 'footer.php'; ?>

    <script src="https://code.jquery.com/jquery-3.5.1.slim.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/@popperjs/core@2.5.2/dist/umd/popper.min.js"></script>
    <script src="https://stackpath.bootstrapcdn.com/bootstrap/4.5.2/js/bootstrap.min.js"></script>
    <script>
        $(document).ready(function(){
            // Hide the spinner and make the page interactable after the page fully loads
            $(window).on('load', function() {
                $('.loading-overlay').fadeOut('slow', function() {
                    $(this).css('display', 'none');
                });
            });

            // Show the spinner and disable interaction when any form is submitted
            $('form').on('submit', function(){
                $('.loading-overlay').show();
                $('.loading-overlay').css('pointer-events', 'auto'); // Disable interactions
            });
        });
    </script>
    
</body>
</html>
