<?php
session_start();
include('../config.php');
require '../vendor/autoload.php'; // Make sure PHPMailer is included

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    die(json_encode(['status' => 'error', 'message' => 'Invalid request']));
}

$user_id = $_SESSION['user_id'];
$total_price = $_POST['total_price'] ?? null; // This is the total price sent by PayPal

if (is_null($total_price)) {
    die(json_encode(['status' => 'error', 'message' => 'Total price is missing.']));
}

// Fetch user email from the database based on user_id
$stmt = $pdo->prepare("SELECT email, first_name FROM users WHERE id = ?");
$stmt->execute([$user_id]);
$user = $stmt->fetch();

if (!$user) {
    echo json_encode(['status' => 'error', 'message' => 'User not found.']);
    exit();
}

$userEmail = $user['email'];
$userName = $user['first_name'];

// Fetch cart items from session
$cartItems = $_SESSION['cart'] ?? [];

if (empty($cartItems)) {
    die(json_encode(['status' => 'error', 'message' => 'Cart is empty.']));
}

// Insert order into `orders` table with the total price from PayPal
$stmt = $pdo->prepare("INSERT INTO orders (user_id, total_price, status) VALUES (?, ?, 'paid')");
$stmt->execute([$user_id, $total_price]);
$order_id = $pdo->lastInsertId();



// Prepare email content
$emailSubject = "Thank you for your purchase!";
$emailBody = "<p>Dear $userName,</p>";
$emailBody .= "<p>Thank you for your purchase. Below are the details of your order:</p><ul>";

foreach ($cartItems as $item) {
     $stmt = $pdo->prepare("INSERT INTO order_details (order_id, product_id, quantity, price) VALUES (?, ?, ?, ?)");
    $stmt->execute([$order_id, $item['id'], $item['quantity'], $item['price']]);

    // Check if the item is a domain
    if ($item['type'] == 'domain') {
        $username = 'hostgoal';
                    $password = '2719243214kK!';

                    $dna = new \DomainNameApi\DomainNameAPI_PHPLibrary($username, $password);

                    $contact = array(
                        "FirstName"        => 'Bunyamin',
                        "LastName"         => 'Mutlu',
                        "Company"          => '',
                        "EMail"            => 'bun.mutlu@gmail.com',
                        "AddressLine1"     => 'adres 1 adres 1 adres 1 ',
                        "AddressLine2"     => 'test test',
                        "AddressLine3"     => '',
                        "City"             => 'Kocaeli',
                        "Country"          => 'TR',
                        "Fax"              => '2626060026',
                        "FaxCountryCode"   => '90',
                        "Phone"            => '5555555555',
                        "PhoneCountryCode" => '90',
                        "Type"             => 'Contact',
                        "ZipCode"          => '41829',
                        "State"            => 'GEBZE'
                    );

                    $domain = $item['name'];
                    $billingCycle = $item['billing_cycle2']; // assuming '1' represents the billing cycle you want

                    $response = $dna->RegisterWithContactInfo($domain, 1, [
                        'Administrative' => $contact,
                        'Billing'        => $contact,
                        'Technical'      => $contact,
                        'Registrant'     => $contact
                    ], [
                        "dns1.hostgoal.net",
                        "dns2.hostgoal.net"
                    ], true, false);

                    // Directly use the response data
                    if ($response['result'] === 'OK') {
                        $data = $response['data'];
                        $domainName = $data['DomainName'];
                        $authCode = $data['AuthCode'];
                        $lockStatus = $data['LockStatus'];
                        $privacyProtectionStatus = $data['PrivacyProtectionStatus'];
                        $nameServers = $data['NameServers'];
                        $expirationDate = $data['Dates']['Expiration'];

                        // Prepare data for insertion
                        $nameserver1 = $nameServers[0] ?? '';
                        $nameserver2 = $nameServers[1] ?? '';
                        $protection = $privacyProtectionStatus ? '1' : '0';
                        $epp_code = $authCode;

                        // Insert data into the `user_products` table
                        $stmt = $pdo->prepare("INSERT INTO user_products (user_id, product_id, purchase_date, expire_date, order_id, domain_name, billing_cycle, epp_code) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
                        $stmt->execute([
                            $user_id,
                            $item['id'],
                            date('Y-m-d H:i:s'),
                            $expirationDate,
                            $order_id,
                            $domainName,
                            $billingCycle,
                            $epp_code
                        ]);

        $emailBody .= "<li>Domain: {$item['domain_name']} - Billing Cycle: {$item['billing_cycle2']}</li>";
    } elseif ($item['type'] == 'hosting') {
        $emailBody .= "<li>Hosting Plan: {$item['name']} - Billing Cycle: {$item['billing_cycle2']}</li>";
    } elseif ($item['name'] == 'DV SSL شهادة') {
        $ssl_product_id = $item['id'];
        
        // Add SSL certificate to user's products
        $stmt = $pdo->prepare("INSERT INTO user_products (user_id, product_id, order_id) VALUES (?, ?, ?)");
        $stmt->execute([$user_id, $ssl_product_id, $order_id]);

        $emailBody .= "<li>SSL Certificate: {$item['name']}</li>";
    }
}
}


$emailBody .= "</ul><p>If you have any questions, feel free to contact our support team.</p>";
$emailBody .= "<p>Best regards,<br>HostGoal Team</p>";

// Clear the cart
unset($_SESSION['cart']);

// Send confirmation email
$mail = new PHPMailer(true);
try {
    $mail->isSMTP();
    $mail->Host = 'mail.hostgoal.net';
    $mail->SMTPAuth = true;
    $mail->Username = 'help@hostgoal.net';
    $mail->Password = '2719243214kK';
    $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
    $mail->Port = 465;

    $mail->setFrom('help@hostgoal.net', 'HostGoal Support');
    $mail->addAddress($userEmail);

    $mail->isHTML(true);
    $mail->Subject = 'Thank you for your purchase!';
    $mail->Body = "<p>Dear $userName,</p><p>Thank you for your purchase.</p>";

    $mail->send();
    echo json_encode(['status' => 'success', 'message' => 'Order completed and confirmation email sent.']);
} catch (Exception $e) {
    echo json_encode(['status' => 'error', 'message' => 'Order completed, but email could not be sent. Error: ' . $mail->ErrorInfo]);
}

?>