<?php
// client/profile.php
include('../config.php');
session_start();
include('includes/auth.php');

use PHPMailer\PHPMailer\PHPMailer;
use PHPMailer\PHPMailer\Exception;

require '../vendor/autoload.php';

$user_id = $_SESSION['user_id'];
$message = '';

// Generate a unique token for form submission
if (empty($_SESSION['form_token'])) {
    $_SESSION['form_token'] = bin2hex(random_bytes(32));
}
$form_token = $_SESSION['form_token'];

// Function to log email actions
function logEmailAction($pdo, $receiver_email, $ip_address, $action_description) {
    $stmt = $pdo->prepare("INSERT INTO email_history (receiver_email, ip_address, action_description) VALUES (?, ?, ?)");
    $stmt->execute([$receiver_email, $ip_address, $action_description]);
}

// Handle form submission
if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    if (isset($_POST['form_token']) && hash_equals($_SESSION['form_token'], $_POST['form_token'])) {
        if (isset($_POST['phone'])) {
            $phone = $_POST['phone'];
            $stmt = $pdo->prepare("UPDATE users SET phone = ? WHERE id = ?");
            $stmt->execute([$phone, $user_id]);
            $message = "Phone number updated successfully.";
        } elseif (isset($_POST['email'])) {
            $newEmail = $_POST['email'];
            $verificationCode = md5(uniqid(rand(), true));
            $stmt = $pdo->prepare("UPDATE users SET verification_token = ?, new_email = ? WHERE id = ?");
            $stmt->execute([$verificationCode, $newEmail, $user_id]);

            // Send verification email to the current email address
            $stmt = $pdo->prepare("SELECT email FROM users WHERE id = ?");
            $stmt->execute([$user_id]);
            $currentEmail = $stmt->fetchColumn();

            $verificationLink = "http://one.hostgoal.net/client/verify_email.php?code=$verificationCode";
            $mail = new PHPMailer(true);

            try {
                //Server settings
                $mail->isSMTP();
                $mail->Host       = 'mail.hostgoal.net'; 
                $mail->SMTPAuth   = true;
                $mail->Username   = 'help@hostgoal.net'; 
                $mail->Password   = '2719243214kK'; 
                $mail->SMTPSecure = PHPMailer::ENCRYPTION_SMTPS;
                $mail->Port       = 465; 

                // Recipients
                $mail->setFrom('help@hostgoal.net', 'Host Goal Support');
                $mail->addAddress($currentEmail);

                // Content
                $mail->isHTML(true);
                $mail->Subject = 'Verify your email change request';
                $mail->Body    = "Please click this link to verify your email change request: <a href='$verificationLink'>$verificationLink</a>";

                $mail->send();
                $message = "A verification link has been sent to your current email address.";

                // Log email action
                $ip_address = $_SERVER['REMOTE_ADDR'];
                logEmailAction($pdo, $currentEmail, $ip_address, 'Sent email change verification link');
            } catch (Exception $e) {
                $message = "Message could not be sent. Mailer Error: {$mail->ErrorInfo}";
            }
        } elseif (isset($_POST['giftcard_code'])) {
            $giftcard_code = $_POST['giftcard_code'];
            $stmt = $pdo->prepare("SELECT * FROM giftcards WHERE code = ? AND user_id IS NULL");
            $stmt->execute([$giftcard_code]);
            $giftcard = $stmt->fetch(PDO::FETCH_ASSOC);

            if ($giftcard) {
                $stmt = $pdo->prepare("UPDATE giftcards SET user_id = ? WHERE code = ?");
                $stmt->execute([$user_id, $giftcard_code]);
                
                // Update user balance
                $stmt = $pdo->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
                $stmt->execute([$giftcard['balance'], $user_id]);

                $message = "Gift card redeemed successfully. Your balance has been updated.";
            } else {
                $message = "Invalid or already used gift card.";
            }
        }
        // Invalidate the current token to prevent reuse
        unset($_SESSION['form_token']);
    } else {
        $message = "Invalid form submission. Please try again.";
    }
}


// Handle form submission for PayPal payment success
if (isset($_GET['payment_success']) && $_GET['payment_success'] == 'true') {
    $amount = $_GET['amount'];

    // Ensure the payment is only processed once by checking for a session flag
    if (!isset($_SESSION['payment_processed'])) {
        // Insert a new order with product ID 10 (for adding funds)
        $stmt = $pdo->prepare("INSERT INTO orders (user_id, total_price, status) VALUES (?, ?, 'paid')");
        $stmt->execute([$user_id, $amount]);
        $order_id = $pdo->lastInsertId();

        // Insert the order details with the default product ID 10
        $stmt = $pdo->prepare("INSERT INTO order_details (order_id, product_id, quantity, price) VALUES (?, ?, 1, ?)");
        $stmt->execute([$order_id, 8, $amount]);

        // Update user balance instantly
        $stmt = $pdo->prepare("UPDATE users SET balance = balance + ? WHERE id = ?");
        $stmt->execute([$amount, $user_id]);

        $message = "Funds added successfully! Your balance has been updated.";

        // Set the session flag to prevent reprocessing
        $_SESSION['payment_processed'] = true;

        // Redirect to clear the query parameters to prevent reprocessing
        header('Location: profile.php');
        exit();
    }
}
if (isset($_GET['logout'])) {
    session_destroy();
    header("Location: index.php");
    exit();
}
// Clear the session flag on regular page load
unset($_SESSION['payment_processed']);

// Fetch user data
$stmt = $pdo->prepare("SELECT username, email, phone, balance, picture, oauth_provider FROM users WHERE id = ?");
$stmt->execute([$user_id]);
$user = $stmt->fetch(PDO::FETCH_ASSOC);

// Check if the user is linked to Google Auth
$isGoogleUser = $user['oauth_provider'] == 'google';

// Default user image path
$defaultImagePath = "/assets/images/default_user.png";
$userImage = !empty($user['picture']) ? $user['picture'] : $defaultImagePath;
?>
<!DOCTYPE html>
<html lang="ar" dir="rtl">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>HostGoal - الملف الشخصي</title>
    <link href="https://fonts.googleapis.com/css2?family=Cairo:wght@400;700&display=swap" rel="stylesheet">
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css" rel="stylesheet">
    <style>
    .container {
            padding: 10px;
        }
        body, html {
            font-family: 'Cairo', sans-serif;
            background-color: #f9f9f9;
            margin: 0;
            padding: 0;
            display: flex;
            flex-direction: column;
            min-height: 100vh;
        }

        .navbar {
            background-color: #2c2c2c;
            padding: 10px 20px;
        }

        .navbar-brand {
            display: flex;
            align-items: center;
            color: white;
        }

        .navbar-brand img {
            height: 40px;
            margin-right: 10px;
        }

        .navbar-nav {
        text-align: center;
        flex-grow: 1;
        justify-content: center;
    }

    .navbar-nav .nav-item {
        margin: 0 15px;
    }
         .navbar-nav .nav-link {
        color: #FFF !important;
        font-size: 18px;
        padding: 10px 20px;
        background-color: #17a2b8;
        text-align: center;
        border-radius: 30px;
        transition: background-color 0.3s ease;
    }

        .navbar-nav .nav-link:hover {
            background-color: #0f8a8a;
        }

        .profile-container {
            margin: 50px auto;
            max-width: 600px;
            background-color: #fff;
            padding: 100px;
            border-radius: 10px;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
            text-align: center;
        }

        .profile-container h2 {
            font-size: 24px;
            margin-bottom: 20px;
            color: #333;
        }

        .profile-picture {
            width: 120px;
            height: 120px;
            border-radius: 50%;
            object-fit: cover;
            margin-bottom: 20px;
        }

        .form-container .form-group {
            text-align: right;
            margin-bottom: 15px;
        }
 .profile-menu .dropdown-toggle {
        color: #fff;
        background-color: #17a2b8;
        border-radius: 30px;
        padding: 12px 24px;
        min-width: 180px;
    }

    .profile-menu .dropdown-menu {
        background-color: #2c2c2c;
        color: #fff;
        border-radius: 8px;
        width: 300px;
        padding: 20px;
    }

    .profile-menu .dropdown-menu a {
        color: #fff;
        padding: 10px 20px;
        display: block;
    }

    .profile-menu .dropdown-menu a:hover {
        background-color: #17a2b8;
    }

    .profile-name {
        font-size: 1.2rem;
        font-weight: bold;
        text-align: center;
        margin-bottom: 10px;
    }
.navbar-toggler {
        border: none;
    }

    .navbar-toggler-icon {
        background-image: url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'%3E%3Cpath stroke='rgba%28255, 255, 255, 1%29' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
    }
    .profile-balance {
        padding: 10px;
        color: #fff;
        text-align: center;
        font-size: 1.2rem;
        margin-bottom: 15px;
    }
        .submit-btn {
            background-color: #17a2b8;
            color: white;
            padding: 10px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            width: 100%;
        }

        .submit-btn:hover {
            background-color: #0f8a8a;
        }

        .input-group-text {
            background-color: #17a2b8;
            color: #fff;
        }

        .alert-info {
            text-align: center;
            margin-bottom: 20px;
        }

        /* Footer */
        .footer {
            background-color: #2c2c2c;
            color: #FFF;
            padding: 40px 0;
            text-align: center;
            margin-top: auto;
        }
 .cart-nav-item {
        margin-left: auto;
        display: flex;
        align-items: center;
    }

    .cart-nav-item .nav-link {
        padding: 10px 20px;
        background-color: transparent;
        color: #FFF !important;
        font-size: 20px;
        transition: transform 0.3s ease;
    }

    .cart-nav-item .nav-link:hover {
        transform: scale(1.1);
    }
        .bottom-footer {
            background-color: #1a1a1a;
            padding: 15px 0;
            color: #bbb;
            text-align: center;
        }
    </style>
    <script src="https://www.paypal.com/sdk/js?client-id=AaCAfwjQzvzPQrp0KX8wnB-70DM0i2uHZk4IYPgYYx-Q1MkxrDZpLU-1K_8_-dd-9kPaQNxkvn8_YFUI&currency=USD"></script>
    <script>
        document.addEventListener('DOMContentLoaded', function() {
            paypal.Buttons({
                createOrder: function(data, actions) {
                    let amount = document.getElementById('amount').value;
                    return actions.order.create({
                        purchase_units: [{
                            amount: {
                                value: amount
                            }
                        }]
                    });
                },
                onApprove: function(data, actions) {
                    return actions.order.capture().then(function(details) {
                        alert('Payment successful by ' + details.payer.name.given_name);

                        let amount = document.getElementById('amount').value;
                        window.location.href = "profile.php?payment_success=true&amount=" + amount;
                    });
                },
                disableFunding: 'credit,card'
            }).render('#paypal-button-container');
        });
    </script>
</head>
<body>

<!-- Navbar -->
<nav class="navbar navbar-expand-lg">
    <div class="container">
        <a class="navbar-brand" href="#">
            <img src="../assets/images/logo.png" alt="HostGoal Logo">
            <span>لوحة التحكم</span>
        </a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarNav" aria-controls="navbarNav" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarNav">
            <ul class="navbar-nav mx-auto">
                <li class="nav-item"><a class="nav-link" href="new_order.php">أطلب</a></li>
                <li class="nav-item"><a class="nav-link" href="services.php">منتجاتي</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">طلباتك</a></li>
                <li class="nav-item"><a class="nav-link" href="invoice.php">الفواتير</a></li>
                <li class="nav-item dropdown">
                    <a class="nav-link dropdown-toggle" href="#" id="navbarDropdown" role="button" data-bs-toggle="dropdown" aria-expanded="false">الدعم</a>
                    <ul class="dropdown-menu" aria-labelledby="navbarDropdown">
                        <li><a class="dropdown-item" href="client_tickets.php">التذاكر</a></li>
                        <li><a class="dropdown-item" href="forum.php">المجتمع</a></li>
                        <li><a class="dropdown-item" href="q_and_a.php">Q&A</a></li>
                    </ul>
                </li>
            </ul>
            <li class="nav-item cart-nav-item">
                <a class="nav-link" href="/client/cart.php">
                    <i class="fas fa-shopping-cart"></i>
                </a>
            </li>
            <div class="dropdown profile-menu">
                <a class="btn btn-primary dropdown-toggle" href="#" role="button" id="dropdownMenuLink" data-bs-toggle="dropdown" aria-expanded="false">
                    <i class="fas fa-user"></i> <?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?>
                </a>
                <ul class="dropdown-menu" aria-labelledby="dropdownMenuLink">
                    <li class="profile-name"><?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?></li>
                    <li class="profile-balance">الرصيد: $<?php echo number_format($user['balance'], 2); ?></li>
                    <li><a class="dropdown-item" href="dashboard.php">لوحة التحكم</a></li>
                    <li><a class="dropdown-item" href="services.php">منتجاتي</a></li>
                    <li><a class="dropdown-item" href="profile.php">الإعدادات</a></li>
                    <li><a class="dropdown-item" href="logout.php">تسجيل الخروج</a></li>
                </ul>
            </div>                      
        </div>
    </div>
</nav>

<!-- Profile Section -->
<div class="profile-container">
    <h2>الملف الشخصي</h2>
    <?php if ($message): ?>
        <div class="alert alert-info"><?php echo htmlspecialchars($message, ENT_QUOTES, 'UTF-8'); ?></div>
    <?php endif; ?>
    <img src="<?php echo htmlspecialchars($userImage, ENT_QUOTES, 'UTF-8'); ?>" alt="User Picture" class="profile-picture">
    <form action="profile.php" method="POST">
        <div class="form-group">
            <label for="username">اسم المستخدم</label>
            <input type="text" class="form-control" name="username" value="<?php echo htmlspecialchars($user['username'], ENT_QUOTES, 'UTF-8'); ?>" disabled>
        </div>
        <div class="form-group">
            <label for="phone">الهاتف الحالي</label>
            <input type="text" class="form-control" name="phone" value="<?php echo htmlspecialchars($user['phone'], ENT_QUOTES, 'UTF-8'); ?>" <?php if ($isGoogleUser) echo 'disabled'; ?> required>
        </div>
                        <input type="hidden" name="form_token" value="<?php echo $form_token; ?>">

        <?php if (!$isGoogleUser): ?>
            <button type="submit" class="submit-btn">تحديث الهاتف</button>
        <?php endif; ?>
    </form>
    <form action="profile.php" method="POST" class="mt-4">
        <div class="form-group">
            <label for="email">البريد الإلكتروني الحالي</label>
            <input type="email" class="form-control" name="current_email" value="<?php echo htmlspecialchars($user['email'], ENT_QUOTES, 'UTF-8'); ?>" disabled>
        </div>
        <?php if (!$isGoogleUser): ?>
            <div class="form-group">
                <label for="email">البريد الإلكتروني الجديد</label>
                <input type="email" class="form-control" name="email" required>
            </div>
            <input type="hidden" name="form_token" value="<?php echo $form_token; ?>">
            <button type="submit" class="submit-btn">تحديث البريد الإلكتروني</button>
        <?php endif; ?>
    </form>

    <form method="POST" class="mt-4">
        <label for="balance">الرصيد الحالي</label>
        <div class="input-group mb-3">
            <div class="input-group-prepend">
                <span class="input-group-text">$</span>
            </div>
            <input type="text" class="form-control" name="balance" value="<?php echo number_format($user['balance'], 2); ?>" disabled>
        </div>
        <div class="form-group">
            <label for="amount">إضافة رصيد</label>
            <input type="number" id="amount" class="form-control" name="amount" placeholder="أدخل المبلغ" required>
        </div>
        <div id="paypal-button-container"></div>
    </form>
</div>

<!-- Footer -->
    <?php include 'footer.php'; ?>

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>