<?php
include('../config.php');
include('includes/auth.php');
require_once __DIR__.'/../client/dna.php';

session_start();

$order_id = $_GET['order_id'];
$status = $_GET['status'];

$stmt = $pdo->prepare("SELECT od.product_id, p.product_type, p.internal_name, up.id as user_product_id, up.domain_name, up.billing_cycle, ua.username
                       FROM order_details od
                       JOIN products p ON od.product_id = p.id
                       LEFT JOIN user_products up ON up.product_id = p.id
                       LEFT JOIN user_accounts ua ON ua.product_id = p.id AND ua.user_id = up.user_id
                       WHERE od.order_id = ?");
$stmt->execute([$order_id]);
$orderDetails = $stmt->fetchAll(PDO::FETCH_ASSOC);

if ($status === 'paid') {
    $paymentDate = date('Y-m-d H:i:s'); // Current date and time of payment
    $_SESSION['api_responses'] = []; // Initialize the session array for API responses

    foreach ($orderDetails as $detail) {
        if ($detail['product_type'] === 'domain') {
            // Initialize Domain API
            $dna = new \DomainNameApi\DomainNameAPI_PHPLibrary('hostgoal', '2719243214kK!');

            // Renew the domain via API
            $domainRenewal = $dna->Renew($detail['domain_name'], $detail['billing_cycle']); 

            // Check if the API call was successful
            if ($domainRenewal['result'] === 'OK') {
                // Extract the new expiration date from the response
                $newExpirationDate = $domainRenewal['data']['ExpirationDate'];

                // Update the creation date and expiration date in user_products
                $stmt = $pdo->prepare("UPDATE user_products SET created_at = ?, expire_date = ? WHERE id = ?");
                $stmt->execute([$paymentDate, $newExpirationDate, $detail['user_product_id']]);

            } else {
                // Handle the API error (e.g., log the error, notify the user, etc.)
                error_log("Domain renewal failed for domain: {$detail['domain_name']}. API response: " . print_r($domainRenewal, true));
                // Store the error response in the session
                $_SESSION['api_responses'][] = [
                    'domain' => $detail['domain_name'],
                    'response' => print_r($domainRenewal, true) // Store the print_r output as a string
                ];
            }

        } elseif ($detail['product_type'] === 'hosting') {
    // Check if the account is suspended before trying to unsuspend it
    $accountStatusResponse = checkCpanelAccountStatus($detail['username']);
    
    if (isset($accountStatusResponse['metadata']['result']) && $accountStatusResponse['metadata']['result'] == 1) {
        // Check if the account is currently suspended
        if ($accountStatusResponse['data']['suspended'] == 1) {
            // Unsuspend the cPanel account using WHM API
            $unsuspendResponse = unsuspendCpanelAccount($detail['username']);

            if (isset($unsuspendResponse['metadata']['result']) && $unsuspendResponse['metadata']['result'] == 1) {
                $_SESSION['invoice_notifications'][] = "تم إعادة تفعيل حساب cPanel لـ {$detail['internal_name']} بعد دفع الفاتورة.";
            } else {
                $_SESSION['invoice_notifications'][] = "فشل إعادة تفعيل حساب cPanel لـ {$detail['internal_name']}.";
                error_log("Failed to unsuspend cPanel account for {$detail['internal_name']}. Response: " . print_r($unsuspendResponse, true));
            }
        } else {
            // Account is not suspended
            $_SESSION['invoice_notifications'][] = "حساب cPanel لـ {$detail['internal_name']} غير معلق.";
        }
    } else {
        $_SESSION['invoice_notifications'][] = "فشل في التحقق من حالة حساب cPanel لـ {$detail['internal_name']}.";
        error_log("Failed to check suspension status for {$detail['internal_name']}. Response: " . print_r($accountStatusResponse, true));
    }

    // Activate hosting account in the database
    $stmt = $pdo->prepare("UPDATE user_accounts SET status = 'active', created_at = NOW() WHERE product_id = ? AND user_id = ?");
    $stmt->execute([$detail['product_id'], $user_id]);
}

    }

    // Update the order's creation date and status to paid after processing all products
    $stmt = $pdo->prepare("UPDATE orders SET created_at = ?, status = 'paid' WHERE id = ?");
    $stmt->execute([$paymentDate, $order_id]);
}

// Redirect back to the invoices page
header("Location: invoice.php");
exit();

// Function to unsuspend cPanel account
function unsuspendCpanelAccount($username) {
    $whm_user = "hostgoal";
    $whm_token = "U2M8FSQKEB4KFDLBOSW6T7MPTL4AUV85";
    $whm_server = "hostgoal.net";
    
    $url = "https://$whm_server:2087/json-api/unsuspendacct?api.version=1&user=$username";
    
    $curl = curl_init();
    curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
    curl_setopt($curl, CURLOPT_SSL_VERIFYHOST, false);
    curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($curl, CURLOPT_URL, $url);
    curl_setopt($curl, CURLOPT_HTTPHEADER, [
        "Authorization: whm $whm_user:$whm_token"
    ]);

    $response = curl_exec($curl);
    curl_close($curl);

    return json_decode($response, true);
}

?>
